(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    305619,       5755]
NotebookOptionsPosition[    301707,       5621]
NotebookOutlinePosition[    302263,       5641]
CellTagsIndexPosition[    302220,       5638]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "tested 190817 using ",
 StyleBox["SpinDynamica",
  FontSlant->"Italic"],
 " 3.0.1 under ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 11.0"
}], "Text",
 CellChangeTimes->{{3.661342462483639*^9, 3.66134250631325*^9}, {
   3.661342549769909*^9, 3.661342557982389*^9}, {3.661342971467606*^9, 
   3.661342974817833*^9}, {3.6613433573329477`*^9, 3.661343357745117*^9}, 
   3.663827731996285*^9, {3.7038513532816772`*^9, 3.7038513721695166`*^9}, {
   3.7121571153459816`*^9, 3.712157125227037*^9}, {3.7121571583767223`*^9, 
   3.7121571593065968`*^9}}],

Cell[CellGroupData[{

Cell["Composite Pulse", "Title",
 CellChangeTimes->{{3.486707671042198*^9, 3.486707681352862*^9}, {
  3.496138701458185*^9, 3.4961387068870792`*^9}}],

Cell["\<\
this example notebook shows how trajectories of a magnetization vector may be \
generated under a sequence of events\
\>", "Text",
 CellChangeTimes->{{3.4867076845703573`*^9, 3.486707721144928*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456486753323069*^9, 3.4564867611682034`*^9}, {
  3.5689040963246765`*^9, 3.568904097427739*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 3.1.0 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.703920723247096*^9, 3.712151040215372*^9, 
  3.7286341722557745`*^9}],

Cell[BoxData[
 TemplateBox[{
  "ModifyBuiltIn","report",
   "\"The following built-in routines have been modified in SpinDynamica: \\!\
\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"Chop\\\", \\\",\\\", \\\"Dot\\\", \
\\\",\\\", \\\"Duration\\\", \\\",\\\", \\\"Exp\\\", \\\",\\\", \
\\\"Expand\\\", \\\",\\\", \\\"ExpandAll\\\", \\\",\\\", \\\"NumericQ\\\", \\\
\",\\\", \\\"Plus\\\", \\\",\\\", \\\"Power\\\", \\\",\\\", \\\"Simplify\\\", \
\\\",\\\", \\\"Times\\\", \\\",\\\", \\\"WignerD\\\"}], \\\"}\\\"}]\\). \
\\nEvaluate \
??\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\) to \
generate the additional definitions for \
\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\).\"",2,1,
   1,32644608679333221010,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.703920724259127*^9, 3.712151041158043*^9, 
  3.7286341732313547`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Trajectory of rotating-frame Magnetization Vectors under a composite pulse, \
without relaxation\
\>", "Subsubtitle",
 CellChangeTimes->{{3.45654559767572*^9, 3.4565456179697647`*^9}, {
  3.486707740466404*^9, 3.4867077430089273`*^9}, {3.486707774811631*^9, 
  3.4867077788090067`*^9}}],

Cell[CellGroupData[{

Cell["Set up", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "1", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456486764078146*^9, 3.456486768296845*^9}, 
   3.486707724812611*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\"}\\\"}]\\)\"",2,2,2,32644608679333221010,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.4564867688476667`*^9, 3.456490985477935*^9, 3.456491049608947*^9, 
   3.456491116917556*^9, 3.456491157681363*^9, 3.45649121749653*^9, 
   3.456491432105215*^9, 3.456496332961212*^9, {3.456498302102263*^9, 
   3.4564983084741697`*^9}, 3.4564986708145647`*^9, 3.456505718796771*^9, 
   3.456505938111739*^9, 3.456506057196533*^9, 3.456506205932489*^9, 
   3.4565070239579906`*^9, 3.456544851405511*^9, 3.456545018527794*^9, 
   3.456545567569685*^9, 3.456570778651332*^9, 3.456589415492635*^9, 
   3.458994529786888*^9, 3.459442719019311*^9, 3.461066532603982*^9, 
   3.461329802925782*^9, 3.462005865970642*^9, 3.464025083820554*^9, 
   3.464803444255741*^9, 3.465814125487908*^9, 3.467015921261812*^9, 
   3.486707728179102*^9, 3.486708000048277*^9, 3.486709666324088*^9, 
   3.486711407811521*^9, 3.486719488058907*^9, 3.496138726572187*^9, 
   3.496138856988586*^9, 3.497518242478581*^9, 3.497528386369418*^9, 
   3.497528464022998*^9, 3.497530308631044*^9, 3.4975693632062283`*^9, 
   3.4975742534804296`*^9, 3.497648481976078*^9, 3.499304085498835*^9, 
   3.5020111697125053`*^9, 3.502710927995579*^9, 3.502761284053297*^9, 
   3.503307132944734*^9, 3.507024636355743*^9, 3.5070257691554947`*^9, 
   3.507028315756967*^9, 3.510318332247847*^9, 3.510318374000402*^9, 
   3.511622994030232*^9, 3.511623375271317*^9, 3.511623900570404*^9, 
   3.5131623874408703`*^9, 3.515068489670658*^9, 3.5150694984657097`*^9, 
   3.533177705134063*^9, 3.5689041032500725`*^9, 3.571380086774671*^9, 
   3.571380451924457*^9, 3.703853699766881*^9, 3.703853855403141*^9, 
   3.7038539270809956`*^9, 3.7038563757356973`*^9, 3.7038567503638*^9, 
   3.7039207244190073`*^9, 3.712151041386284*^9, 3.7286341733642263`*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \
\\\"Automatic\\\"}]}], \\\"]\\\"}]\\).\"",2,2,3,32644608679333221010,"Local"},
  
  "MessageTemplate"]], "Message", "MSG",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.4564867688476667`*^9, 3.456490985477935*^9, 3.456491049608947*^9, 
   3.456491116917556*^9, 3.456491157681363*^9, 3.45649121749653*^9, 
   3.456491432105215*^9, 3.456496332961212*^9, {3.456498302102263*^9, 
   3.4564983084741697`*^9}, 3.4564986708145647`*^9, 3.456505718796771*^9, 
   3.456505938111739*^9, 3.456506057196533*^9, 3.456506205932489*^9, 
   3.4565070239579906`*^9, 3.456544851405511*^9, 3.456545018527794*^9, 
   3.456545567569685*^9, 3.456570778651332*^9, 3.456589415492635*^9, 
   3.458994529786888*^9, 3.459442719019311*^9, 3.461066532603982*^9, 
   3.461329802925782*^9, 3.462005865970642*^9, 3.464025083820554*^9, 
   3.464803444255741*^9, 3.465814125487908*^9, 3.467015921261812*^9, 
   3.486707728179102*^9, 3.486708000048277*^9, 3.486709666324088*^9, 
   3.486711407811521*^9, 3.486719488058907*^9, 3.496138726572187*^9, 
   3.496138856988586*^9, 3.497518242478581*^9, 3.497528386369418*^9, 
   3.497528464022998*^9, 3.497530308631044*^9, 3.4975693632062283`*^9, 
   3.4975742534804296`*^9, 3.497648481976078*^9, 3.499304085498835*^9, 
   3.5020111697125053`*^9, 3.502710927995579*^9, 3.502761284053297*^9, 
   3.503307132944734*^9, 3.507024636355743*^9, 3.5070257691554947`*^9, 
   3.507028315756967*^9, 3.510318332247847*^9, 3.510318374000402*^9, 
   3.511622994030232*^9, 3.511623375271317*^9, 3.511623900570404*^9, 
   3.5131623874408703`*^9, 3.515068489670658*^9, 3.5150694984657097`*^9, 
   3.533177705134063*^9, 3.5689041032500725`*^9, 3.571380086774671*^9, 
   3.571380451924457*^9, 3.703853699766881*^9, 3.703853855403141*^9, 
   3.7038539270809956`*^9, 3.7038563757356973`*^9, 3.7038567503638*^9, 
   3.7039207244190073`*^9, 3.712151041386284*^9, 3.7286341734115105`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["set nutation frequency and pulse durations", "Subsubsection",
 CellChangeTimes->{{3.48670775122621*^9, 3.4867077575448713`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]nut", "=", 
  RowBox[{"2", "\[Pi]", " ", "50", " ", 
   RowBox[{"10", "^", "3"}]}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.45648725443048*^9, 3.4564872674862623`*^9}}],

Cell[BoxData[
 RowBox[{"100000", " ", "\[Pi]"}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwBmLeK71vdh546XipMMZvF5C2YJXZtxtI21558RxElxys
DtwPpFXCG34dBtK7IibnXgPS6xQfPgfRH3hub34EpDf11+g0HX3p2GGTxBJ7
7KVjjr3k09KTLx3/HY4v/Aak96mdnuBw+qVj24KaeqnzLx2dfnzqm3bhpeMS
1428LZdeOt44MfPeuSsvHXv2sqjE/Xrp2HnJ9wuI3vXiz9l4IN3LxXogGUjb
/bryJ4rnlaPGb0XeaCA9pSVoyh++V44Lrvp1MPK/cjTvYZkEovdKT6tgAtIX
lmV0iQLpOP6Nb8WB9LECBx0bIJ0quXFSitArx8uLLVL6xF85vnBmFHoi8crx
0dWmFX+AtKTOAn12KaA96T3xcoqvHA9Yq70F0QFhldoKQPppcOf8NPVXjkXt
h5aA6C3F7qsea75ybPN6fxNE7/wwU/oJkF4dXRB0WeeVo4KyOWeZwSvHJxMD
20H0iWWquQzBrxyZrfd+VZkO5J/jeX939itHkbYLMveAtG9cVUDXjNeOTJvf
JYPoV8VPckC0wYmf87qBtEnc2bMg2mVNH9dqIP3hqe6B2BWvHSW016qfO/7a
EQDlKfgw
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]360", "=", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{"\[Pi]", "/", "\[Omega]nut"}]}], "//", "N"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4564872737502413`*^9, 3.45648728231886*^9}, {
  3.571380410569335*^9, 3.571380411552565*^9}}],

Cell[BoxData["0.00002`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAWIrgfJ3Ow+8dBT4k+i3C0hLscjt2w2kXXXfPQfRvQm1
gfuBtMzPxl+HgfTeuum514D0/ftPn4PohF33Nj8C6a9o0mk6+tKRf3s6S+yx
l45/OmSflp586Xj+RULhNyDNW3d+gsPpl45XdtTWS51/6djg9K1v2oWXjhsS
N/G2XHrpWNM89965Ky8dzSXZVOJ+vXTUCfb/AqIttP+fjQfSk+azHUgG0qeU
r/2J4nnl+HKHMm80kLY9HjzlD98rx0cZAR2M/K8cb61hnwSiueZMr2AC0urn
MrtEgfQvq81vxYF0tZCTjg2Qttu8aVKK0CtHyd2WKX3irxwrpjEJPZF45ajk
17LiD5DeunmhPrvUK0ch/b54OcVXjqu2qL8F0ZNkq7UVgLTB5K75aepAe5SP
LAHRH096rHqs+cqxpOvDTRC99+ps6SdA+kBTYdBlnVeO01wsOMsMXjk+2BPU
DqJ1otRzGYJfObLscf+mMv2VI8dsg/d3Z79ydLs9Q/wekH7yulIWRHftqQro
mvHa8VXU+2QQXfPlSQ6IfmT0a143kJ7Gdu4siP71to9rNZA2ydU7ELvitaPW
pbXq546/dgQAam/6+g==
  "]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Tau]90", "=", 
   RowBox[{"\[Tau]360", "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]180", "=", 
   RowBox[{"\[Tau]360", "/", "2"}]}], ";"}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456487303908699*^9, 3.456487322265479*^9}, 
   3.5713802560898542`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["set a factor to take into account an rf field error", "Subsubsection",
 CellChangeTimes->{{3.486707795305949*^9, 3.4867078084645147`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rffactor", "=", "0.9"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456487343618906*^9, 3.456487350563151*^9}}],

Cell[BoxData["0.9`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwA+KOsu/fdh546RjGlOq3C0jPXKOwbzeQ/nP5w3MQfZG1
IXA/kHZpafl1GEjvsp6dew1IT+V/+RxEc9x+sPkRkJ6r0KrTdPSl4+YLWSyx
x146iloqPi09CZSvSyr8BqRt1l6e4HD6peODpIZ6qfMvHUPyf/ZNu/DSsejn
Zt6WSy8dWZ0X3jt35aVjx1wOlbhfLx3ftQR+AdFxuxjPxQPpXYqcB5KB9LK8
lL9RPK8cl6mo8UYDaUXv8Cl/+F45XugI7mDkB4q/5poEonOMZlUwAWnD3zld
okD69IQtb8WB9N0OFx0bIG2jv3VSitArR1ddm5Q+8VeO7+xYhJ5IvHK8+LJt
xR8gvSVpsT671CvHlaIT4uUUXzlqeGq9BdE3JtZqKwBpe63e+WnqrxwFTh9b
AqIZwguPgOg3b3+ueqz5ytEv5/NNEH1Pb570EyCdpVgSdFnnlaP2fivOMoNX
jpO+hbSD6G1PNHMZgl857jN58l1l+ivHMOE57+/OBrrHvoXlHpDuL3glDqKj
Ft6RBdHVldUBXTNeO4axfkgG0f8WPM0B0fySv+d1A+kbX86dBdEdTP1cq0Hi
vPoHYle8dtzXt0793PHXjgBOfgLD
  "]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["define the CompositePulse events", "Subsubsection",
 CellChangeTimes->{{3.486707795305949*^9, 3.4867078310165663`*^9}, {
  3.486707883008696*^9, 3.4867078855362186`*^9}}],

Cell["\<\
the events in this example have the form {Hamiltonian, duration}\
\>", "Text",
 CellChangeTimes->{{3.486707919112117*^9, 3.486707932272455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompositePulse", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}]}], ",", "\[Tau]90"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]180"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}]}], ",", "\[Tau]90"}], "}"}]}], 
   "}"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456486777827767*^9, 3.456486807941424*^9}, {
  3.4564872932597227`*^9, 3.456487364614019*^9}, {3.456545631845837*^9, 
  3.456545639691646*^9}, {3.456546615295023*^9, 3.456546620333604*^9}, {
  3.571380328755287*^9, 3.571380422036787*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"282743.3388230814`", " ", 
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "y"}]],
       DisplayForm]}], ",", "5.`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"282743.3388230814`", " ", 
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "x"}]],
       DisplayForm]}], ",", "0.00001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"282743.3388230814`", " ", 
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "y"}]],
       DisplayForm]}], ",", "5.`*^-6"}], "}"}]}], "}"}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.456486808373254*^9, 3.456487366201235*^9, 3.456490993084261*^9, 
   3.456498316051669*^9, 3.456507860174181*^9, 3.4565456448858433`*^9, 
   3.45654662332018*^9, 3.456570783094582*^9, 3.458994532197195*^9, 
   3.4594427233733273`*^9, 3.461066537073645*^9, 3.461329803112359*^9, 
   3.462005915392868*^9, 3.46402508406954*^9, 3.464803447834118*^9, 
   3.4658141256583023`*^9, 3.467015925097261*^9, 3.4867079700454893`*^9, 
   3.4867080003417587`*^9, 3.4867096665966787`*^9, 3.48671140812533*^9, 
   3.486719488345499*^9, 3.49613873632355*^9, 3.496138857229785*^9, 
   3.4975182427689457`*^9, 3.4975283866686983`*^9, 3.4975284644002113`*^9, 
   3.497530308873089*^9, 3.497569363440144*^9, 3.497574253683196*^9, 
   3.497648482198881*^9, 3.499304085719961*^9, 3.5020111699372673`*^9, 
   3.502710928167856*^9, 3.502761284274275*^9, 3.5033071331389217`*^9, 
   3.5070246365395517`*^9, 3.507025769379627*^9, 3.50702831598178*^9, 
   3.510318332463326*^9, 3.510318374264708*^9, 3.51031840933994*^9, {
   3.5103186087420063`*^9, 3.510318627659898*^9}, 3.5116229999450293`*^9, 
   3.5116233756698008`*^9, 3.511623901004915*^9, 3.513162387686613*^9, 
   3.515068489891563*^9, 3.515069498707625*^9, 3.5331777053592863`*^9, 
   3.568904176861283*^9, 3.5713801092687197`*^9, 3.571380263466633*^9, {
   3.5713803307739267`*^9, 3.571380423647875*^9}, 3.57138047504224*^9, 
   3.703853699870454*^9, 3.703853855514188*^9, 3.7038539271899405`*^9, 
   3.7038563758499727`*^9, 3.7038567504884443`*^9, 3.703920724489571*^9, 
   3.712151041482853*^9, 3.7286341734614673`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TotalDuration", "=", 
  RowBox[{"EventDuration", "[", "CompositePulse", "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.486708077644203*^9, 3.486708112610662*^9}, 
   3.5103183603617373`*^9, {3.703853677979781*^9, 3.70385367883292*^9}}],

Cell[BoxData["0.00002`"], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.486708113284984*^9, 3.486709666635248*^9, 3.4867114081951437`*^9, 
   3.486719488454164*^9, 3.496138736457921*^9, 3.496138857298582*^9, 
   3.497518242823004*^9, 3.497528386742837*^9, 3.4975284644620047`*^9, 
   3.4975303089215927`*^9, 3.4975693634953938`*^9, 3.497574253718444*^9, 
   3.497648482250607*^9, 3.4993040857654543`*^9, 3.502011169987691*^9, 
   3.502710928214916*^9, 3.502761284323965*^9, 3.503307133193198*^9, 
   3.507024636593504*^9, 3.5070257694289923`*^9, 3.507028316026917*^9, 
   3.510318332513612*^9, 3.51031837431383*^9, 3.51031840945617*^9, {
   3.510318608859171*^9, 3.510318627711323*^9}, 3.511623000003599*^9, 
   3.5116233757606697`*^9, 3.511623901050851*^9, 3.513162387736068*^9, 
   3.515068489941279*^9, 3.5150694987423267`*^9, 3.533177705411393*^9, 
   3.568904179507434*^9, 3.57138011216673*^9, 3.571380265421607*^9, {
   3.571380331870887*^9, 3.5713804256522818`*^9}, 3.571380477030979*^9, 
   3.7038536998848825`*^9, 3.703853855519702*^9, 3.703853927200388*^9, 
   3.7038563758656006`*^9, 3.703856750508016*^9, 3.703920724498596*^9, 
   3.7121510414958863`*^9, 3.7286341734614673`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["on-resonance trajectory of z-magnetization, starting from z", \
"Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707871584403*^9}, {
  3.486707939722651*^9, 3.486707945208267*^9}, {3.486708008593843*^9, 
  3.4867080096800623`*^9}, {3.4867084425459023`*^9, 3.4867084445507593`*^9}}],

Cell["\<\
in this example,  an option is given setting the initial time point to 0. \
Otherwise the final time point will be 0\
\>", "Text",
 CellChangeTimes->{{3.486708253424407*^9, 3.4867082875594273`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iztraj", "=", 
  RowBox[{"Trajectory", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}], "\[Rule]", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
    "CompositePulse"}], "\[IndentingNewLine]", "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4565095226613693`*^9, 3.456509562395952*^9}, {
  3.486708014261339*^9, 3.48670803633846*^9}, {3.497528432213043*^9, 
  3.497528451351882*^9}, {3.510318392151885*^9, 3.5103183974210243`*^9}, {
  3.5713802269825153`*^9, 3.571380229467991*^9}, {3.57138027681271*^9, 
  3.571380279123439*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"TrajectoryFunction", "["}], 
   TagBox[
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"0\"\>",
        0,
        Editable->False], ",", 
       InterpretationBox[
        RowBox[{"\<\"20.\"\>", "\[Times]", 
         SuperscriptBox["10", "\<\"-6\"\>"]}],
        0.00002,
        AutoDelete->True]}], "}"}], "}"}],
    EngineeringForm], "\<\", <>]\"\>"}],
  DisplayForm]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456509549294127*^9, 3.45650956323951*^9}, 
   3.456509647542842*^9, 3.4565098974113092`*^9, 3.456545656175568*^9, 
   3.456546623398144*^9, {3.456570783390377*^9, 3.456570796273484*^9}, 
   3.456570832703512*^9, 3.458994532296883*^9, 3.459442723512301*^9, 
   3.461066537245344*^9, 3.4613298032665*^9, {3.4620059345073957`*^9, 
   3.4620059394326477`*^9}, 3.4640250841192636`*^9, 3.464803447884685*^9, 
   3.465814125692009*^9, 3.467015925147357*^9, {3.486707964429309*^9, 
   3.4867079728747177`*^9}, 3.4867080041836433`*^9, 3.486708037345064*^9, 
   3.486709666747039*^9, 3.4867114082855797`*^9, 3.48671948881513*^9, 
   3.49613874134447*^9, 3.496138857572397*^9, 3.4975182491635113`*^9, 
   3.49752838717353*^9, {3.4975284521564407`*^9, 3.497528467876129*^9}, 
   3.497530308973771*^9, 3.497569371419191*^9, 3.49757425377354*^9, 
   3.497648482487999*^9, 3.4993040858570833`*^9, 3.502011170035692*^9, 
   3.5027109282512703`*^9, 3.50276128448379*^9, 3.503307133237276*^9, 
   3.507024636814217*^9, 3.507025769886622*^9, 3.507028316081903*^9, 
   3.51031833256347*^9, 3.510318374364255*^9, {3.5103184053587112`*^9, 
   3.5103184095076733`*^9}, {3.51031861244042*^9, 3.510318630881318*^9}, 
   3.511623010511313*^9, 3.511623380015483*^9, {3.511623905126514*^9, 
   3.511623919243656*^9}, 3.5131623877844276`*^9, 3.515068489991561*^9, 
   3.5150694987869043`*^9, 3.533177705470131*^9, 3.568904188198931*^9, 
   3.5713801181836767`*^9, 3.571380230298695*^9, 3.571380267633562*^9, {
   3.571380333861266*^9, 3.571380427561781*^9}, 3.57138048003728*^9, 
   3.7038537000207205`*^9, 3.703853855664493*^9, 3.703853927336963*^9, 
   3.7038563760218744`*^9, 3.7038567505963545`*^9, 3.703920724644144*^9, 
   3.712151041725031*^9, 3.7286341736121917`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Iztraj", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "TotalDuration"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.45650956890828*^9, 3.456509571083004*^9}, {
   3.4565099019330606`*^9, 3.4565099070840673`*^9}, {3.456545660832933*^9, 
   3.4565456665182953`*^9}, {3.486708063467409*^9, 3.4867080670420017`*^9}, 
   3.486708120749165*^9, {3.57138015166833*^9, 3.571380176414342*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk0Vd0bB3BKlAYZKsn00oi3NHlRPTsZQspYSSQiRKVBSqg0GIpkLsqQ
IYXMc7Z7ryQZCteYEpku927cQyj63d/+56zPetba69nP9+yzzj/2F80cF/Dx
8d3k5+P7/9Mxd7Dpc7H1vpq//18EyWaKO9RZakL5sWvtf3g2Fro8EWZpCDv/
rrTn8iwkfb7Dlm4OWa1f4vp4dtqVqHHN0gqWzJQF1PN8JpVlpOd5Gi5WNm/I
4Tk8V8DHlH4G7N/LXg3hmVEhm2m93Alyvr284sgzt1a928nyHNz9x3W9Gs8K
bWbLr7w8D7o/fB7w8Zx+qVAWebpD8duBp1XzBNE8GYVV0pdhwDrnlB/PHT6f
jxjSr4D8L1aLBs/jd7sHGp084G9t4h/WHEFLgli+R5d7gs2ZfmYkzxpRAm9P
W3qBoc7x5+1/CDKJEz04MHcT6B2vH7rz7Jwk+931pQ8E1TOVF/BsdDzOf4/n
bZBZLewn9psgy84k83mDO2CTfkD9ySxBDjbpcjRpP2hYk5OwhGfvM4VFevS7
kJEVGzA4TVDAQPndJZH34K6g6eLDPEe4MIzrnO7DiZgszYxfBGVc/Dxoutwf
bK70Fh2fIujrTdYaG8sgsGmbWHOGS9DQ/FifnPJDMJBJU42aIIi68+tt79xD
SJtVnKOPE7QsQEDf+WUwrD0gl7tkjJefoUi5hmcofBv/FXpolKDkh2IKsT2h
EKlaZWQ0QpBS/aqAPwZPgNFW806PRZCaibQFlg6D0E7Dys1DBB05tmVUhx4O
1rcVDyf2EdQSrWKWqhwBWxXiii/2EmTVsa1YKDIChk4t6/rvB0FnrdXu1TpF
QnJDrW7BN4J87bWlTZZHQx+rusShg6CsCzZGJy2fga60kGVUPUEqtyv6ntY+
A8O0o73dnwh680TuZvveWBCzq1ohW0vQq/wf6Uf/iYPRtS+NA6oJSpx1FDJh
PQcJDSUfAUyQofZ/dgoVCbCVs24kNouXb91ghtavBDhaWfvpfAZBNRYx06dV
EyHMpveo+muCDp6deRyflAgJ+Seci1II0gksq5D2TwIZ6c2RNnEEQSOSXmOS
DBlinwMNAwiaOz7mpBaYDEU+ygfS7hNU3pOQd5SeDGP3RjL++BG0Z4L/UMSu
FKh4Ix73xIcg9VVVN0TXpsLf/tKJM5cJ2n5Sv21pbxoobE+WeGNF0PpBkzC+
q2/AotlCpmYDQaUJdg3H0t9AQHFMy3UF3v2yuiyc+e0N/Mn8pqUoR5BXfbjf
CYMMYJYoajlKEvQ5r/Vyrmwm7Pv9rv+5MEE3b1ubO3zMgtYVJQ69bA4aXrZL
2EEkB1j7jjq/e8tB+S57N4so5cBrc3e91Dcc5Futo1eqkwPRXcETAWkcJHH7
qN9KrxyYD1tfvCeeg4B7bbb8Zw7ktVusPB7CQREdJaxVpbmgVedV4OjKQftT
0acPDvngl/pr7bA8B/3RuD836psP2uJSPzZIc1Bxfe02saf5UFJR1Gi9hoNU
J49GWNfng62FzKaS5Rz0j46bzfjuArD1/9quPMtGC3pjiJRQIXCzNGRnv7DR
e5kJ8QvpRXAxU1hay4eNDCOTrSU4paAXYTCSRx9FAs+1utyFy2A4Smnmd9ko
qkj+dqJ+Yxm4zj+8tq9gFO3Mlzz+wLYM3qr+fp+RNoqkmx+ZTn8ug5dnl/ft
fTSKOCs99L7mlYPCz+lr6y1GUdgjXdXkGxXQFBFyUvr7CGJrcfmfLaDBS6PX
4St6WYiv6cQcU4QGvsOLiw53spCYfeW0qAwNtouE+vk3sZC6XzAJ/I8GgisM
JEfoLORH39R9w40GlmTa5fJLFpLUti4+0UoD+4LTgnfPsJC2zvsLa1/TQfrD
sFXR92H0VC+6K8a0Cqr3fA//WDOEFn/asv/O4AeQqtRofL9lAKX8e0Ylw+0T
SLk3sl30+lDq83hZvYIGkAt7FjtztAcV6PXXOyh8ARd+jxnxjg5koOst8u1T
E0gKnjreptiM+MiTG/ZNTVA2bN3Jt6QZFcak9Q20N0F1bW32Rk4TWj/aVET6
m6Df762bU3ETmg/bcpqfrxnuLRzKeWfUhPJ7WrPX72qG1vicedrVL0jWe7uZ
a1wzXF/ZYRZ3rxExNxwsJ0nNIGmDHCSPNKJHjdYbr6Y3g9dQ3bmQNY1oRiFg
1ruwGYzOed1xft2AWj5+Swr53AwZhzf/YTbWo8A1j7g5Ai3Qu7HWPn5tHaJy
ByKm3VoAjC8vV0uvQa81xJqEr7aAn9DVv+bna9Dpyn0iMjdboCntoYPb9hpU
Xx8RqBXYApbn3SselXxAqUMHfINSWkBs5NbW4I/VyPrihbK4jBbY3BGtdju4
GolNPZ3OymuBoFX1shdMq5HvwvHLzTRe/dOWas2O9+i4bLyT9LcWOKC1nsQM
VaEVKbXJW/tbgO4ddc0howpVKU/92D/aAl4TnoeU3auQV+4/cubcFtja4HmT
vbMKqWoctnacbYGqS/f0lgpWoQF8/aknPxN6PPVZQjzH6SW3Bi5mwimWPj8f
z2b1jeJxIkw4Hen/kLuoCi22+G2StZoJuYeFAnt5rujcGFIpw4SPY59m6ni+
amf2qWk9E7BDZ3cuz0pDPov7lZlwNEZ9dwTPPy6k6/7awYRpP/Zfd55jJlv8
lmgyIW89PxjwfMSbr3KdFhN2PvAm0jwLLFSZ+1efCdXFLhKjAlWoNPC45n5j
Jli3NmcU8uy+8q6n2TEm3OT/UOzN88borHwHGybsdzRRB56/ynSOX3NggtNu
X+XfC6tQePKibYGuTNiRZRuWx7Oh8na32MtM8JZYdN6JZ75c6/TMG0xIKbhV
tppnN5yn2OTPBMZilO+0oAop6H0//TOECStuvzm1hOf2OuEXU5FM6C7f65PK
X4V0Ou0k1yUzgXVh85pmviokMymy3KGSCZzezsrJeQZqubnH8NoHJhjckBa5
wnPQAif/gAYm8N0ybxqZY6ApkQr+zK9MSP8kU9z4h4EalNymJqeZ0NxVKWA3
y0D3cqJ3LuZrhbH1OvMlMwykqc5wlxJqBYeYxvMreE7TlRqBVa2QPhn7Nv0X
A90+XfPdf3sr0IQf09MpBjJl/52VV2+F/Osz20a5DKTg9d/qUmiFwfrvr5V4
rgpPNRo91Aq2a0s/xo4z0OIP90pMzrbC8EnB7CMcBuowL28ZdmsF97w3wZfY
DPS6h0v8rrSCisQqr9BRBjKatd9YcLsVZJgDt+gsBgr9Vyt8bWwrTKlH6fwa
YCC70utZuYmtYK5/9vlsPwPtOJj98dCrVvjudlVw9idvPqfl+HwLWkHi42ph
di8DSUbMufU2tkLF1h3dL78xUPxsid4bgTYoUtXps2AykLv/uJ3O0jaYfnf1
xNoWBtovscWnW7QNYNitr6OJgXr/jckTkWuDXZk5O40/M9BGu2vyVzXa4IR9
Wp3wJwbK+rBjdu+FNhg6kLSuGjNQRcSbzIa2NvAJP7fdOJWBQuanYye/tcHx
b4m3LiUzkK2zXpD0QBt8WTu393ESA/Ht/XH2HNUGgx09gu9eMNCBvtXygqLt
ILihr+9HFANVb/cL22fYDp7tN5RMH/DybLD0zChvh2rF+FMf7RjohXqqYzOj
HSZoi25Z2TLQxSSu+WxtO/SlxssOWjPQymshqvod7WCZWtA9cZyBzGSqhvsm
2yE9L9615TADtbpus163rQOmKv0OVaoz0LfFglpBiR2wacVXL7SUgVwr7fMf
v+qAd1Jny4wXM9C0J94U+bYDIMGl+OQiBhIbvL4i4V0HPL9zl3X2Lx3pvh/p
KujoAMk/VVqGXDrKuPPl2g/RTlB4nHNUt5OOvGbjMtT9OqFE58kKsRQ6Esqd
kYPATsj07VCPTaTz/hePhWuHdkKu03M1+Rd0lNUu4nXkRSeIpha9lYmmox+F
fgcdSjvhYZFu1kAAHelfce59PNEJEsVHQ3Nc6WjV6E7JQfsuCEY2Bapb6ag8
Pc7liksX3He8nOmlREcOTovK/l7sgi2JZ9bRNtJRfm+rjaRPF+xA9JPacnRk
1nHjpUF0F8yz2X4yK+kotBpvzfjUBQfLtopuGach4cRDupd2fYVTMrl+Sdk0
NH/0zOXfi7rhHPNM3KENNJQy9iNq1fJuWDNiLHBMnoaMHp4u2ybRDWnF+res
19HQs0obAQeFbohZOJ5rI0pD/ylbRtVBN4haHti+fa4SufMdLn3u2Q1SRkIh
Mi2VqO+12oL9w91g0Z27RuJWJar5uyTsXt03KAvoCb4ZjpGC5Iln9po9EFo1
5bo2qRyZfnY+sk/+B8S03k8dFi5BS/fbJw/x90JYptMCyS0FSPbK17KLLb1Q
UhC0ulInh/c9ElPLKe4DG+dM0w3x6ejW15pLDcE/wS5su8GKqQTkpORiXH6q
H3RitnmFPghF+yXfP3bQGoAea/Pbf/0d8OWPiU+GJAYh4FnU0kUnI3CklObU
xtlBOH7r2qqFGS+xjmL5n91dQyCVkL9VqCgDHyIVVfKZw1D4d63mrEMu1j7p
Q96HssBLyFre6l4hjggq79JzHIFDl018FcRL8aVL/S4xu0fh0exmgd/wDsP0
R6vkNWwYaZVBP9dX4rPB4TNEig2Fd0Y5G5Qq8WMFm5g9smwYOtxz3mFbJe4x
GmM2rWcDGhJntmlU4ruJq035d7Bh6nOrcsyRSlxjeObgKSM2MO32rfb1rMSm
z//slLzDho9fUrvaqiuxw4Ftyx+x2KCojHYEn6ThZdV3I2U5bNj40VDU6jQN
Fxi0y+SMs8Fa/vyQgiMNC5re2do6zQZ5uwdery7QcJpts7G8EAc0PHaI3L1D
wyxvz7B8RQ7oLKQJeqTSsHsRXtNtzQHVqQG6DpuGJfdIJFw8zYHltODQkHEa
plU4b17gwAGaYtyulkkaFqsW1djkyoGarzO/zeZpOK/ljNWlGxz45KvmJitC
x1PjQs8XRXHAOKhhZmQbHd9UMVHY2sgBFz6/3Scv0LFq3uu195o4EPFf7rFv
l+h4QGORaCeTAwUF9eU2HnRsdrD07/2vHHBqm7Aw9abjLfbru7uHObBH7Vji
0iA6bouejg4WICDfxb+yLpmOH8maP+4TIrBPNV1F/BUdH0jJfKCxlEDDlM7d
Y2/oOCvX3qNflEA7vbDrSw4d36+vM9snR2A0WH1TbAUd71yYuJytQUBavDfG
s42OhwJ/C2jvI/Cs3EDIr5OOX6w89idmPwFBx8spAd10LCy7dETnIIHvOOJC
UB8d/1D3qImzIPBKQ1nxNKHjKNyIJ44TMBF9OX9ogo6N9JSK9E8ScJZatmjX
JB0Xm39PoewIXH9sGTo9S8cXOjWeGzoSQOaiEsw5Ol5vFxGR4Ezg0LRjZSYf
A3cOch5OuRJ4tI4R4beQgR9fMLhrdJHArHxUqLkgA+tMvvRKukwga+fhPPkl
DDx7c/7StAfvvCtztjyXYuDsBSdcjtwgsKc/7ruHOQOfDcw7nexNYN27pgzD
RwwsvXKF5ewtAurtzffXvWfgpihnY5O7BES0FWyH5hh4X7IM/Akk4HAw76fH
xSo8oXR9t1kwAY8V8zfUXlXhVzlNKq9CCay5n/pjoqcKS2D/dRbRBGLXKM2e
MnuPRzrGp98kE/DU/75i4e5q7CvUsmM8jcC7Kwq999yqsdjuQje1NwSUVKxO
LEiuxpqhXj2VOQT0Vt1ZPCb2AQfpLaxhVhBY8ePLnsixD1gpTyL6bzuBfzrC
g+Zef8S7qmOfpQuOQYdq4rPZdfX4SnyF+pzmGFzZKr5/89QXPPyPfeqdDF69
RVHx3cYOvFSwmrqyehxMbLOfywd9xxtL/a9qB45Di0mZlNKCPixoCLq/Z8aB
pRJxR3ykH4fvKZiSPzMB84sMHnOshrDkXGCHInMCzjkb9DW/YuEU05i4+tYJ
sJbocCnJZuEdqam2nu0TsKJIO+xpMQsfMmb013ZNwE+Ro3SDGhb2Tfwzfql3
AkLHza64DLLwT92LwpVkAkaLksqS14/gnBCLPdbCXKgp2aXGFzuCDeXlnkcg
LmTsWPB7+too1tO/xK+mxYUw/yRfK59RfMCd4dh2gAtjayNvF94dxZqVTlul
9Liw65T/rE3oKN5yOhvHG3FBfuR68rn0Ubw4Qav39QkuRB5tpd/oHMXVcg6b
aFe44LVBkjqrzsb0g4UP7T24sFdXanIVsHHFxcVjCz25sFJlqzHWZuNCnFGs
58UFgW5lYX5jNk6xnTSou82FW1w5n/2ObHwv/oFbWzCvf+dgp6xQNtaSS89h
p3HBV91pOepjY++KyqDcdC4kfH06kTTExsU27Wc833DhVGPdEj4OG6vGCa3m
f8uFNZHmH1Om2Vhu7VkviUIuOCusc41fzsFzYorae6q40HTBVtVQjYNLBJ+3
BPRwYTRlRa2HHwdTKfmZh3u5kHVhW/bcAw5W1a17IPaTC3onDZJ9H3Lwq7u/
1eMGuSDONcl1jeDgaD6r5285XIibtTOYSOFgj9nVZ1v/cKHn2dEH2R84eDsn
9JfiWgpUak1SWIsIpkKUA2qlKMgNuSVqsYTgwm3VkpekKbjq8fZ40TKCNS/9
1qiQo8Aq2eGiqzjBOpSjt+VGCrJTU0sC5Qm2nNXkD95JwWRY7JYXGgRLxTKf
7NxNAevZ/GDyXoK797grdKpRUGWqfi0FEWzvk6K9SZOChAWf/4brEuzGt/IB
bT8FLYlqRRtNCb4l2C88dZiCGAkpdQUngg+k3YqNM6Zg5W6Nt+9dCBbQl1LR
NuXtZwtsezeCAwKND4daUBBaMVwWdIngsGWlj5VOUkD/Jyzy8U2CU8UeS9g6
UxBBT6o7H0Kwc96WlEXnKCg5ln0tM5RgZYuq3RmuFNz5yfk+EEZwduTMsZkL
FGRRezl60QSXSjo8Dfeg4NEDCU5ZPMH1shqyNX4U6Lndlr3xluD1Ih+a4+9R
YGb1yvVhDsHefy0CPR9Q0Cj2sz8yj2CVHndqYxAF3gMRtuFFBAclvqq9/4SC
I06aVqqY4N4nardtwimQvWK6QIDGm7df1e7dkRSUPXnd3EgneNi+J+FnDAUH
Rk6NGVcTrL9e0lM7gQLr/O+LJuoITpBIVVmXRIGv+5LRBw0ETwvs6p14ScG8
rdy0+GeC0/qNDyelUWBUEnh7dTPBgmn+ivxvKehcJqX/rp3gU9GrOtqzKagI
OmEu3snL3/9lSHYuBedc3tyx6yLY0RnP2BZSULsP9Aa6Ca7a8qux4h1v/6yI
s096CZaWun8/ClNQuKThzqs+gq8Ki++5QKMgRKX8XdFPghVHtqbKvKeAGsyI
qhgg2Kur/ORkNQXSrtt2Fg4S3PTJULS+hoLqh2dJyhDBfhlnvb3reO9Ht1D1
eRbBnXHUdosGCuz8+Xt0RwjeEew3qPyZgp+4QXL1KME/zr8w62rm5b9TcuAF
m2D1UyqL85i8/q7t9DrOITj0SOm7oDYKGk6cVllMCN6/rXWzZhcF7h4HWKZj
BMfIOXwT7aag+GDqJIvnMZGJ8OFvvPmOXpf1HufNm++2Aa2HgrrgKIdFEwTH
jy3/G9PL61e/+8MDnqd6YvPdf1JwUeVffT4uwUe+bDmnP0CBsaZz/yWe53N0
mb+GKZCM3n5tH0XwsaTmoMYRCixTgl2iec4Ks9ufxqYgzNr9xjDPgnfJpC/h
5eH1PmXnJME2V3zeHBvn3b9sL44Hz/lnltpt5VLgk3DLPJvnZRZPVwtOUvC5
531LL88OOpvquqcoeDKz//LyKYLLdxXcKZimINlxQFmV5/8B02GMEg==
       "]]},
     Annotation[#, "Charting`Private`Tag$1500#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Helvetica", FontSize -> 14],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.00002}, {-0.9988022668286942, 0.9999999999999938}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.456509572000661*^9, 3.456509653636228*^9, 3.456509899944787*^9, {
   3.456545656336225*^9, 3.456545667486722*^9}, 3.4565466234500847`*^9, 
   3.456570783589847*^9, 3.456570837050729*^9, 3.458994532350522*^9, 
   3.459442723564172*^9, 3.4610665372926807`*^9, 3.4613298034579077`*^9, 
   3.46200594275671*^9, 3.464025084171768*^9, 3.464803447935872*^9, 
   3.465814125726612*^9, 3.467015925309105*^9, {3.486708059353109*^9, 
   3.486708068097351*^9}, 3.486708121976638*^9, 3.486709666822544*^9, 
   3.486711408361988*^9, 3.486719489042938*^9, 3.4961387414722443`*^9, 
   3.496138857670226*^9, 3.4975182493307877`*^9, 3.497528387516385*^9, {
   3.497528456253882*^9, 3.497528468034212*^9}, 3.49753030904547*^9, 
   3.497569371613937*^9, 3.4975742538173113`*^9, 3.497648482554346*^9, 
   3.499304086008762*^9, 3.502011170103105*^9, 3.502710928450521*^9, 
   3.502761284719982*^9, 3.503307133448838*^9, 3.5070246371508417`*^9, 
   3.507025772328562*^9, 3.50702831628342*^9, 3.510318332854189*^9, 
   3.510318374479053*^9, 3.510318413814787*^9, {3.5103186157428007`*^9, 
   3.510318631090716*^9}, {3.511623912015904*^9, 3.511623919420492*^9}, 
   3.513162387871004*^9, 3.51506849007654*^9, 3.515069498846057*^9, 
   3.5331777055328417`*^9, 3.5689041946422997`*^9, 3.571380124437537*^9, {
   3.571380164498754*^9, 3.571380179701673*^9}, 3.5713802315512*^9, 
   3.571380269752509*^9, {3.571380334846759*^9, 3.571380428675847*^9}, 
   3.571380482579782*^9, 3.703853700069949*^9, 3.703853855769899*^9, 
   3.7038539274466076`*^9, 3.7038563761312513`*^9, 3.703856750623946*^9, 
   3.7039207247555847`*^9, 3.7121510418706336`*^9, 3.72863417371208*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Iztraj", "[", 
    RowBox[{"t\[Mu]s", "\[Times]", 
     RowBox[{"10", "^", 
      RowBox[{"-", "6"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t\[Mu]s", ",", "0", ",", 
     RowBox[{"TotalDuration", "\[Times]", 
      RowBox[{"10", "^", "6"}]}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Medium", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], ",", 
   
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Mu]s\>\"", ",", "\"\<amplitude\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.45650956890828*^9, 3.456509571083004*^9}, {
   3.4565099019330606`*^9, 3.4565099070840673`*^9}, {3.456545660832933*^9, 
   3.4565456665182953`*^9}, {3.486708063467409*^9, 3.4867080670420017`*^9}, 
   3.486708120749165*^9, {3.510318426041108*^9, 3.5103184638588457`*^9}, {
   3.5103185596245832`*^9, 3.5103185599644403`*^9}, {3.571380201787774*^9, 
   3.571380203037525*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1mk4VV8XAHBDFErhkpkyVLjCKaFhL5WKNKJB5ggVSVGJSKVShJBSiVBJ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       "]]},
     Annotation[#, "Charting`Private`Tag$1602#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"amplitude\"", TraditionalForm], None}, {
     FormBox["\"\[Mu]s\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 20.}, {-0.9988022668286942, 0.9999999999999938}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.456509572000661*^9, 3.456509653636228*^9, 3.456509899944787*^9, {
   3.456545656336225*^9, 3.456545667486722*^9}, 3.4565466234500847`*^9, 
   3.456570783589847*^9, 3.456570837050729*^9, 3.458994532350522*^9, 
   3.459442723564172*^9, 3.4610665372926807`*^9, 3.4613298034579077`*^9, 
   3.46200594275671*^9, 3.464025084171768*^9, 3.464803447935872*^9, 
   3.465814125726612*^9, 3.467015925309105*^9, {3.486708059353109*^9, 
   3.486708068097351*^9}, 3.486708121976638*^9, 3.486709666822544*^9, 
   3.486711408361988*^9, 3.486719489042938*^9, 3.4961387414722443`*^9, 
   3.496138857670226*^9, 3.4975182493307877`*^9, 3.497528387516385*^9, {
   3.497528456253882*^9, 3.497528468034212*^9}, 3.49753030904547*^9, 
   3.497569371613937*^9, 3.4975742538173113`*^9, 3.497648482554346*^9, 
   3.499304086008762*^9, 3.502011170103105*^9, 3.502710928450521*^9, 
   3.502761284719982*^9, 3.503307133448838*^9, 3.5070246371508417`*^9, 
   3.507025772328562*^9, 3.50702831628342*^9, 3.510318332854189*^9, 
   3.510318374479053*^9, 3.510318413814787*^9, {3.510318444425517*^9, 
   3.510318464799139*^9}, 3.510318561037787*^9, 3.510318631229587*^9, 
   3.5116239195003138`*^9, 3.5131623879665537`*^9, 3.515068490204129*^9, 
   3.515069498899054*^9, 3.533177705618383*^9, 3.5689041996515865`*^9, {
   3.571380203881847*^9, 3.5713802337692347`*^9}, 3.571380486821968*^9, 
   3.703853700145668*^9, 3.7038538559804935`*^9, 3.7038539274954414`*^9, 
   3.7038563761952133`*^9, 3.703856750689378*^9, 3.703920724802804*^9, 
   3.712151041948703*^9, 3.728634173771576*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
on-resonance trajectory of {x,y,z}-magnetization, starting from z\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707871584403*^9}, {
  3.486707939722651*^9, 3.486707945208267*^9}, {3.486708008593843*^9, 
  3.4867080096800623`*^9}, {3.4867081353531647`*^9, 3.486708140856287*^9}, {
  3.486708450441025*^9, 3.4867084673602533`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"Ixtraj", ",", "Iytraj", ",", "Iztraj"}], "}"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{"Trajectory", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}], ",", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}], ",", 
       RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", "CompositePulse"}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4565095226613693`*^9, 3.456509562395952*^9}, {
  3.486708014261339*^9, 3.48670803633846*^9}, {3.486708147684558*^9, 
  3.4867081730827513`*^9}, {3.497528477101227*^9, 3.4975284912349777`*^9}, {
  3.510318471946803*^9, 3.510318484547085*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"20.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-6\"\>"]}],
          0.00002,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"20.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-6\"\>"]}],
          0.00002,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"20.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-6\"\>"]}],
          0.00002,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456509549294127*^9, 3.45650956323951*^9}, 
   3.456509647542842*^9, 3.4565098974113092`*^9, 3.456545656175568*^9, 
   3.456546623398144*^9, {3.456570783390377*^9, 3.456570796273484*^9}, 
   3.456570832703512*^9, 3.458994532296883*^9, 3.459442723512301*^9, 
   3.461066537245344*^9, 3.4613298032665*^9, {3.4620059345073957`*^9, 
   3.4620059394326477`*^9}, 3.4640250841192636`*^9, 3.464803447884685*^9, 
   3.465814125692009*^9, 3.467015925147357*^9, {3.486707964429309*^9, 
   3.4867079728747177`*^9}, 3.4867080041836433`*^9, 3.486708037345064*^9, 
   3.486708175165627*^9, 3.4867096668688602`*^9, 3.4867114084295797`*^9, 
   3.486719489128416*^9, 3.496138749053214*^9, 3.496138857728897*^9, 
   3.497518254976068*^9, 3.497528387635714*^9, 3.497528492038886*^9, 
   3.497530309104681*^9, 3.497569384488237*^9, 3.497574253870129*^9, 
   3.4976484826488447`*^9, 3.499304086106929*^9, 3.502011170165524*^9, 
   3.5027109284867077`*^9, 3.502761284786407*^9, 3.503307133492279*^9, 
   3.507024637398253*^9, 3.5070257728306017`*^9, 3.507028316345167*^9, 
   3.510318332945695*^9, 3.5103183745204277`*^9, 3.510318485449053*^9, 
   3.510318580328273*^9, 3.510318635739406*^9, 3.511623924780037*^9, 
   3.5131623880311823`*^9, 3.5150684902722797`*^9, 3.515069498938006*^9, 
   3.533177705702216*^9, 3.568904204714876*^9, 3.571380493464781*^9, 
   3.703853700294832*^9, 3.703853859760336*^9, 3.703853927642429*^9, 
   3.70385637632533*^9, 3.703856750802945*^9, 3.7039207249625854`*^9, 
   3.712151042186392*^9, 3.728634173912034*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ixtraj", "[", 
      RowBox[{"t\[Mu]s", "\[Times]", 
       RowBox[{"10", "^", 
        RowBox[{"-", "6"}]}]}], "]"}], ",", 
     RowBox[{"Iytraj", "[", 
      RowBox[{"t\[Mu]s", "\[Times]", 
       RowBox[{"10", "^", 
        RowBox[{"-", "6"}]}]}], "]"}], ",", 
     RowBox[{"Iztraj", "[", 
      RowBox[{"t\[Mu]s", "\[Times]", 
       RowBox[{"10", "^", 
        RowBox[{"-", "6"}]}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t\[Mu]s", ",", "0", ",", 
     RowBox[{"TotalDuration", "\[Times]", 
      RowBox[{"10", "^", "6"}]}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Green"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Medium", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Mu]s\>\"", ",", "\"\<amplitude\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.45650956890828*^9, 3.456509571083004*^9}, {
   3.4565099019330606`*^9, 3.4565099070840673`*^9}, {3.456545660832933*^9, 
   3.4565456665182953`*^9}, {3.486708063467409*^9, 3.4867080670420017`*^9}, 
   3.486708120749165*^9, {3.486708180925454*^9, 3.486708191714155*^9}, 
   3.486708226238326*^9, {3.510318491918379*^9, 3.510318548033098*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJxFlXk41fkXx2XNfheZqOEWIsv3Xu7UpDLntFuKSlRipm5cEorc35Qlsgwq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       "]]},
     Annotation[#, "Charting`Private`Tag$2320#1"]& ], 
    TagBox[
     {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJxF1nc4lWEbAHA7aUlHS3E45z1HnGMkDRW30lAUSSQlZFR2S8goEjKzQiHK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       "]]},
     Annotation[#, "Charting`Private`Tag$2320#2"]& ], 
    TagBox[
     {RGBColor[0, 1, 0], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1mk4VV8XAHBDFErhkpkyVLjCKaFhL5WKNKJB5ggVSVGJSKVShJBSiVBJ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       "]]},
     Annotation[#, "Charting`Private`Tag$2320#3"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"amplitude\"", TraditionalForm], None}, {
     FormBox["\"\[Mu]s\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 20.}, {-0.9988022668286942, 0.9999999999999938}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.456509572000661*^9, 3.456509653636228*^9, 3.456509899944787*^9, {
   3.456545656336225*^9, 3.456545667486722*^9}, 3.4565466234500847`*^9, 
   3.456570783589847*^9, 3.456570837050729*^9, 3.458994532350522*^9, 
   3.459442723564172*^9, 3.4610665372926807`*^9, 3.4613298034579077`*^9, 
   3.46200594275671*^9, 3.464025084171768*^9, 3.464803447935872*^9, 
   3.465814125726612*^9, 3.467015925309105*^9, {3.486708059353109*^9, 
   3.486708068097351*^9}, 3.486708121976638*^9, 3.4867081924220343`*^9, 
   3.486708227184865*^9, 3.48670966694198*^9, 3.486711408520846*^9, 
   3.4867194892316504`*^9, 3.4961387492163477`*^9, 3.496138857912655*^9, 
   3.4975182552059097`*^9, 3.4975283877388153`*^9, 3.49752849495741*^9, 
   3.497530309176661*^9, 3.497569384685874*^9, 3.497574253939742*^9, 
   3.4976484827744703`*^9, 3.499304086223187*^9, 3.5020111702835827`*^9, 
   3.502710928566328*^9, 3.502761284979458*^9, 3.503307133572269*^9, 
   3.507024637820898*^9, 3.507025778777791*^9, 3.507028316606247*^9, 
   3.510318333204981*^9, 3.510318374591288*^9, 3.510318509978633*^9, 
   3.510318548887705*^9, 3.5103185805021143`*^9, 3.510318635909956*^9, 
   3.511623924955579*^9, 3.513162388173024*^9, 3.5150684904442472`*^9, 
   3.5150694990197687`*^9, 3.533177705826639*^9, 3.5689042099381742`*^9, 
   3.571380495267424*^9, 3.7038537003529153`*^9, 3.703853859858596*^9, 
   3.7038539277005944`*^9, 3.7038563763722143`*^9, 3.7038567508712225`*^9, 
   3.7039207250207376`*^9, 3.7121510422719364`*^9, 3.7286341739838204`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Opacity", "[", "0.1", "]"}], ",", 
       RowBox[{"EdgeForm", "[", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"Cos", "[", "#", "]"}], ",", 
            RowBox[{"Sin", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "100"}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "#", "]"}], ",", 
            RowBox[{"Sin", "[", "#", "]"}], ",", "0"}], "}"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "100"}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "#", "]"}], ",", "0", ",", 
            RowBox[{"Sin", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "100"}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ParametricPlot3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Re", "@", 
       RowBox[{"Through", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Ixtraj", ",", "Iytraj", ",", "Iztraj"}], "}"}], "[", "t", 
         "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "TotalDuration"}], "}"}], ",", 
      RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Axes3D", "[", "]"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ViewVertical", "\[Rule]", "ez"}]}], "\[IndentingNewLine]", "]"}],
   "\[IndentingNewLine]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456510853408382*^9, 3.4565109643318768`*^9}, 
   3.456545885234786*^9, {3.456545930266377*^9, 3.456546035352107*^9}, {
   3.456546468726475*^9, 3.456546469396908*^9}, {3.456546543591886*^9, 
   3.456546549343329*^9}, {3.456546664497095*^9, 3.456546667679903*^9}, {
   3.486708337033456*^9, 3.486708407853148*^9}, {3.511624048477488*^9, 
   3.511624151244787*^9}, {3.511624194166769*^9, 3.511624465192794*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {Opacity[0.1], EdgeForm[None], 
    Polygon3DBox[
     NCache[{{0, 1, 0}, {
       0, Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi]}, {
       0, Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi]}, {
       0, Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi]}, {
       0, Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi]}, {
       0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       0, Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi]}, {
       0, Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi]}, {
       0, Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi]}, {
       0, Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi]}, {
       0, Rational[1, 4] (1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi]}, {
       0, Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi]}, {
       0, Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi]}, {
       0, Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi]}, {
       0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       0, Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi]}, {
       0, Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi]}, {
       0, Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi]}, {
       0, Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi]}, {
       0, Rational[1, 4] (-1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi]}, {
       0, Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi]}, {
       0, Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi]}, {
       0, Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi]}, {0, 0, 1}, {
       0, -Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi]}, {
       0, -Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi]}, {
       0, -Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi]}, {
       0, -Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi]}, {
       0, 
        Rational[1, 4] (1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi]}, {
       0, -Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi]}, {
       0, -Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi]}, {
       0, -Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi]}, {
       0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2],
         Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       0, -Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi]}, {
       0, -Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi]}, {
       0, -Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi]}, {
       0, -Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi]}, {
       0, Rational[1, 4] (-1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi]}, {
       0, -Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi]}, {
       0, -Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi]}, {
       0, -Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi]}, {
       0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       0, -Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi]}, {
       0, -Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi]}, {
       0, -Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi]}, {
       0, -Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi]}, {0, -1, 0}, {
       0, -Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi]}, {
       0, -Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi]}, {
       0, -Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi]}, {
       0, -Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi]}, {
       0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       0, -Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi]}, {
       0, -Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi]}, {
       0, -Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi]}, {
       0, -Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi]}, {
       0, Rational[1, 4] (-1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi]}, {
       0, -Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi]}, {
       0, -Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi]}, {
       0, -Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi]}, {
       0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2],
         Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       0, -Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi]}, {
       0, -Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi]}, {
       0, -Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi]}, {
       0, -Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi]}, {
       0, Rational[1, 4] (1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       0, -Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi]}, {
       0, -Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi]}, {
       0, -Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi]}, {
       0, -Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi]}, {0, 0, -1}, {
       0, Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi]}, {
       0, Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi]}, {
       0, Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi]}, {
       0, Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi]}, {
       0, Rational[1, 4] (-1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi]}, {
       0, Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi]}, {
       0, Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi]}, {
       0, Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi]}, {
       0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       0, Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi]}, {
       0, Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi]}, {
       0, Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi]}, {
       0, Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi]}, {
       0, Rational[1, 4] (1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi]}, {
       0, Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi]}, {
       0, Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi]}, {
       0, Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi]}, {
       0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       0, Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi]}, {
       0, Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi]}, {
       0, Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi]}, {
       0, Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi]}, {0, 1, 0}}, {{0,
        1, 0}, {0, 0.9980267284282716, 0.06279051952931337}, {
       0, 0.9921147013144779, 0.12533323356430426`}, {
       0, 0.9822872507286887, 0.1873813145857246}, {
       0, 0.9685831611286311, 0.2486898871648548}, {
       0, 0.9510565162951535, 0.30901699437494745`}, {
       0, 0.9297764858882515, 0.3681245526846779}, {
       0, 0.9048270524660195, 0.4257792915650727}, {
       0, 0.8763066800438636, 0.4817536741017153}, {
       0, 0.8443279255020151, 0.5358267949789967}, {
       0, 0.8090169943749475, 0.5877852522924731}, {
       0, 0.7705132427757893, 0.6374239897486896}, {
       0, 0.7289686274214116, 0.6845471059286886}, {
       0, 0.6845471059286886, 0.7289686274214116}, {
       0, 0.6374239897486896, 0.7705132427757893}, {
       0, 0.5877852522924731, 0.8090169943749475}, {
       0, 0.5358267949789967, 0.8443279255020151}, {
       0, 0.4817536741017153, 0.8763066800438636}, {
       0, 0.4257792915650727, 0.9048270524660195}, {
       0, 0.3681245526846779, 0.9297764858882515}, {
       0, 0.30901699437494745`, 0.9510565162951535}, {
       0, 0.2486898871648548, 0.9685831611286311}, {
       0, 0.1873813145857246, 0.9822872507286887}, {
       0, 0.12533323356430426`, 0.9921147013144779}, {
       0, 0.06279051952931337, 0.9980267284282716}, {0, 0, 1}, {
       0, -0.06279051952931337, 0.9980267284282716}, {
       0, -0.12533323356430426`, 0.9921147013144779}, {
       0, -0.1873813145857246, 0.9822872507286887}, {
       0, -0.2486898871648548, 0.9685831611286311}, {
       0, -0.30901699437494745`, 0.9510565162951535}, {
       0, -0.3681245526846779, 0.9297764858882515}, {
       0, -0.4257792915650727, 0.9048270524660195}, {
       0, -0.4817536741017153, 0.8763066800438636}, {
       0, -0.5358267949789967, 0.8443279255020151}, {
       0, -0.5877852522924731, 0.8090169943749475}, {
       0, -0.6374239897486896, 0.7705132427757893}, {
       0, -0.6845471059286886, 0.7289686274214116}, {
       0, -0.7289686274214116, 0.6845471059286886}, {
       0, -0.7705132427757893, 0.6374239897486896}, {
       0, -0.8090169943749475, 0.5877852522924731}, {
       0, -0.8443279255020151, 0.5358267949789967}, {
       0, -0.8763066800438636, 0.4817536741017153}, {
       0, -0.9048270524660195, 0.4257792915650727}, {
       0, -0.9297764858882515, 0.3681245526846779}, {
       0, -0.9510565162951535, 0.30901699437494745`}, {
       0, -0.9685831611286311, 0.2486898871648548}, {
       0, -0.9822872507286887, 0.1873813145857246}, {
       0, -0.9921147013144779, 0.12533323356430426`}, {
       0, -0.9980267284282716, 0.06279051952931337}, {0, -1, 0}, {
       0, -0.9980267284282716, -0.06279051952931337}, {
       0, -0.9921147013144779, -0.12533323356430426`}, {
       0, -0.9822872507286887, -0.1873813145857246}, {
       0, -0.9685831611286311, -0.2486898871648548}, {
       0, -0.9510565162951535, -0.30901699437494745`}, {
       0, -0.9297764858882515, -0.3681245526846779}, {
       0, -0.9048270524660195, -0.4257792915650727}, {
       0, -0.8763066800438636, -0.4817536741017153}, {
       0, -0.8443279255020151, -0.5358267949789967}, {
       0, -0.8090169943749475, -0.5877852522924731}, {
       0, -0.7705132427757893, -0.6374239897486896}, {
       0, -0.7289686274214116, -0.6845471059286886}, {
       0, -0.6845471059286886, -0.7289686274214116}, {
       0, -0.6374239897486896, -0.7705132427757893}, {
       0, -0.5877852522924731, -0.8090169943749475}, {
       0, -0.5358267949789967, -0.8443279255020151}, {
       0, -0.4817536741017153, -0.8763066800438636}, {
       0, -0.4257792915650727, -0.9048270524660195}, {
       0, -0.3681245526846779, -0.9297764858882515}, {
       0, -0.30901699437494745`, -0.9510565162951535}, {
       0, -0.2486898871648548, -0.9685831611286311}, {
       0, -0.1873813145857246, -0.9822872507286887}, {
       0, -0.12533323356430426`, -0.9921147013144779}, {
       0, -0.06279051952931337, -0.9980267284282716}, {0, 0, -1}, {
       0, 0.06279051952931337, -0.9980267284282716}, {
       0, 0.12533323356430426`, -0.9921147013144779}, {
       0, 0.1873813145857246, -0.9822872507286887}, {
       0, 0.2486898871648548, -0.9685831611286311}, {
       0, 0.30901699437494745`, -0.9510565162951535}, {
       0, 0.3681245526846779, -0.9297764858882515}, {
       0, 0.4257792915650727, -0.9048270524660195}, {
       0, 0.4817536741017153, -0.8763066800438636}, {
       0, 0.5358267949789967, -0.8443279255020151}, {
       0, 0.5877852522924731, -0.8090169943749475}, {
       0, 0.6374239897486896, -0.7705132427757893}, {
       0, 0.6845471059286886, -0.7289686274214116}, {
       0, 0.7289686274214116, -0.6845471059286886}, {
       0, 0.7705132427757893, -0.6374239897486896}, {
       0, 0.8090169943749475, -0.5877852522924731}, {
       0, 0.8443279255020151, -0.5358267949789967}, {
       0, 0.8763066800438636, -0.4817536741017153}, {
       0, 0.9048270524660195, -0.4257792915650727}, {
       0, 0.9297764858882515, -0.3681245526846779}, {
       0, 0.9510565162951535, -0.30901699437494745`}, {
       0, 0.9685831611286311, -0.2486898871648548}, {
       0, 0.9822872507286887, -0.1873813145857246}, {
       0, 0.9921147013144779, -0.12533323356430426`}, {
       0, 0.9980267284282716, -0.06279051952931337}, {0, 1, 0}}]], 
    Polygon3DBox[
     NCache[{{1, 0, 0}, {
       Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi], 0}, {
       Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi], 0}, {
       Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi], 0}, {
       Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi], 
        0}, {(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {
       Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi], 0}, {
       Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi], 0}, {
       Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi], 0}, {
       Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi], 0}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi], 0}, {
       Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi], 0}, {
       Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi], 0}, {
       Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi], 
        0}, {(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {
       Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi], 0}, {
       Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi], 0}, {
       Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi], 0}, {
       Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi], 0}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi], 0}, {
       Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi], 0}, {
       Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi], 0}, {
       Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi], 0}, {0, 1, 
       0}, {-Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi], 0}, {-
        Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi], 0}, {-
        Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi], 0}, {-
        Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi], 0}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi], 0}, {-
        Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi], 0}, {-
        Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi], 0}, {-
        Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi], 
        0}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {-
        Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi], 0}, {-
        Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi], 0}, {-
        Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi], 0}, {-
        Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi], 0}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi], 0}, {-
        Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi], 0}, {-
        Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi], 0}, {-
        Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi], 
        0}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {-
        Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi], 0}, {-
        Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi], 0}, {-
        Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi], 0}, {-
        Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi], 0}, {-1, 0, 
       0}, {-Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi], 0}, {-
        Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi], 0}, {-
        Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi], 0}, {-
        Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi], 
        0}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {-
        Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi], 0}, {-
        Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi], 0}, {-
        Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi], 0}, {-
        Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi], 0}, {
       Rational[1, 4] (-1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi], 0}, {-
        Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi], 0}, {-
        Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi], 0}, {-
        Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi], 
        0}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {-
        Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi], 0}, {-
        Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi], 0}, {-
        Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi], 0}, {-
        Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi], 0}, {
       Rational[1, 4] (1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0}, {-Sin[Rational[2, 25] Pi], -
        Cos[Rational[2, 25] Pi], 0}, {-Sin[Rational[3, 50] Pi], -
        Cos[Rational[3, 50] Pi], 0}, {-Sin[Rational[1, 25] Pi], -
        Cos[Rational[1, 25] Pi], 0}, {-Sin[Rational[1, 50] Pi], -
        Cos[Rational[1, 50] Pi], 0}, {0, -1, 0}, {
       Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi], 0}, {
       Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi], 0}, {
       Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi], 0}, {
       Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi], 0}, {
       Rational[1, 4] (-1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi], 0}, {
       Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi], 0}, {
       Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi], 0}, {
       Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi], 
        0}, {(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {
       Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi], 0}, {
       Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi], 0}, {
       Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi], 0}, {
       Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi], 0}, {
       Rational[1, 4] (1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi], 0}, {
       Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi], 0}, {
       Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi], 0}, {
       Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi], 
        0}, {(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {
       Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi], 0}, {
       Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi], 0}, {
       Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi], 0}, {
       Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi], 0}, {1, 0, 0}}, {{1,
        0, 0}, {0.9980267284282716, 0.06279051952931337, 0}, {
       0.9921147013144779, 0.12533323356430426`, 0}, {
       0.9822872507286887, 0.1873813145857246, 0}, {
       0.9685831611286311, 0.2486898871648548, 0}, {
       0.9510565162951535, 0.30901699437494745`, 0}, {
       0.9297764858882515, 0.3681245526846779, 0}, {
       0.9048270524660195, 0.4257792915650727, 0}, {
       0.8763066800438636, 0.4817536741017153, 0}, {
       0.8443279255020151, 0.5358267949789967, 0}, {
       0.8090169943749475, 0.5877852522924731, 0}, {
       0.7705132427757893, 0.6374239897486896, 0}, {
       0.7289686274214116, 0.6845471059286886, 0}, {
       0.6845471059286886, 0.7289686274214116, 0}, {
       0.6374239897486896, 0.7705132427757893, 0}, {
       0.5877852522924731, 0.8090169943749475, 0}, {
       0.5358267949789967, 0.8443279255020151, 0}, {
       0.4817536741017153, 0.8763066800438636, 0}, {
       0.4257792915650727, 0.9048270524660195, 0}, {
       0.3681245526846779, 0.9297764858882515, 0}, {
       0.30901699437494745`, 0.9510565162951535, 0}, {
       0.2486898871648548, 0.9685831611286311, 0}, {
       0.1873813145857246, 0.9822872507286887, 0}, {
       0.12533323356430426`, 0.9921147013144779, 0}, {
       0.06279051952931337, 0.9980267284282716, 0}, {0, 1, 
       0}, {-0.06279051952931337, 0.9980267284282716, 
        0}, {-0.12533323356430426`, 0.9921147013144779, 
        0}, {-0.1873813145857246, 0.9822872507286887, 
        0}, {-0.2486898871648548, 0.9685831611286311, 
        0}, {-0.30901699437494745`, 0.9510565162951535, 
        0}, {-0.3681245526846779, 0.9297764858882515, 
        0}, {-0.4257792915650727, 0.9048270524660195, 
        0}, {-0.4817536741017153, 0.8763066800438636, 
        0}, {-0.5358267949789967, 0.8443279255020151, 
        0}, {-0.5877852522924731, 0.8090169943749475, 
        0}, {-0.6374239897486896, 0.7705132427757893, 
        0}, {-0.6845471059286886, 0.7289686274214116, 
        0}, {-0.7289686274214116, 0.6845471059286886, 
        0}, {-0.7705132427757893, 0.6374239897486896, 
        0}, {-0.8090169943749475, 0.5877852522924731, 
        0}, {-0.8443279255020151, 0.5358267949789967, 
        0}, {-0.8763066800438636, 0.4817536741017153, 
        0}, {-0.9048270524660195, 0.4257792915650727, 
        0}, {-0.9297764858882515, 0.3681245526846779, 
        0}, {-0.9510565162951535, 0.30901699437494745`, 
        0}, {-0.9685831611286311, 0.2486898871648548, 
        0}, {-0.9822872507286887, 0.1873813145857246, 
        0}, {-0.9921147013144779, 0.12533323356430426`, 
        0}, {-0.9980267284282716, 0.06279051952931337, 0}, {-1, 0, 
       0}, {-0.9980267284282716, -0.06279051952931337, 
        0}, {-0.9921147013144779, -0.12533323356430426`, 
        0}, {-0.9822872507286887, -0.1873813145857246, 
        0}, {-0.9685831611286311, -0.2486898871648548, 
        0}, {-0.9510565162951535, -0.30901699437494745`, 
        0}, {-0.9297764858882515, -0.3681245526846779, 
        0}, {-0.9048270524660195, -0.4257792915650727, 
        0}, {-0.8763066800438636, -0.4817536741017153, 
        0}, {-0.8443279255020151, -0.5358267949789967, 
        0}, {-0.8090169943749475, -0.5877852522924731, 
        0}, {-0.7705132427757893, -0.6374239897486896, 
        0}, {-0.7289686274214116, -0.6845471059286886, 
        0}, {-0.6845471059286886, -0.7289686274214116, 
        0}, {-0.6374239897486896, -0.7705132427757893, 
        0}, {-0.5877852522924731, -0.8090169943749475, 
        0}, {-0.5358267949789967, -0.8443279255020151, 
        0}, {-0.4817536741017153, -0.8763066800438636, 
        0}, {-0.4257792915650727, -0.9048270524660195, 
        0}, {-0.3681245526846779, -0.9297764858882515, 
        0}, {-0.30901699437494745`, -0.9510565162951535, 
        0}, {-0.2486898871648548, -0.9685831611286311, 
        0}, {-0.1873813145857246, -0.9822872507286887, 
        0}, {-0.12533323356430426`, -0.9921147013144779, 
        0}, {-0.06279051952931337, -0.9980267284282716, 0}, {0, -1, 0}, {
       0.06279051952931337, -0.9980267284282716, 0}, {
       0.12533323356430426`, -0.9921147013144779, 0}, {
       0.1873813145857246, -0.9822872507286887, 0}, {
       0.2486898871648548, -0.9685831611286311, 0}, {
       0.30901699437494745`, -0.9510565162951535, 0}, {
       0.3681245526846779, -0.9297764858882515, 0}, {
       0.4257792915650727, -0.9048270524660195, 0}, {
       0.4817536741017153, -0.8763066800438636, 0}, {
       0.5358267949789967, -0.8443279255020151, 0}, {
       0.5877852522924731, -0.8090169943749475, 0}, {
       0.6374239897486896, -0.7705132427757893, 0}, {
       0.6845471059286886, -0.7289686274214116, 0}, {
       0.7289686274214116, -0.6845471059286886, 0}, {
       0.7705132427757893, -0.6374239897486896, 0}, {
       0.8090169943749475, -0.5877852522924731, 0}, {
       0.8443279255020151, -0.5358267949789967, 0}, {
       0.8763066800438636, -0.4817536741017153, 0}, {
       0.9048270524660195, -0.4257792915650727, 0}, {
       0.9297764858882515, -0.3681245526846779, 0}, {
       0.9510565162951535, -0.30901699437494745`, 0}, {
       0.9685831611286311, -0.2486898871648548, 0}, {
       0.9822872507286887, -0.1873813145857246, 0}, {
       0.9921147013144779, -0.12533323356430426`, 0}, {
       0.9980267284282716, -0.06279051952931337, 0}, {1, 0, 0}}]], 
    Polygon3DBox[
     NCache[{{1, 0, 0}, {
       Cos[Rational[1, 50] Pi], 0, Sin[Rational[1, 50] Pi]}, {
       Cos[Rational[1, 25] Pi], 0, Sin[Rational[1, 25] Pi]}, {
       Cos[Rational[3, 50] Pi], 0, Sin[Rational[3, 50] Pi]}, {
       Cos[Rational[2, 25] Pi], 0, Sin[
        Rational[2, 25] Pi]}, {(Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       Cos[Rational[3, 25] Pi], 0, Sin[Rational[3, 25] Pi]}, {
       Cos[Rational[7, 50] Pi], 0, Sin[Rational[7, 50] Pi]}, {
       Cos[Rational[4, 25] Pi], 0, Sin[Rational[4, 25] Pi]}, {
       Cos[Rational[9, 50] Pi], 0, Sin[Rational[9, 50] Pi]}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {
       Cos[Rational[11, 50] Pi], 0, Sin[Rational[11, 50] Pi]}, {
       Cos[Rational[6, 25] Pi], 0, Sin[Rational[6, 25] Pi]}, {
       Sin[Rational[6, 25] Pi], 0, Cos[Rational[6, 25] Pi]}, {
       Sin[Rational[11, 50] Pi], 0, Cos[
        Rational[11, 50] Pi]}, {(Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       Sin[Rational[9, 50] Pi], 0, Cos[Rational[9, 50] Pi]}, {
       Sin[Rational[4, 25] Pi], 0, Cos[Rational[4, 25] Pi]}, {
       Sin[Rational[7, 50] Pi], 0, Cos[Rational[7, 50] Pi]}, {
       Sin[Rational[3, 25] Pi], 0, Cos[Rational[3, 25] Pi]}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {
       Sin[Rational[2, 25] Pi], 0, Cos[Rational[2, 25] Pi]}, {
       Sin[Rational[3, 50] Pi], 0, Cos[Rational[3, 50] Pi]}, {
       Sin[Rational[1, 25] Pi], 0, Cos[Rational[1, 25] Pi]}, {
       Sin[Rational[1, 50] Pi], 0, Cos[Rational[1, 50] Pi]}, {0, 0, 
       1}, {-Sin[Rational[1, 50] Pi], 0, Cos[Rational[1, 50] Pi]}, {-
        Sin[Rational[1, 25] Pi], 0, Cos[Rational[1, 25] Pi]}, {-
        Sin[Rational[3, 50] Pi], 0, Cos[Rational[3, 50] Pi]}, {-
        Sin[Rational[2, 25] Pi], 0, Cos[Rational[2, 25] Pi]}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {-Sin[Rational[3, 25] Pi], 0, Cos[
        Rational[3, 25] Pi]}, {-Sin[Rational[7, 50] Pi], 0, Cos[
        Rational[7, 50] Pi]}, {-Sin[Rational[4, 25] Pi], 0, Cos[
        Rational[4, 25] Pi]}, {-Sin[Rational[9, 50] Pi], 0, Cos[
        Rational[9, 50] 
         Pi]}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0, Rational[1, 4] (1 + 5^Rational[1, 2])}, {-
        Sin[Rational[11, 50] Pi], 0, Cos[Rational[11, 50] Pi]}, {-
        Sin[Rational[6, 25] Pi], 0, Cos[Rational[6, 25] Pi]}, {-
        Cos[Rational[6, 25] Pi], 0, Sin[Rational[6, 25] Pi]}, {-
        Cos[Rational[11, 50] Pi], 0, Sin[Rational[11, 50] Pi]}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {-Cos[Rational[9, 50] Pi], 0, Sin[
        Rational[9, 50] Pi]}, {-Cos[Rational[4, 25] Pi], 0, Sin[
        Rational[4, 25] Pi]}, {-Cos[Rational[7, 50] Pi], 0, Sin[
        Rational[7, 50] Pi]}, {-Cos[Rational[3, 25] Pi], 0, Sin[
        Rational[3, 25] 
         Pi]}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0, Rational[1, 4] (-1 + 5^Rational[1, 2])}, {-
        Cos[Rational[2, 25] Pi], 0, Sin[Rational[2, 25] Pi]}, {-
        Cos[Rational[3, 50] Pi], 0, Sin[Rational[3, 50] Pi]}, {-
        Cos[Rational[1, 25] Pi], 0, Sin[Rational[1, 25] Pi]}, {-
        Cos[Rational[1, 50] Pi], 0, Sin[Rational[1, 50] Pi]}, {-1, 0, 
       0}, {-Cos[Rational[1, 50] Pi], 0, -Sin[Rational[1, 50] Pi]}, {-
        Cos[Rational[1, 25] Pi], 0, -Sin[Rational[1, 25] Pi]}, {-
        Cos[Rational[3, 50] Pi], 0, -Sin[Rational[3, 50] Pi]}, {-
        Cos[Rational[2, 25] Pi], 0, -
        Sin[Rational[2, 25] Pi]}, {-(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {-Cos[Rational[3, 25] Pi], 
        0, -Sin[Rational[3, 25] Pi]}, {-Cos[Rational[7, 50] Pi], 0, -
        Sin[Rational[7, 50] Pi]}, {-Cos[Rational[4, 25] Pi], 0, -
        Sin[Rational[4, 25] Pi]}, {-Cos[Rational[9, 50] Pi], 0, -
        Sin[Rational[9, 50] Pi]}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {-Cos[Rational[11, 50] Pi], 0, -
        Sin[Rational[11, 50] Pi]}, {-Cos[Rational[6, 25] Pi], 0, -
        Sin[Rational[6, 25] Pi]}, {-Sin[Rational[6, 25] Pi], 0, -
        Cos[Rational[6, 25] Pi]}, {-Sin[Rational[11, 50] Pi], 0, -
        Cos[Rational[11, 50] Pi]}, {-(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {-Sin[Rational[9, 50] Pi], 
        0, -Cos[Rational[9, 50] Pi]}, {-Sin[Rational[4, 25] Pi], 0, -
        Cos[Rational[4, 25] Pi]}, {-Sin[Rational[7, 50] Pi], 0, -
        Cos[Rational[7, 50] Pi]}, {-Sin[Rational[3, 25] Pi], 0, -
        Cos[Rational[3, 25] Pi]}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {-Sin[Rational[2, 25] Pi], 0, -
        Cos[Rational[2, 25] Pi]}, {-Sin[Rational[3, 50] Pi], 0, -
        Cos[Rational[3, 50] Pi]}, {-Sin[Rational[1, 25] Pi], 0, -
        Cos[Rational[1, 25] Pi]}, {-Sin[Rational[1, 50] Pi], 0, -
        Cos[Rational[1, 50] Pi]}, {0, 0, -1}, {
       Sin[Rational[1, 50] Pi], 0, -Cos[Rational[1, 50] Pi]}, {
       Sin[Rational[1, 25] Pi], 0, -Cos[Rational[1, 25] Pi]}, {
       Sin[Rational[3, 50] Pi], 0, -Cos[Rational[3, 50] Pi]}, {
       Sin[Rational[2, 25] Pi], 0, -Cos[Rational[2, 25] Pi]}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       Sin[Rational[3, 25] Pi], 0, -Cos[Rational[3, 25] Pi]}, {
       Sin[Rational[7, 50] Pi], 0, -Cos[Rational[7, 50] Pi]}, {
       Sin[Rational[4, 25] Pi], 0, -Cos[Rational[4, 25] Pi]}, {
       Sin[Rational[9, 50] Pi], 0, -
        Cos[Rational[9, 50] Pi]}, {(Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       Sin[Rational[11, 50] Pi], 0, -Cos[Rational[11, 50] Pi]}, {
       Sin[Rational[6, 25] Pi], 0, -Cos[Rational[6, 25] Pi]}, {
       Cos[Rational[6, 25] Pi], 0, -Sin[Rational[6, 25] Pi]}, {
       Cos[Rational[11, 50] Pi], 0, -Sin[Rational[11, 50] Pi]}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       Cos[Rational[9, 50] Pi], 0, -Sin[Rational[9, 50] Pi]}, {
       Cos[Rational[4, 25] Pi], 0, -Sin[Rational[4, 25] Pi]}, {
       Cos[Rational[7, 50] Pi], 0, -Sin[Rational[7, 50] Pi]}, {
       Cos[Rational[3, 25] Pi], 0, -
        Sin[Rational[3, 25] Pi]}, {(Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       Cos[Rational[2, 25] Pi], 0, -Sin[Rational[2, 25] Pi]}, {
       Cos[Rational[3, 50] Pi], 0, -Sin[Rational[3, 50] Pi]}, {
       Cos[Rational[1, 25] Pi], 0, -Sin[Rational[1, 25] Pi]}, {
       Cos[Rational[1, 50] Pi], 0, -Sin[Rational[1, 50] Pi]}, {1, 0, 0}}, {{1,
        0, 0}, {0.9980267284282716, 0, 0.06279051952931337}, {
       0.9921147013144779, 0, 0.12533323356430426`}, {
       0.9822872507286887, 0, 0.1873813145857246}, {
       0.9685831611286311, 0, 0.2486898871648548}, {
       0.9510565162951535, 0, 0.30901699437494745`}, {
       0.9297764858882515, 0, 0.3681245526846779}, {
       0.9048270524660195, 0, 0.4257792915650727}, {
       0.8763066800438636, 0, 0.4817536741017153}, {
       0.8443279255020151, 0, 0.5358267949789967}, {
       0.8090169943749475, 0, 0.5877852522924731}, {
       0.7705132427757893, 0, 0.6374239897486896}, {
       0.7289686274214116, 0, 0.6845471059286886}, {
       0.6845471059286886, 0, 0.7289686274214116}, {
       0.6374239897486896, 0, 0.7705132427757893}, {
       0.5877852522924731, 0, 0.8090169943749475}, {
       0.5358267949789967, 0, 0.8443279255020151}, {
       0.4817536741017153, 0, 0.8763066800438636}, {
       0.4257792915650727, 0, 0.9048270524660195}, {
       0.3681245526846779, 0, 0.9297764858882515}, {
       0.30901699437494745`, 0, 0.9510565162951535}, {
       0.2486898871648548, 0, 0.9685831611286311}, {
       0.1873813145857246, 0, 0.9822872507286887}, {
       0.12533323356430426`, 0, 0.9921147013144779}, {
       0.06279051952931337, 0, 0.9980267284282716}, {0, 0, 
       1}, {-0.06279051952931337, 0, 
        0.9980267284282716}, {-0.12533323356430426`, 0, 
        0.9921147013144779}, {-0.1873813145857246, 0, 
        0.9822872507286887}, {-0.2486898871648548, 0, 
        0.9685831611286311}, {-0.30901699437494745`, 0, 
        0.9510565162951535}, {-0.3681245526846779, 0, 
        0.9297764858882515}, {-0.4257792915650727, 0, 
        0.9048270524660195}, {-0.4817536741017153, 0, 
        0.8763066800438636}, {-0.5358267949789967, 0, 
        0.8443279255020151}, {-0.5877852522924731, 0, 
        0.8090169943749475}, {-0.6374239897486896, 0, 
        0.7705132427757893}, {-0.6845471059286886, 0, 
        0.7289686274214116}, {-0.7289686274214116, 0, 
        0.6845471059286886}, {-0.7705132427757893, 0, 
        0.6374239897486896}, {-0.8090169943749475, 0, 
        0.5877852522924731}, {-0.8443279255020151, 0, 
        0.5358267949789967}, {-0.8763066800438636, 0, 
        0.4817536741017153}, {-0.9048270524660195, 0, 
        0.4257792915650727}, {-0.9297764858882515, 0, 
        0.3681245526846779}, {-0.9510565162951535, 0, 
        0.30901699437494745`}, {-0.9685831611286311, 0, 
        0.2486898871648548}, {-0.9822872507286887, 0, 
        0.1873813145857246}, {-0.9921147013144779, 0, 
        0.12533323356430426`}, {-0.9980267284282716, 0, 
        0.06279051952931337}, {-1, 0, 
       0}, {-0.9980267284282716, 
        0, -0.06279051952931337}, {-0.9921147013144779, 
        0, -0.12533323356430426`}, {-0.9822872507286887, 
        0, -0.1873813145857246}, {-0.9685831611286311, 
        0, -0.2486898871648548}, {-0.9510565162951535, 
        0, -0.30901699437494745`}, {-0.9297764858882515, 
        0, -0.3681245526846779}, {-0.9048270524660195, 
        0, -0.4257792915650727}, {-0.8763066800438636, 
        0, -0.4817536741017153}, {-0.8443279255020151, 
        0, -0.5358267949789967}, {-0.8090169943749475, 
        0, -0.5877852522924731}, {-0.7705132427757893, 
        0, -0.6374239897486896}, {-0.7289686274214116, 
        0, -0.6845471059286886}, {-0.6845471059286886, 
        0, -0.7289686274214116}, {-0.6374239897486896, 
        0, -0.7705132427757893}, {-0.5877852522924731, 
        0, -0.8090169943749475}, {-0.5358267949789967, 
        0, -0.8443279255020151}, {-0.4817536741017153, 
        0, -0.8763066800438636}, {-0.4257792915650727, 
        0, -0.9048270524660195}, {-0.3681245526846779, 
        0, -0.9297764858882515}, {-0.30901699437494745`, 
        0, -0.9510565162951535}, {-0.2486898871648548, 
        0, -0.9685831611286311}, {-0.1873813145857246, 
        0, -0.9822872507286887}, {-0.12533323356430426`, 
        0, -0.9921147013144779}, {-0.06279051952931337, 
        0, -0.9980267284282716}, {0, 0, -1}, {
       0.06279051952931337, 0, -0.9980267284282716}, {
       0.12533323356430426`, 0, -0.9921147013144779}, {
       0.1873813145857246, 0, -0.9822872507286887}, {
       0.2486898871648548, 0, -0.9685831611286311}, {
       0.30901699437494745`, 0, -0.9510565162951535}, {
       0.3681245526846779, 0, -0.9297764858882515}, {
       0.4257792915650727, 0, -0.9048270524660195}, {
       0.4817536741017153, 0, -0.8763066800438636}, {
       0.5358267949789967, 0, -0.8443279255020151}, {
       0.5877852522924731, 0, -0.8090169943749475}, {
       0.6374239897486896, 0, -0.7705132427757893}, {
       0.6845471059286886, 0, -0.7289686274214116}, {
       0.7289686274214116, 0, -0.6845471059286886}, {
       0.7705132427757893, 0, -0.6374239897486896}, {
       0.8090169943749475, 0, -0.5877852522924731}, {
       0.8443279255020151, 0, -0.5358267949789967}, {
       0.8763066800438636, 0, -0.4817536741017153}, {
       0.9048270524660195, 0, -0.4257792915650727}, {
       0.9297764858882515, 0, -0.3681245526846779}, {
       0.9510565162951535, 0, -0.30901699437494745`}, {
       0.9685831611286311, 0, -0.2486898871648548}, {
       0.9822872507286887, 0, -0.1873813145857246}, {
       0.9921147013144779, 0, -0.12533323356430426`}, {
       0.9980267284282716, 0, -0.06279051952931337}, {1, 0, 0}}]], 
    SphereBox[{0, 0, 0}, 1]}, {{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[Large], Line3DBox[CompressedData["
1:eJxN1Hk4VfkfB3C7FuFnqUlZpkvWB2VSzOSYSJaylOY2CNmK9CNZfogQJfse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       "]]},
     Annotation[#, "Charting`Private`Tag$2361#1"]& ]}, {
    {Arrowheads[Medium], Arrow3DBox[TubeBox[{{0, 0, 0}, {1., 0., 0.}}]], 
     Text3DBox[
      StyleBox["\<\"x\"\>",
       StripOnInput->False,
       FormatType->StandardForm,
       FontFamily->"Helvetica",
       FontSize->14], {0.8, -0.032009219983224, -0.03841106397986879},
      FormatType->StandardForm]}, 
    {Arrowheads[Medium], Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1., 0.}}]], 
     Text3DBox[
      StyleBox["\<\"y\"\>",
       StripOnInput->False,
       FormatType->StandardForm,
       FontFamily->"Helvetica",
       FontSize->14], {0.04192218081503186, 0.8, -0.02724941752977071},
      FormatType->StandardForm]}, 
    {Arrowheads[Medium], Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.}}]], 
     Text3DBox[
      StyleBox["\<\"z\"\>",
       StripOnInput->False,
       FormatType->StandardForm,
       FontFamily->"Helvetica",
       FontSize->14], {0.0439645983268387, 0.02381415742703763, 0.8},
      FormatType->StandardForm]}}},
  Boxed->False,
  ImageSize->{202.66666666666617`, Automatic},
  LabelStyle->Directive[FontFamily -> "Helvetica", FontSize -> 14],
  ViewPoint->{6, 2, 1},
  ViewVertical->{0, 0, 1}]], "Output",
 CellChangeTimes->{{3.511624394834071*^9, 3.511624465714164*^9}, 
   3.513162388279839*^9, 3.5150684906193447`*^9, 3.5150694991100483`*^9, 
   3.533177705988584*^9, 3.568904217249593*^9, 3.5713804991421843`*^9, 
   3.703853700430638*^9, 3.7038538599730005`*^9, 3.7038539278294144`*^9, 
   3.703856376465969*^9, 3.703856750992895*^9, 3.7039207252787457`*^9, 
   3.7121510431275005`*^9, 3.728634174241785*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
off-resonance trajectory of {x,y,z}-magnetization, starting from z\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707871584403*^9}, {
  3.486707939722651*^9, 3.486707945208267*^9}, {3.486708008593843*^9, 
  3.4867080096800623`*^9}, {3.4867081353531647`*^9, 3.486708140856287*^9}, {
  3.486708450441025*^9, 3.486708469102826*^9}}],

Cell["\<\
This example uses the option BackgroundGenerator to provide a Hamiltonian \
term that acts at the same time as the defined events\
\>", "Text",
 CellChangeTimes->{{3.486708494895919*^9, 3.4867085148547373`*^9}, 
   3.49757414324194*^9, 3.712151037886928*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rffactor", "=", "1.0"}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.486708520478739*^9, 3.4867085233037453`*^9}, 
   3.486708589447815*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"resonanceoffset", "=", 
   RowBox[{"0.5", " ", "\[Omega]nut"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.486708575308324*^9, 3.486708585905423*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompositePulse", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
        RowBox[{"opI", "[", "\"\<y\>\"", "]"}]}], ",", "\[Tau]90"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
        RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]180"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
        RowBox[{"opI", "[", "\"\<y\>\"", "]"}]}], ",", "\[Tau]90"}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{3.48670859223352*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"Ixtraj", ",", "Iytraj", ",", "Iztraj"}], "}"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{"Trajectory", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}], ",", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}], ",", 
       RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", "CompositePulse", ",", "\[IndentingNewLine]", 
    RowBox[{"BackgroundGenerator", "\[Rule]", 
     RowBox[{"resonanceoffset", "\[Times]", " ", 
      RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4565095226613693`*^9, 3.456509562395952*^9}, {
   3.486708014261339*^9, 3.48670803633846*^9}, {3.486708147684558*^9, 
   3.4867081730827513`*^9}, {3.486708554819775*^9, 3.4867085694270277`*^9}, 
   3.486708599484769*^9, {3.497528537278023*^9, 3.497528584731378*^9}, 
   3.497574144382688*^9, {3.510318645758973*^9, 3.510318654797866*^9}, 
   3.712151038072033*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"20.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-6\"\>"]}],
          0.00002,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"20.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-6\"\>"]}],
          0.00002,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"20.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-6\"\>"]}],
          0.00002,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456509549294127*^9, 3.45650956323951*^9}, 
   3.456509647542842*^9, 3.4565098974113092`*^9, 3.456545656175568*^9, 
   3.456546623398144*^9, {3.456570783390377*^9, 3.456570796273484*^9}, 
   3.456570832703512*^9, 3.458994532296883*^9, 3.459442723512301*^9, 
   3.461066537245344*^9, 3.4613298032665*^9, {3.4620059345073957`*^9, 
   3.4620059394326477`*^9}, 3.4640250841192636`*^9, 3.464803447884685*^9, 
   3.465814125692009*^9, 3.467015925147357*^9, {3.486707964429309*^9, 
   3.4867079728747177`*^9}, 3.4867080041836433`*^9, 3.486708037345064*^9, 
   3.486708175165627*^9, {3.486708527706403*^9, 3.486708546365292*^9}, 
   3.486708600877496*^9, 3.486709667674693*^9, 3.4867114088000803`*^9, 
   3.486719490062199*^9, 3.496138766131628*^9, 3.4961388585967493`*^9, 
   3.497528388552473*^9, 3.49752855481623*^9, 3.4975303094498262`*^9, 
   3.497569397577917*^9, 3.497574254106003*^9, 3.497648486037816*^9, 
   3.49930409085394*^9, 3.502011171072074*^9, 3.5027109317060833`*^9, 
   3.50276128817304*^9, 3.5033071342817574`*^9, 3.5070246388544493`*^9, 
   3.50702831746196*^9, 3.510318333999751*^9, 3.510318375349532*^9, 
   3.510318661080637*^9, 3.5116239357170143`*^9, 3.511624492560285*^9, 
   3.5131623887269993`*^9, 3.515068491214755*^9, 3.515069499576583*^9, 
   3.533177706469282*^9, 3.5689042335235233`*^9, 3.571380519007183*^9, 
   3.7038537007706733`*^9, 3.703853864797886*^9, 3.7038539280992556`*^9, 
   3.703856376745919*^9, 3.703856751148735*^9, 3.703920725599543*^9, 
   3.712151043703911*^9, 3.7286341746176853`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ixtraj", "[", 
      RowBox[{"t\[Mu]s", "\[Times]", 
       RowBox[{"10", "^", 
        RowBox[{"-", "6"}]}]}], "]"}], ",", 
     RowBox[{"Iytraj", "[", 
      RowBox[{"t\[Mu]s", "\[Times]", 
       RowBox[{"10", "^", 
        RowBox[{"-", "6"}]}]}], "]"}], ",", 
     RowBox[{"Iztraj", "[", 
      RowBox[{"t\[Mu]s", "\[Times]", 
       RowBox[{"10", "^", 
        RowBox[{"-", "6"}]}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t\[Mu]s", ",", "0", ",", 
     RowBox[{"TotalDuration", "\[Times]", 
      RowBox[{"10", "^", "6"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Green"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Medium", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Mu]s\>\"", ",", "\"\<amplitude\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.45650956890828*^9, 3.456509571083004*^9}, {
   3.4565099019330606`*^9, 3.4565099070840673`*^9}, {3.456545660832933*^9, 
   3.4565456665182953`*^9}, {3.486708063467409*^9, 3.4867080670420017`*^9}, 
   3.486708120749165*^9, {3.486708180925454*^9, 3.486708191714155*^9}, 
   3.486708226238326*^9, {3.5103186735688133`*^9, 3.510318696963477*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13c8Vf8fB3CFbNmpZLs29yKl9X43VERCVkZI2ZtQQlKkRJKMrxWigYaU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       "]]},
     Annotation[#, "Charting`Private`Tag$3208#1"]& ], 
    TagBox[
     {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwt1nk4Vd/XAHCZylCZMtxrzFS4UjeJYi2kAakMFYmSKUkoEVKZEmVKpSKZ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       "]]},
     Annotation[#, "Charting`Private`Tag$3208#2"]& ], 
    TagBox[
     {RGBColor[0, 1, 0], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk8VN8bB3BLKSpZI8k6cwehZaRSeh5RSlK2FnyJEpUlSiRJSVQqoSiJ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       "]]},
     Annotation[#, "Charting`Private`Tag$3208#3"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"amplitude\"", TraditionalForm], None}, {
     FormBox["\"\[Mu]s\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 20.}, {-0.8198557326661625, 0.9999999999999913}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.456509572000661*^9, 3.456509653636228*^9, 3.456509899944787*^9, {
   3.456545656336225*^9, 3.456545667486722*^9}, 3.4565466234500847`*^9, 
   3.456570783589847*^9, 3.456570837050729*^9, 3.458994532350522*^9, 
   3.459442723564172*^9, 3.4610665372926807`*^9, 3.4613298034579077`*^9, 
   3.46200594275671*^9, 3.464025084171768*^9, 3.464803447935872*^9, 
   3.465814125726612*^9, 3.467015925309105*^9, {3.486708059353109*^9, 
   3.486708068097351*^9}, 3.486708121976638*^9, 3.4867081924220343`*^9, 
   3.486708227184865*^9, {3.4867085278784037`*^9, 3.48670854915646*^9}, 
   3.4867086031353893`*^9, 3.486709667779928*^9, 3.4867114089194307`*^9, 
   3.486719490172556*^9, 3.496138766234392*^9, 3.496138858693478*^9, 
   3.497528388655117*^9, 3.497528557956822*^9, 3.497530309550967*^9, 
   3.497569397691099*^9, 3.497574254209352*^9, 3.4976484861446457`*^9, 
   3.499304090962685*^9, 3.502011171187208*^9, 3.502710931822565*^9, 
   3.502761288286933*^9, 3.503307134398137*^9, 3.507024638918689*^9, 
   3.507028317846068*^9, 3.510318334048856*^9, 3.51031837545413*^9, 
   3.5103186611868668`*^9, 3.510318697842525*^9, 3.511623935856151*^9, 
   3.511624492715926*^9, 3.513162388848802*^9, 3.5150684913813066`*^9, 
   3.515069499698634*^9, 3.533177706613119*^9, 3.568904239260852*^9, 
   3.571380521043969*^9, 3.7038537008914833`*^9, 3.703853864868573*^9, 
   3.7038539282538505`*^9, 3.7038563769004655`*^9, 3.7038567512277317`*^9, 
   3.7039207256898785`*^9, 3.7121510438730316`*^9, 3.7286341746814575`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Opacity", "[", "0.1", "]"}], ",", 
       RowBox[{"EdgeForm", "[", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"Cos", "[", "#", "]"}], ",", 
            RowBox[{"Sin", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "100"}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "#", "]"}], ",", 
            RowBox[{"Sin", "[", "#", "]"}], ",", "0"}], "}"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "100"}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "#", "]"}], ",", "0", ",", 
            RowBox[{"Sin", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "100"}]}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ParametricPlot3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Re", "@", 
       RowBox[{"Through", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Ixtraj", ",", "Iytraj", ",", "Iztraj"}], "}"}], "[", "t", 
         "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "TotalDuration"}], "}"}], ",", 
      RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Axes3D", "[", "]"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ViewVertical", "\[Rule]", "ez"}]}], "\[IndentingNewLine]", "]"}],
   "\[IndentingNewLine]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.456510853408382*^9, 3.4565109643318768`*^9}, 
   3.456545885234786*^9, {3.456545930266377*^9, 3.456546035352107*^9}, {
   3.456546468726475*^9, 3.456546469396908*^9}, {3.456546543591886*^9, 
   3.456546549343329*^9}, {3.456546664497095*^9, 3.456546667679903*^9}, {
   3.486708337033456*^9, 3.486708407853148*^9}, 3.511624489088361*^9}],

Cell[BoxData[
 Graphics3DBox[{
   {Opacity[0.1], EdgeForm[None], 
    Polygon3DBox[
     NCache[{{0, 1, 0}, {
       0, Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi]}, {
       0, Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi]}, {
       0, Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi]}, {
       0, Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi]}, {
       0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       0, Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi]}, {
       0, Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi]}, {
       0, Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi]}, {
       0, Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi]}, {
       0, Rational[1, 4] (1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi]}, {
       0, Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi]}, {
       0, Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi]}, {
       0, Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi]}, {
       0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       0, Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi]}, {
       0, Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi]}, {
       0, Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi]}, {
       0, Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi]}, {
       0, Rational[1, 4] (-1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi]}, {
       0, Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi]}, {
       0, Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi]}, {
       0, Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi]}, {0, 0, 1}, {
       0, -Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi]}, {
       0, -Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi]}, {
       0, -Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi]}, {
       0, -Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi]}, {
       0, 
        Rational[1, 4] (1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi]}, {
       0, -Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi]}, {
       0, -Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi]}, {
       0, -Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi]}, {
       0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2],
         Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       0, -Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi]}, {
       0, -Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi]}, {
       0, -Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi]}, {
       0, -Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi]}, {
       0, Rational[1, 4] (-1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi]}, {
       0, -Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi]}, {
       0, -Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi]}, {
       0, -Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi]}, {
       0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       0, -Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi]}, {
       0, -Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi]}, {
       0, -Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi]}, {
       0, -Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi]}, {0, -1, 0}, {
       0, -Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi]}, {
       0, -Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi]}, {
       0, -Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi]}, {
       0, -Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi]}, {
       0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       0, -Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi]}, {
       0, -Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi]}, {
       0, -Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi]}, {
       0, -Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi]}, {
       0, Rational[1, 4] (-1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi]}, {
       0, -Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi]}, {
       0, -Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi]}, {
       0, -Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi]}, {
       0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2],
         Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       0, -Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi]}, {
       0, -Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi]}, {
       0, -Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi]}, {
       0, -Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi]}, {
       0, Rational[1, 4] (1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       0, -Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi]}, {
       0, -Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi]}, {
       0, -Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi]}, {
       0, -Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi]}, {0, 0, -1}, {
       0, Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi]}, {
       0, Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi]}, {
       0, Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi]}, {
       0, Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi]}, {
       0, Rational[1, 4] (-1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi]}, {
       0, Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi]}, {
       0, Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi]}, {
       0, Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi]}, {
       0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       0, Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi]}, {
       0, Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi]}, {
       0, Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi]}, {
       0, Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi]}, {
       0, Rational[1, 4] (1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi]}, {
       0, Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi]}, {
       0, Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi]}, {
       0, Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi]}, {
       0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       0, Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi]}, {
       0, Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi]}, {
       0, Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi]}, {
       0, Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi]}, {0, 1, 0}}, {{0,
        1, 0}, {0, 0.9980267284282716, 0.06279051952931337}, {
       0, 0.9921147013144779, 0.12533323356430426`}, {
       0, 0.9822872507286887, 0.1873813145857246}, {
       0, 0.9685831611286311, 0.2486898871648548}, {
       0, 0.9510565162951535, 0.30901699437494745`}, {
       0, 0.9297764858882515, 0.3681245526846779}, {
       0, 0.9048270524660195, 0.4257792915650727}, {
       0, 0.8763066800438636, 0.4817536741017153}, {
       0, 0.8443279255020151, 0.5358267949789967}, {
       0, 0.8090169943749475, 0.5877852522924731}, {
       0, 0.7705132427757893, 0.6374239897486896}, {
       0, 0.7289686274214116, 0.6845471059286886}, {
       0, 0.6845471059286886, 0.7289686274214116}, {
       0, 0.6374239897486896, 0.7705132427757893}, {
       0, 0.5877852522924731, 0.8090169943749475}, {
       0, 0.5358267949789967, 0.8443279255020151}, {
       0, 0.4817536741017153, 0.8763066800438636}, {
       0, 0.4257792915650727, 0.9048270524660195}, {
       0, 0.3681245526846779, 0.9297764858882515}, {
       0, 0.30901699437494745`, 0.9510565162951535}, {
       0, 0.2486898871648548, 0.9685831611286311}, {
       0, 0.1873813145857246, 0.9822872507286887}, {
       0, 0.12533323356430426`, 0.9921147013144779}, {
       0, 0.06279051952931337, 0.9980267284282716}, {0, 0, 1}, {
       0, -0.06279051952931337, 0.9980267284282716}, {
       0, -0.12533323356430426`, 0.9921147013144779}, {
       0, -0.1873813145857246, 0.9822872507286887}, {
       0, -0.2486898871648548, 0.9685831611286311}, {
       0, -0.30901699437494745`, 0.9510565162951535}, {
       0, -0.3681245526846779, 0.9297764858882515}, {
       0, -0.4257792915650727, 0.9048270524660195}, {
       0, -0.4817536741017153, 0.8763066800438636}, {
       0, -0.5358267949789967, 0.8443279255020151}, {
       0, -0.5877852522924731, 0.8090169943749475}, {
       0, -0.6374239897486896, 0.7705132427757893}, {
       0, -0.6845471059286886, 0.7289686274214116}, {
       0, -0.7289686274214116, 0.6845471059286886}, {
       0, -0.7705132427757893, 0.6374239897486896}, {
       0, -0.8090169943749475, 0.5877852522924731}, {
       0, -0.8443279255020151, 0.5358267949789967}, {
       0, -0.8763066800438636, 0.4817536741017153}, {
       0, -0.9048270524660195, 0.4257792915650727}, {
       0, -0.9297764858882515, 0.3681245526846779}, {
       0, -0.9510565162951535, 0.30901699437494745`}, {
       0, -0.9685831611286311, 0.2486898871648548}, {
       0, -0.9822872507286887, 0.1873813145857246}, {
       0, -0.9921147013144779, 0.12533323356430426`}, {
       0, -0.9980267284282716, 0.06279051952931337}, {0, -1, 0}, {
       0, -0.9980267284282716, -0.06279051952931337}, {
       0, -0.9921147013144779, -0.12533323356430426`}, {
       0, -0.9822872507286887, -0.1873813145857246}, {
       0, -0.9685831611286311, -0.2486898871648548}, {
       0, -0.9510565162951535, -0.30901699437494745`}, {
       0, -0.9297764858882515, -0.3681245526846779}, {
       0, -0.9048270524660195, -0.4257792915650727}, {
       0, -0.8763066800438636, -0.4817536741017153}, {
       0, -0.8443279255020151, -0.5358267949789967}, {
       0, -0.8090169943749475, -0.5877852522924731}, {
       0, -0.7705132427757893, -0.6374239897486896}, {
       0, -0.7289686274214116, -0.6845471059286886}, {
       0, -0.6845471059286886, -0.7289686274214116}, {
       0, -0.6374239897486896, -0.7705132427757893}, {
       0, -0.5877852522924731, -0.8090169943749475}, {
       0, -0.5358267949789967, -0.8443279255020151}, {
       0, -0.4817536741017153, -0.8763066800438636}, {
       0, -0.4257792915650727, -0.9048270524660195}, {
       0, -0.3681245526846779, -0.9297764858882515}, {
       0, -0.30901699437494745`, -0.9510565162951535}, {
       0, -0.2486898871648548, -0.9685831611286311}, {
       0, -0.1873813145857246, -0.9822872507286887}, {
       0, -0.12533323356430426`, -0.9921147013144779}, {
       0, -0.06279051952931337, -0.9980267284282716}, {0, 0, -1}, {
       0, 0.06279051952931337, -0.9980267284282716}, {
       0, 0.12533323356430426`, -0.9921147013144779}, {
       0, 0.1873813145857246, -0.9822872507286887}, {
       0, 0.2486898871648548, -0.9685831611286311}, {
       0, 0.30901699437494745`, -0.9510565162951535}, {
       0, 0.3681245526846779, -0.9297764858882515}, {
       0, 0.4257792915650727, -0.9048270524660195}, {
       0, 0.4817536741017153, -0.8763066800438636}, {
       0, 0.5358267949789967, -0.8443279255020151}, {
       0, 0.5877852522924731, -0.8090169943749475}, {
       0, 0.6374239897486896, -0.7705132427757893}, {
       0, 0.6845471059286886, -0.7289686274214116}, {
       0, 0.7289686274214116, -0.6845471059286886}, {
       0, 0.7705132427757893, -0.6374239897486896}, {
       0, 0.8090169943749475, -0.5877852522924731}, {
       0, 0.8443279255020151, -0.5358267949789967}, {
       0, 0.8763066800438636, -0.4817536741017153}, {
       0, 0.9048270524660195, -0.4257792915650727}, {
       0, 0.9297764858882515, -0.3681245526846779}, {
       0, 0.9510565162951535, -0.30901699437494745`}, {
       0, 0.9685831611286311, -0.2486898871648548}, {
       0, 0.9822872507286887, -0.1873813145857246}, {
       0, 0.9921147013144779, -0.12533323356430426`}, {
       0, 0.9980267284282716, -0.06279051952931337}, {0, 1, 0}}]], 
    Polygon3DBox[
     NCache[{{1, 0, 0}, {
       Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi], 0}, {
       Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi], 0}, {
       Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi], 0}, {
       Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi], 
        0}, {(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {
       Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi], 0}, {
       Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi], 0}, {
       Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi], 0}, {
       Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi], 0}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi], 0}, {
       Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi], 0}, {
       Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi], 0}, {
       Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi], 
        0}, {(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {
       Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi], 0}, {
       Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi], 0}, {
       Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi], 0}, {
       Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi], 0}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi], 0}, {
       Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi], 0}, {
       Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi], 0}, {
       Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi], 0}, {0, 1, 
       0}, {-Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi], 0}, {-
        Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi], 0}, {-
        Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi], 0}, {-
        Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi], 0}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi], 0}, {-
        Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi], 0}, {-
        Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi], 0}, {-
        Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi], 
        0}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {-
        Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi], 0}, {-
        Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi], 0}, {-
        Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi], 0}, {-
        Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi], 0}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi], 0}, {-
        Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi], 0}, {-
        Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi], 0}, {-
        Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi], 
        0}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {-
        Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi], 0}, {-
        Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi], 0}, {-
        Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi], 0}, {-
        Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi], 0}, {-1, 0, 
       0}, {-Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi], 0}, {-
        Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi], 0}, {-
        Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi], 0}, {-
        Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi], 
        0}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {-
        Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi], 0}, {-
        Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi], 0}, {-
        Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi], 0}, {-
        Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi], 0}, {
       Rational[1, 4] (-1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi], 0}, {-
        Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi], 0}, {-
        Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi], 0}, {-
        Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi], 
        0}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {-
        Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi], 0}, {-
        Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi], 0}, {-
        Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi], 0}, {-
        Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi], 0}, {
       Rational[1, 4] (1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0}, {-Sin[Rational[2, 25] Pi], -
        Cos[Rational[2, 25] Pi], 0}, {-Sin[Rational[3, 50] Pi], -
        Cos[Rational[3, 50] Pi], 0}, {-Sin[Rational[1, 25] Pi], -
        Cos[Rational[1, 25] Pi], 0}, {-Sin[Rational[1, 50] Pi], -
        Cos[Rational[1, 50] Pi], 0}, {0, -1, 0}, {
       Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi], 0}, {
       Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi], 0}, {
       Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi], 0}, {
       Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi], 0}, {
       Rational[1, 4] (-1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi], 0}, {
       Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi], 0}, {
       Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi], 0}, {
       Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi], 
        0}, {(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {
       Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi], 0}, {
       Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi], 0}, {
       Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi], 0}, {
       Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi], 0}, {
       Rational[1, 4] (1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi], 0}, {
       Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi], 0}, {
       Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi], 0}, {
       Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi], 
        0}, {(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {
       Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi], 0}, {
       Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi], 0}, {
       Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi], 0}, {
       Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi], 0}, {1, 0, 0}}, {{1,
        0, 0}, {0.9980267284282716, 0.06279051952931337, 0}, {
       0.9921147013144779, 0.12533323356430426`, 0}, {
       0.9822872507286887, 0.1873813145857246, 0}, {
       0.9685831611286311, 0.2486898871648548, 0}, {
       0.9510565162951535, 0.30901699437494745`, 0}, {
       0.9297764858882515, 0.3681245526846779, 0}, {
       0.9048270524660195, 0.4257792915650727, 0}, {
       0.8763066800438636, 0.4817536741017153, 0}, {
       0.8443279255020151, 0.5358267949789967, 0}, {
       0.8090169943749475, 0.5877852522924731, 0}, {
       0.7705132427757893, 0.6374239897486896, 0}, {
       0.7289686274214116, 0.6845471059286886, 0}, {
       0.6845471059286886, 0.7289686274214116, 0}, {
       0.6374239897486896, 0.7705132427757893, 0}, {
       0.5877852522924731, 0.8090169943749475, 0}, {
       0.5358267949789967, 0.8443279255020151, 0}, {
       0.4817536741017153, 0.8763066800438636, 0}, {
       0.4257792915650727, 0.9048270524660195, 0}, {
       0.3681245526846779, 0.9297764858882515, 0}, {
       0.30901699437494745`, 0.9510565162951535, 0}, {
       0.2486898871648548, 0.9685831611286311, 0}, {
       0.1873813145857246, 0.9822872507286887, 0}, {
       0.12533323356430426`, 0.9921147013144779, 0}, {
       0.06279051952931337, 0.9980267284282716, 0}, {0, 1, 
       0}, {-0.06279051952931337, 0.9980267284282716, 
        0}, {-0.12533323356430426`, 0.9921147013144779, 
        0}, {-0.1873813145857246, 0.9822872507286887, 
        0}, {-0.2486898871648548, 0.9685831611286311, 
        0}, {-0.30901699437494745`, 0.9510565162951535, 
        0}, {-0.3681245526846779, 0.9297764858882515, 
        0}, {-0.4257792915650727, 0.9048270524660195, 
        0}, {-0.4817536741017153, 0.8763066800438636, 
        0}, {-0.5358267949789967, 0.8443279255020151, 
        0}, {-0.5877852522924731, 0.8090169943749475, 
        0}, {-0.6374239897486896, 0.7705132427757893, 
        0}, {-0.6845471059286886, 0.7289686274214116, 
        0}, {-0.7289686274214116, 0.6845471059286886, 
        0}, {-0.7705132427757893, 0.6374239897486896, 
        0}, {-0.8090169943749475, 0.5877852522924731, 
        0}, {-0.8443279255020151, 0.5358267949789967, 
        0}, {-0.8763066800438636, 0.4817536741017153, 
        0}, {-0.9048270524660195, 0.4257792915650727, 
        0}, {-0.9297764858882515, 0.3681245526846779, 
        0}, {-0.9510565162951535, 0.30901699437494745`, 
        0}, {-0.9685831611286311, 0.2486898871648548, 
        0}, {-0.9822872507286887, 0.1873813145857246, 
        0}, {-0.9921147013144779, 0.12533323356430426`, 
        0}, {-0.9980267284282716, 0.06279051952931337, 0}, {-1, 0, 
       0}, {-0.9980267284282716, -0.06279051952931337, 
        0}, {-0.9921147013144779, -0.12533323356430426`, 
        0}, {-0.9822872507286887, -0.1873813145857246, 
        0}, {-0.9685831611286311, -0.2486898871648548, 
        0}, {-0.9510565162951535, -0.30901699437494745`, 
        0}, {-0.9297764858882515, -0.3681245526846779, 
        0}, {-0.9048270524660195, -0.4257792915650727, 
        0}, {-0.8763066800438636, -0.4817536741017153, 
        0}, {-0.8443279255020151, -0.5358267949789967, 
        0}, {-0.8090169943749475, -0.5877852522924731, 
        0}, {-0.7705132427757893, -0.6374239897486896, 
        0}, {-0.7289686274214116, -0.6845471059286886, 
        0}, {-0.6845471059286886, -0.7289686274214116, 
        0}, {-0.6374239897486896, -0.7705132427757893, 
        0}, {-0.5877852522924731, -0.8090169943749475, 
        0}, {-0.5358267949789967, -0.8443279255020151, 
        0}, {-0.4817536741017153, -0.8763066800438636, 
        0}, {-0.4257792915650727, -0.9048270524660195, 
        0}, {-0.3681245526846779, -0.9297764858882515, 
        0}, {-0.30901699437494745`, -0.9510565162951535, 
        0}, {-0.2486898871648548, -0.9685831611286311, 
        0}, {-0.1873813145857246, -0.9822872507286887, 
        0}, {-0.12533323356430426`, -0.9921147013144779, 
        0}, {-0.06279051952931337, -0.9980267284282716, 0}, {0, -1, 0}, {
       0.06279051952931337, -0.9980267284282716, 0}, {
       0.12533323356430426`, -0.9921147013144779, 0}, {
       0.1873813145857246, -0.9822872507286887, 0}, {
       0.2486898871648548, -0.9685831611286311, 0}, {
       0.30901699437494745`, -0.9510565162951535, 0}, {
       0.3681245526846779, -0.9297764858882515, 0}, {
       0.4257792915650727, -0.9048270524660195, 0}, {
       0.4817536741017153, -0.8763066800438636, 0}, {
       0.5358267949789967, -0.8443279255020151, 0}, {
       0.5877852522924731, -0.8090169943749475, 0}, {
       0.6374239897486896, -0.7705132427757893, 0}, {
       0.6845471059286886, -0.7289686274214116, 0}, {
       0.7289686274214116, -0.6845471059286886, 0}, {
       0.7705132427757893, -0.6374239897486896, 0}, {
       0.8090169943749475, -0.5877852522924731, 0}, {
       0.8443279255020151, -0.5358267949789967, 0}, {
       0.8763066800438636, -0.4817536741017153, 0}, {
       0.9048270524660195, -0.4257792915650727, 0}, {
       0.9297764858882515, -0.3681245526846779, 0}, {
       0.9510565162951535, -0.30901699437494745`, 0}, {
       0.9685831611286311, -0.2486898871648548, 0}, {
       0.9822872507286887, -0.1873813145857246, 0}, {
       0.9921147013144779, -0.12533323356430426`, 0}, {
       0.9980267284282716, -0.06279051952931337, 0}, {1, 0, 0}}]], 
    Polygon3DBox[
     NCache[{{1, 0, 0}, {
       Cos[Rational[1, 50] Pi], 0, Sin[Rational[1, 50] Pi]}, {
       Cos[Rational[1, 25] Pi], 0, Sin[Rational[1, 25] Pi]}, {
       Cos[Rational[3, 50] Pi], 0, Sin[Rational[3, 50] Pi]}, {
       Cos[Rational[2, 25] Pi], 0, Sin[
        Rational[2, 25] Pi]}, {(Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       Cos[Rational[3, 25] Pi], 0, Sin[Rational[3, 25] Pi]}, {
       Cos[Rational[7, 50] Pi], 0, Sin[Rational[7, 50] Pi]}, {
       Cos[Rational[4, 25] Pi], 0, Sin[Rational[4, 25] Pi]}, {
       Cos[Rational[9, 50] Pi], 0, Sin[Rational[9, 50] Pi]}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {
       Cos[Rational[11, 50] Pi], 0, Sin[Rational[11, 50] Pi]}, {
       Cos[Rational[6, 25] Pi], 0, Sin[Rational[6, 25] Pi]}, {
       Sin[Rational[6, 25] Pi], 0, Cos[Rational[6, 25] Pi]}, {
       Sin[Rational[11, 50] Pi], 0, Cos[
        Rational[11, 50] Pi]}, {(Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       Sin[Rational[9, 50] Pi], 0, Cos[Rational[9, 50] Pi]}, {
       Sin[Rational[4, 25] Pi], 0, Cos[Rational[4, 25] Pi]}, {
       Sin[Rational[7, 50] Pi], 0, Cos[Rational[7, 50] Pi]}, {
       Sin[Rational[3, 25] Pi], 0, Cos[Rational[3, 25] Pi]}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {
       Sin[Rational[2, 25] Pi], 0, Cos[Rational[2, 25] Pi]}, {
       Sin[Rational[3, 50] Pi], 0, Cos[Rational[3, 50] Pi]}, {
       Sin[Rational[1, 25] Pi], 0, Cos[Rational[1, 25] Pi]}, {
       Sin[Rational[1, 50] Pi], 0, Cos[Rational[1, 50] Pi]}, {0, 0, 
       1}, {-Sin[Rational[1, 50] Pi], 0, Cos[Rational[1, 50] Pi]}, {-
        Sin[Rational[1, 25] Pi], 0, Cos[Rational[1, 25] Pi]}, {-
        Sin[Rational[3, 50] Pi], 0, Cos[Rational[3, 50] Pi]}, {-
        Sin[Rational[2, 25] Pi], 0, Cos[Rational[2, 25] Pi]}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {-Sin[Rational[3, 25] Pi], 0, Cos[
        Rational[3, 25] Pi]}, {-Sin[Rational[7, 50] Pi], 0, Cos[
        Rational[7, 50] Pi]}, {-Sin[Rational[4, 25] Pi], 0, Cos[
        Rational[4, 25] Pi]}, {-Sin[Rational[9, 50] Pi], 0, Cos[
        Rational[9, 50] 
         Pi]}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0, Rational[1, 4] (1 + 5^Rational[1, 2])}, {-
        Sin[Rational[11, 50] Pi], 0, Cos[Rational[11, 50] Pi]}, {-
        Sin[Rational[6, 25] Pi], 0, Cos[Rational[6, 25] Pi]}, {-
        Cos[Rational[6, 25] Pi], 0, Sin[Rational[6, 25] Pi]}, {-
        Cos[Rational[11, 50] Pi], 0, Sin[Rational[11, 50] Pi]}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {-Cos[Rational[9, 50] Pi], 0, Sin[
        Rational[9, 50] Pi]}, {-Cos[Rational[4, 25] Pi], 0, Sin[
        Rational[4, 25] Pi]}, {-Cos[Rational[7, 50] Pi], 0, Sin[
        Rational[7, 50] Pi]}, {-Cos[Rational[3, 25] Pi], 0, Sin[
        Rational[3, 25] 
         Pi]}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0, Rational[1, 4] (-1 + 5^Rational[1, 2])}, {-
        Cos[Rational[2, 25] Pi], 0, Sin[Rational[2, 25] Pi]}, {-
        Cos[Rational[3, 50] Pi], 0, Sin[Rational[3, 50] Pi]}, {-
        Cos[Rational[1, 25] Pi], 0, Sin[Rational[1, 25] Pi]}, {-
        Cos[Rational[1, 50] Pi], 0, Sin[Rational[1, 50] Pi]}, {-1, 0, 
       0}, {-Cos[Rational[1, 50] Pi], 0, -Sin[Rational[1, 50] Pi]}, {-
        Cos[Rational[1, 25] Pi], 0, -Sin[Rational[1, 25] Pi]}, {-
        Cos[Rational[3, 50] Pi], 0, -Sin[Rational[3, 50] Pi]}, {-
        Cos[Rational[2, 25] Pi], 0, -
        Sin[Rational[2, 25] Pi]}, {-(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {-Cos[Rational[3, 25] Pi], 
        0, -Sin[Rational[3, 25] Pi]}, {-Cos[Rational[7, 50] Pi], 0, -
        Sin[Rational[7, 50] Pi]}, {-Cos[Rational[4, 25] Pi], 0, -
        Sin[Rational[4, 25] Pi]}, {-Cos[Rational[9, 50] Pi], 0, -
        Sin[Rational[9, 50] Pi]}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {-Cos[Rational[11, 50] Pi], 0, -
        Sin[Rational[11, 50] Pi]}, {-Cos[Rational[6, 25] Pi], 0, -
        Sin[Rational[6, 25] Pi]}, {-Sin[Rational[6, 25] Pi], 0, -
        Cos[Rational[6, 25] Pi]}, {-Sin[Rational[11, 50] Pi], 0, -
        Cos[Rational[11, 50] Pi]}, {-(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {-Sin[Rational[9, 50] Pi], 
        0, -Cos[Rational[9, 50] Pi]}, {-Sin[Rational[4, 25] Pi], 0, -
        Cos[Rational[4, 25] Pi]}, {-Sin[Rational[7, 50] Pi], 0, -
        Cos[Rational[7, 50] Pi]}, {-Sin[Rational[3, 25] Pi], 0, -
        Cos[Rational[3, 25] Pi]}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {-Sin[Rational[2, 25] Pi], 0, -
        Cos[Rational[2, 25] Pi]}, {-Sin[Rational[3, 50] Pi], 0, -
        Cos[Rational[3, 50] Pi]}, {-Sin[Rational[1, 25] Pi], 0, -
        Cos[Rational[1, 25] Pi]}, {-Sin[Rational[1, 50] Pi], 0, -
        Cos[Rational[1, 50] Pi]}, {0, 0, -1}, {
       Sin[Rational[1, 50] Pi], 0, -Cos[Rational[1, 50] Pi]}, {
       Sin[Rational[1, 25] Pi], 0, -Cos[Rational[1, 25] Pi]}, {
       Sin[Rational[3, 50] Pi], 0, -Cos[Rational[3, 50] Pi]}, {
       Sin[Rational[2, 25] Pi], 0, -Cos[Rational[2, 25] Pi]}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       Sin[Rational[3, 25] Pi], 0, -Cos[Rational[3, 25] Pi]}, {
       Sin[Rational[7, 50] Pi], 0, -Cos[Rational[7, 50] Pi]}, {
       Sin[Rational[4, 25] Pi], 0, -Cos[Rational[4, 25] Pi]}, {
       Sin[Rational[9, 50] Pi], 0, -
        Cos[Rational[9, 50] Pi]}, {(Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       Sin[Rational[11, 50] Pi], 0, -Cos[Rational[11, 50] Pi]}, {
       Sin[Rational[6, 25] Pi], 0, -Cos[Rational[6, 25] Pi]}, {
       Cos[Rational[6, 25] Pi], 0, -Sin[Rational[6, 25] Pi]}, {
       Cos[Rational[11, 50] Pi], 0, -Sin[Rational[11, 50] Pi]}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       Cos[Rational[9, 50] Pi], 0, -Sin[Rational[9, 50] Pi]}, {
       Cos[Rational[4, 25] Pi], 0, -Sin[Rational[4, 25] Pi]}, {
       Cos[Rational[7, 50] Pi], 0, -Sin[Rational[7, 50] Pi]}, {
       Cos[Rational[3, 25] Pi], 0, -
        Sin[Rational[3, 25] Pi]}, {(Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       Cos[Rational[2, 25] Pi], 0, -Sin[Rational[2, 25] Pi]}, {
       Cos[Rational[3, 50] Pi], 0, -Sin[Rational[3, 50] Pi]}, {
       Cos[Rational[1, 25] Pi], 0, -Sin[Rational[1, 25] Pi]}, {
       Cos[Rational[1, 50] Pi], 0, -Sin[Rational[1, 50] Pi]}, {1, 0, 0}}, {{1,
        0, 0}, {0.9980267284282716, 0, 0.06279051952931337}, {
       0.9921147013144779, 0, 0.12533323356430426`}, {
       0.9822872507286887, 0, 0.1873813145857246}, {
       0.9685831611286311, 0, 0.2486898871648548}, {
       0.9510565162951535, 0, 0.30901699437494745`}, {
       0.9297764858882515, 0, 0.3681245526846779}, {
       0.9048270524660195, 0, 0.4257792915650727}, {
       0.8763066800438636, 0, 0.4817536741017153}, {
       0.8443279255020151, 0, 0.5358267949789967}, {
       0.8090169943749475, 0, 0.5877852522924731}, {
       0.7705132427757893, 0, 0.6374239897486896}, {
       0.7289686274214116, 0, 0.6845471059286886}, {
       0.6845471059286886, 0, 0.7289686274214116}, {
       0.6374239897486896, 0, 0.7705132427757893}, {
       0.5877852522924731, 0, 0.8090169943749475}, {
       0.5358267949789967, 0, 0.8443279255020151}, {
       0.4817536741017153, 0, 0.8763066800438636}, {
       0.4257792915650727, 0, 0.9048270524660195}, {
       0.3681245526846779, 0, 0.9297764858882515}, {
       0.30901699437494745`, 0, 0.9510565162951535}, {
       0.2486898871648548, 0, 0.9685831611286311}, {
       0.1873813145857246, 0, 0.9822872507286887}, {
       0.12533323356430426`, 0, 0.9921147013144779}, {
       0.06279051952931337, 0, 0.9980267284282716}, {0, 0, 
       1}, {-0.06279051952931337, 0, 
        0.9980267284282716}, {-0.12533323356430426`, 0, 
        0.9921147013144779}, {-0.1873813145857246, 0, 
        0.9822872507286887}, {-0.2486898871648548, 0, 
        0.9685831611286311}, {-0.30901699437494745`, 0, 
        0.9510565162951535}, {-0.3681245526846779, 0, 
        0.9297764858882515}, {-0.4257792915650727, 0, 
        0.9048270524660195}, {-0.4817536741017153, 0, 
        0.8763066800438636}, {-0.5358267949789967, 0, 
        0.8443279255020151}, {-0.5877852522924731, 0, 
        0.8090169943749475}, {-0.6374239897486896, 0, 
        0.7705132427757893}, {-0.6845471059286886, 0, 
        0.7289686274214116}, {-0.7289686274214116, 0, 
        0.6845471059286886}, {-0.7705132427757893, 0, 
        0.6374239897486896}, {-0.8090169943749475, 0, 
        0.5877852522924731}, {-0.8443279255020151, 0, 
        0.5358267949789967}, {-0.8763066800438636, 0, 
        0.4817536741017153}, {-0.9048270524660195, 0, 
        0.4257792915650727}, {-0.9297764858882515, 0, 
        0.3681245526846779}, {-0.9510565162951535, 0, 
        0.30901699437494745`}, {-0.9685831611286311, 0, 
        0.2486898871648548}, {-0.9822872507286887, 0, 
        0.1873813145857246}, {-0.9921147013144779, 0, 
        0.12533323356430426`}, {-0.9980267284282716, 0, 
        0.06279051952931337}, {-1, 0, 
       0}, {-0.9980267284282716, 
        0, -0.06279051952931337}, {-0.9921147013144779, 
        0, -0.12533323356430426`}, {-0.9822872507286887, 
        0, -0.1873813145857246}, {-0.9685831611286311, 
        0, -0.2486898871648548}, {-0.9510565162951535, 
        0, -0.30901699437494745`}, {-0.9297764858882515, 
        0, -0.3681245526846779}, {-0.9048270524660195, 
        0, -0.4257792915650727}, {-0.8763066800438636, 
        0, -0.4817536741017153}, {-0.8443279255020151, 
        0, -0.5358267949789967}, {-0.8090169943749475, 
        0, -0.5877852522924731}, {-0.7705132427757893, 
        0, -0.6374239897486896}, {-0.7289686274214116, 
        0, -0.6845471059286886}, {-0.6845471059286886, 
        0, -0.7289686274214116}, {-0.6374239897486896, 
        0, -0.7705132427757893}, {-0.5877852522924731, 
        0, -0.8090169943749475}, {-0.5358267949789967, 
        0, -0.8443279255020151}, {-0.4817536741017153, 
        0, -0.8763066800438636}, {-0.4257792915650727, 
        0, -0.9048270524660195}, {-0.3681245526846779, 
        0, -0.9297764858882515}, {-0.30901699437494745`, 
        0, -0.9510565162951535}, {-0.2486898871648548, 
        0, -0.9685831611286311}, {-0.1873813145857246, 
        0, -0.9822872507286887}, {-0.12533323356430426`, 
        0, -0.9921147013144779}, {-0.06279051952931337, 
        0, -0.9980267284282716}, {0, 0, -1}, {
       0.06279051952931337, 0, -0.9980267284282716}, {
       0.12533323356430426`, 0, -0.9921147013144779}, {
       0.1873813145857246, 0, -0.9822872507286887}, {
       0.2486898871648548, 0, -0.9685831611286311}, {
       0.30901699437494745`, 0, -0.9510565162951535}, {
       0.3681245526846779, 0, -0.9297764858882515}, {
       0.4257792915650727, 0, -0.9048270524660195}, {
       0.4817536741017153, 0, -0.8763066800438636}, {
       0.5358267949789967, 0, -0.8443279255020151}, {
       0.5877852522924731, 0, -0.8090169943749475}, {
       0.6374239897486896, 0, -0.7705132427757893}, {
       0.6845471059286886, 0, -0.7289686274214116}, {
       0.7289686274214116, 0, -0.6845471059286886}, {
       0.7705132427757893, 0, -0.6374239897486896}, {
       0.8090169943749475, 0, -0.5877852522924731}, {
       0.8443279255020151, 0, -0.5358267949789967}, {
       0.8763066800438636, 0, -0.4817536741017153}, {
       0.9048270524660195, 0, -0.4257792915650727}, {
       0.9297764858882515, 0, -0.3681245526846779}, {
       0.9510565162951535, 0, -0.30901699437494745`}, {
       0.9685831611286311, 0, -0.2486898871648548}, {
       0.9822872507286887, 0, -0.1873813145857246}, {
       0.9921147013144779, 0, -0.12533323356430426`}, {
       0.9980267284282716, 0, -0.06279051952931337}, {1, 0, 0}}]], 
    SphereBox[{0, 0, 0}, 1]}, {{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[Large], Line3DBox[CompressedData["
1:eJwt13c41d8fAHAjGUkhGamIUBRJQ8WbKIUys5MGSZKMUikSsrJTtuxkb8Kx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       "]]},
     Annotation[#, "Charting`Private`Tag$3245#1"]& ]}, {
    {Arrowheads[Medium], Arrow3DBox[TubeBox[{{0, 0, 0}, {1., 0., 0.}}]], 
     Text3DBox[
      StyleBox["\<\"x\"\>",
       StripOnInput->False,
       FormatType->StandardForm,
       FontFamily->"Helvetica",
       FontSize->14], {0.8, -0.032009219983224, -0.03841106397986879},
      FormatType->StandardForm]}, 
    {Arrowheads[Medium], Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1., 0.}}]], 
     Text3DBox[
      StyleBox["\<\"y\"\>",
       StripOnInput->False,
       FormatType->StandardForm,
       FontFamily->"Helvetica",
       FontSize->14], {0.04192218081503186, 0.8, -0.02724941752977071},
      FormatType->StandardForm]}, 
    {Arrowheads[Medium], Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.}}]], 
     Text3DBox[
      StyleBox["\<\"z\"\>",
       StripOnInput->False,
       FormatType->StandardForm,
       FontFamily->"Helvetica",
       FontSize->14], {0.0439645983268387, 0.02381415742703763, 0.8},
      FormatType->StandardForm]}}},
  Boxed->False,
  ImageSize->{157.99999999999997`, Automatic},
  LabelStyle->Directive[FontFamily -> "Helvetica", FontSize -> 14],
  ViewPoint->{6, 2, 1},
  ViewVertical->{0, 0, 1}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.456546668111147*^9, 3.456570785278153*^9, 3.456570867237522*^9, 
   3.458994532649579*^9, 3.459442725428873*^9, 3.4610665391202803`*^9, 
   3.4613298050824423`*^9, 3.462005972747088*^9, 3.46402508709846*^9, 
   3.4648034505888166`*^9, 3.4658141278704653`*^9, 3.467015927324387*^9, {
   3.486708321013212*^9, 3.4867084083191347`*^9}, 3.48670860736939*^9, 
   3.486709667881331*^9, 3.486711409030736*^9, 3.486719490301263*^9, 
   3.496138766334634*^9, 3.496138858796566*^9, 3.497528388755845*^9, 
   3.497528564723036*^9, 3.497530309751252*^9, 3.497569397822092*^9, 
   3.49757425431621*^9, 3.497648486278508*^9, 3.499304091072824*^9, 
   3.5020111713027487`*^9, 3.502710931935869*^9, 3.5027612884245157`*^9, 
   3.5033071345110483`*^9, 3.507024639013872*^9, 3.507028318288567*^9, 
   3.5103183342257557`*^9, 3.5103183755623207`*^9, 3.510318704054532*^9, 
   3.511623936021759*^9, 3.511624492917837*^9, 3.513162389014975*^9, 
   3.515068491556682*^9, 3.515069499877452*^9, 3.533177706898944*^9, 
   3.5689042487713957`*^9, 3.571380524610282*^9, 3.703853701009019*^9, 
   3.7038538667689953`*^9, 3.703853930558875*^9, 3.7038563770254803`*^9, 
   3.703856751333495*^9, 3.703920725805293*^9, 3.7121510440761757`*^9, 
   3.7286341748379736`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
determine off-resonance and rf performance of a composite pulse using \
TransformationAmplitude\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707871584403*^9}, {
  3.486707939722651*^9, 3.486707945208267*^9}, {3.486708008593843*^9, 
  3.4867080096800623`*^9}, {3.4867081353531647`*^9, 3.486708140856287*^9}, {
  3.486708450441025*^9, 3.486708469102826*^9}, {3.497530345235826*^9, 
  3.49753035610564*^9}, {3.497530711879258*^9, 3.497530713197855*^9}, {
  3.497531178769596*^9, 3.497531184387055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rffactor", "=", "1.0"}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.486708520478739*^9, 3.4867085233037453`*^9}, 
   3.486708589447815*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"resonanceoffset", "=", 
   RowBox[{"0.5", " ", "\[Omega]nut"}]}], ";"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.486708575308324*^9, 3.486708585905423*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "CompositePulse", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CompositePulse", "[", "rffactor_", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}]}], ",", "\[Tau]90"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]180"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rffactor", " ", "\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}]}], ",", "\[Tau]90"}], "}"}]}], 
   "\[IndentingNewLine]", "}"}]}]}], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.497530482764707*^9, 3.497530508674776*^9}, {
  3.497531148861862*^9, 3.497531155714347*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ztoz", "[", 
   RowBox[{"rffactor_", ",", "resonanceoffset_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"TransformationAmplitude", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}], "\[Rule]", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"CompositePulse", "[", "rffactor", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"BackgroundGenerator", "\[Rule]", 
     RowBox[{"resonanceoffset", "\[Times]", "\[Omega]nut", " ", 
      RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.49753051909303*^9, 3.497530566348296*^9}, {
   3.497530934682315*^9, 3.497530939313788*^9}, {3.497530983395625*^9, 
   3.497530984921935*^9}, 3.497531115599064*^9, {3.49753152869057*^9, 
   3.497531531721751*^9}, 3.497574146426038*^9, {3.49757423804298*^9, 
   3.497574248706998*^9}, 3.4993041178933907`*^9, {3.49930415694136*^9, 
   3.499304164485352*^9}, 3.5020112213311872`*^9, {3.510318721491622*^9, 
   3.5103187272579803`*^9}, {3.7038545140759535`*^9, 
   3.7038545184377527`*^9}, {3.7038557602008905`*^9, 3.7038557603727827`*^9}, 
   3.712151038108056*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"off", ",", 
       RowBox[{"ztoz", "[", 
        RowBox[{"1", ",", "off"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"off", ",", 
       RowBox[{"-", "2"}], ",", "2", ",", "0.05"}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Medium", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<resonance offset\>\"", ",", "\"\<amplitude\>\""}], 
     "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.497530722589981*^9, 3.497530776904146*^9}, {
  3.497530964571458*^9, 3.4975309694972773`*^9}, {3.497531539633712*^9, 
  3.4975315399368887`*^9}, {3.510318747885111*^9, 3.51031875724479*^9}, {
  3.703854526296175*^9, 3.7038545266446238`*^9}, {3.7038548585048556`*^9, 
  3.703854858730768*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      Thickness[Large], LineBox[CompressedData["
1:eJw1lFtIVFEUhgdfgoQsE0xU1JAuFhQqapYtkS4PqaQPOYFOGmaJQSVSGJpi
iJVdtMC8UxJlEFk9FFK0JFOaMpm0DPGuk5eZ8Yx5T03Ls/6zYBgOe69v7b32
/y+fk+diTznodLqY/7/Vf0TDclSKS7DOTAFqrHDHNefAH7kjlKLGMtfeMuwK
emKh8rLV+Mvf0wuMOXvH6WvLaixx5kaPNyWOdhLcEp9wWig5r9jBW+SegYJN
Q8128Ba4sFZXU5+vgPeHA9xfRY/42cCb5/JJ7+1vm0bBm+c897pf6zK0883x
82JHw1xDL3iz7HvRozQlpx28GY68ZDqenPqeVFzLNGfNXg1d0/SShTfNVcaP
H/TbTCy8KW69e3vU4NbFwpvk0YcJwSUXBll4vznT4WxfVNUwC2+C+/OrD9Dc
GHgTrDwePtKeYUO+wkOu77zS3RTst7HL4VDKm1HYX61n5WMdDk65vnYuVflj
XBTd5K//rIA3yh698V5h6xXwhtkQkT22x2ccPDOHbI0s+rTFBt4QewcNFr84
aAVvgHfE+VWmVVjA62dDhSksYp8F+d0cr++5H+Fvwf5Ofp0YU+idbeFktV4H
H7KuDV90tvJuld/OWZ5lXyYGrOCZOCG4rzGuzYZ8I7cY7m1INY5jfyMHexVn
uz9TuEhdr+e8oRuTSpKdc9Xvp9z4Le366Z921gS4vLIadm6QdWrA+gPJJy0f
fNL4sm6kZtTH+SgR5wuR85N2/jNyP9LuJ/mdVIf7m6Q/pEd/0D9KQP8qpb+0
E/0NlP7TZvRf8s20H+8j9YYpCe+H9yVPvK/wxugm3l94VtJDH8KzkSv0IzyF
zNAX9Ec26K9V9EmD0Cf0S5p+JX+SuqBvqTdFLdA//EHV8IfwpukK/AN/0VH4
S3izFAv/CW+ONH/Cv5QL/wpvnh7B3/A/af4X3gLdwXwQ3iJ1Y35gvpA2X4S3
RJcxfzCfqA3zSXjLVIP5JbwVasJ8g/zCddEy//4BQsyRsQ==
      
      "]]}}, {}, {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"amplitude\"", TraditionalForm], None}, {
     FormBox["\"resonance offset\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-2., 2.}, {-1, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.497530738574695*^9, 3.497530778444474*^9}, {
   3.497530971303631*^9, 3.4975309888578463`*^9}, 3.497531568464458*^9, 
   3.497569427957933*^9, 3.4975742560298443`*^9, 3.497648487857974*^9, {
   3.499304092712047*^9, 3.4993041223441553`*^9}, 3.49930416924601*^9, 
   3.50201117176864*^9, 3.502011225876124*^9, 3.502710933391464*^9, 
   3.502761290744294*^9, 3.503307135921389*^9, 3.507024640887987*^9, 
   3.507028320145626*^9, 3.510318336398678*^9, 3.510318377709817*^9, {
   3.510318735708037*^9, 3.5103187597268953`*^9}, 3.5116239439754953`*^9, 
   3.5131623913863363`*^9, 3.515068494356966*^9, 3.515069502829047*^9, 
   3.533177717528534*^9, 3.5689042776240463`*^9, 3.5713805454200974`*^9, 
   3.703853705121513*^9, 3.7038538434593644`*^9, 3.703853879289714*^9, 
   3.703853960187394*^9, {3.703854259407827*^9, 3.7038542647986326`*^9}, 
   3.7038543389980435`*^9, 3.703854420073303*^9, 3.7038544673543167`*^9, 
   3.703854541506939*^9, {3.703854660176017*^9, 3.703854700468935*^9}, {
   3.70385482965044*^9, 3.70385486316106*^9}, 3.7038551063459415`*^9, 
   3.703855200650879*^9, 3.7038552805341635`*^9, 3.703855371286892*^9, 
   3.7038554136868963`*^9, 3.703855572951851*^9, 3.7038561771781693`*^9, 
   3.7038562774354897`*^9, 3.7038563810363283`*^9, 3.703856755374881*^9, 
   3.703920729941634*^9, 3.7121510537015233`*^9, 3.728634179361226*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListContourPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"off", ",", "rf", ",", 
         RowBox[{"ztoz", "[", 
          RowBox[{"rf", ",", "off"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"off", ",", 
         RowBox[{"-", "2"}], ",", "2", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rf", ",", "0", ",", "2", ",", "0.1"}], "}"}]}], "]"}], ",", 
     "1"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<resonance offset\>\"", ",", "\"\<rf field\>\""}], "}"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Medium", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.4975307872770033`*^9, 3.4975308229435883`*^9}, {
   3.4975308626329107`*^9, 3.497530906147428*^9}, {3.497530997434923*^9, 
   3.4975310473697968`*^9}, {3.4975312695089703`*^9, 3.497531270257689*^9}, 
   3.49753133859645*^9, {3.4975313727927094`*^9, 3.497531394277832*^9}, {
   3.497531460469016*^9, 3.497531464530632*^9}, 3.497531543600101*^9, {
   3.5103187776885347`*^9, 3.510318795014786*^9}, {3.703853748859776*^9, 
   3.7038537496349397`*^9}, {3.7038548661739097`*^9, 
   3.7038548753049574`*^9}, {3.7038549586046677`*^9, 
   3.7038549664209223`*^9}, {3.70385551077699*^9, 3.703855519799176*^9}, 
   3.7038555907047725`*^9, {3.7038560225866117`*^9, 3.7038560268532915`*^9}, 
   3.7038563717603807`*^9, {3.703856442094093*^9, 3.703856448581612*^9}, {
   3.703856546913037*^9, 3.7038565480098486`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx8/QdYU83zPg6DvffeCyAgNuyKDiKiWLGABRXEBmIH7CL2iqDYC4oiolhR
URRdQFAjoHQIzUDoNb0n/PN5krPne5b393L5XHvdz8zem0zmbJ85Q912Ldvc
zMDAYGs7A4P/lfq/WAPmX+yd2//7iwYmZmE8Yfz//jIIORtjXcEh9LkYb93y
v79yon4VxinJ//urJfh4hD6f4BcS9UVEexKCT0bwyQk+JcGnIvg0BJ+B9Rbd
/0eUISlM2ZOJWRhT9mTK2cDk4xD6XIwpezLrV2FM2ZPJxyP0+QS/kKgvItqT
EHwygk9O8CkJPhXBpyH4DKz1etieFKbsycQsjCl7MuVsYPJxCH0uxpQ9mfWr
MKbsyeTjEfp8gl9I1BcR7UkIPhnBJyf4lASfiuDTEHwG1uN19bA9KUzZk4lZ
GFP2ZMrZwOTjEPpcjCl7MutXYUzZk8nHI/T5BL+QqC8i2pMQfDKCT07wKQk+
FcGnIfgMrPU82J4UpuzJxCyMKXsy5Wxg8nEIfS7GlD2Z9aswpuzJ5OMR+nyC
X0jUFxHtSQg+GcEnJ/iUBJ+K4NMQfAbWel5sTwozxyMZtieFmeORDNuTycch
9LkYM8cjGbYnhZnjkQzbk6nPJ/iFRH0R0Z6E4JMRfHKCT0nwqQg+DcFHjUcS
YjySEOORBNuTwszxSILtyeTjEPpcjJnjkQTbk8LM8UiC7cnU5xP8QqK+iGhP
QvDJCD45wack+FQEn4bgM7BO1rWL7Ulhyp5MzMKYsidTzgYmH4fQ52JM2ZNZ
vwpjyp5MPh6hzyf4hUR9EdGehOCTEXxygk9J8KkIPg3BR41HQmI8EhLjkRDb
k8LM8UiI7cnk4xD6XIyZ45EQ25PCzPFIiO3J1OcT/EKivohoT0LwyQg+OcGn
JPhUBJ+G4KPGIz4xHvGJ8YiP7Ulh5njEx/Zk8nEIfS7GzPGIj+1JYeZ4xMf2
ZOrzCX4hUV9EtCch+GQEn5zgUxJ8KoJPQ/BR4xGPGI94xHjEw/akMHM84mF7
Mvk4hD4XY+Z4xMP2pDBzPOJhezL1+QS/kKgvItqTEHwygk9O8CkJPhXBpyH4
qP6zlug/a4n+sxbbk8LM/rMW25PJxyH0uRgz+89abE8KM/vPWmxPpj6f4BcS
9UVEexKCT0bwyQk+JcGnIvg0BJ+B9S3d98D2pDBlTyZmYUzZkylnA5OPQ+hz
MabsyaxfhTFlTyYfj9DnE/xCor6IaE9C8MkIPjnBpyT4VASfhuCj5kvlxHyp
nJgvlWN7Upg5XyrH9mTycQh9LsbM+VI5tieFmfOlcmxPpj6f4BcS9UVEexKC
T0bwyQk+JcGnIvg0BJ+BtaXue2J7UpiyJxOzMKbsyZSzgcnHIfS5GFP2ZNav
wpiyJ5OPR+jzCX4hUV9EtCch+GQEn5zgUxJ8KoJPQ/BR4xGHGI84xHjEIcYj
DjEecYjxiIPtydTnYswcjzjEeMQhxiMOtidTn0/wC4n6IqI9CcEnI/jkBJ+S
4FMRfBqCj+o/2UT/ySb6TzbRf7KJ/pNN9J9sbE+mPhdjZv/JJvpPNtF/srE9
mfp8gl9I1BcR7UkIPhnBJyf4lASfiuDTEHwG1mN1dsH2pDBlTyZmYUzZkyln
A5OPQ+hzMabsyaxfhTFlTyYfj9DnE/xCor6IaE9C8MkIPjnBpyT4VASfhuCj
/JNF+CeL8E8W4Z8swj9ZhH+yCP9kEf7JIvyTRfgni/BPFuGfLMI/WYR/sgj/
ZBH+ySL8k0X4J4vwTxbhnyzCP7H9rAN1dsP2pDBlTyZmYUzZkylnA5OPQ+hz
MabsyaxfhTFlTyYfj9DnE/xCor6IaE9C8MkIPjnBpyT4VASfhuCjxqOmf8zx
iML4/MiAOD8yYI5H1B+H0MfnRwbE+ZEBczyizglqCT4eoc8n+IVEfRHRnoTg
kxF8coJPSfCpCD4NwWdg/ZCwG4UpezIxC2PKnkw5G5h8HEKfizFlT2b9Kowp
ezL5eIQ+n+AXEvVFRHsSgk9G8MkJPiXBpyL4NAQfZU8WYU8WYU8WYU8WYU8W
YU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8WYU8W
YU9sP+spxHNLYcqeTMzCmLInU84GJh+H0OdiTNmTWb8KY8qeTD4eoc8n+IVE
fRHRnoTgkxF8coJPSfCpCD4NwUf5J5vwTzbhn2zCP9mEf7IJ/2QT/skm/JNN
+Ceb8E824Z9swj/ZhH+yCf9kE/7JJvyTTfgnm/BPNuGfbMI/2YR/YvtZU9+b
2a1ygDkecYA5HnGAOR5xgDkecZqUxPoIiPURMMcjDhDrI2xPpj6f4BcS9UVE
exKCT0bwyQk+JcGnIvg0BJ+BNTnuMvd96XGEsieFKXsy5ewmdmPq0yVlT2b9
KowpexL7poQ+n+AVEvVFRHsSgk9G8MkJPiXBpyL4NASfgbU7MW+hMGVPJmZh
TNmTKWcDk49D6HMxpuzJrF+FMWVPJh+P0OcT/EKivohoT0LwyQg+OcGnJPhU
BJ+G4DOwvsd4zgwMKEzZk4lZGFP2ZMrZwOTjEPpcjCl7MutXYUzZk8nHI/T5
BL+QqC8i2pMQfDKCT07wKQk+FcGnIfgMrFOJeTOFKXsyMQtjyp5MORuYfBxC
n4sxZU9m/SqMKXsy+XiEPp/gFxL1RUR7EoJPRvDJCT4lwaci+DQEHz4/arIO
Ic6PiPGIh+3JlNPjMGVPst+jMHF+RIxHPGI84jUpifMjYjziEeMRjxiP8L0I
gk9O8CkJPhXBpyH48Plmk3UcZU8mZhHjQAYhZxPfk0Po0+MIcb6J7Ulh4nyz
iR3JkjjfxPZktich+GQEj5zgUxJ8KoJPQ/BR4zu97mV+rmjic7KIcTSDkLMJ
P+EQ+vQ4zBzfhdieFGaO78ImfkjakSyZ47uQGN/xvRyCT07wKAk+FcGnIfgM
rP8wngsDgz+M3zUamJiFMWVPppwNTD4Ooc/FmLIns34VxpQ9mXw8Qp9P8AuJ
+iKiPQnBJyP45ASfkuBTEXwago+aL9H7Lu6M54KaL0mwPd0Zv3MGIWcDk49D
6HMxZs6XJNieFGbOl+h+j6nPJ/iFRH0R0Z6E4JMRfHKCT0nwqQg+DcGH79c1
2cdijkcybE/mc5JByNlEP88h9Ol5NHG/jhiPZMR4RI8bTH1+k+eWWV9EtCch
+GQEn5zgUxJ8KoJPQ/Dg+5/EeCTH9mRiFtHPZBByNvG5OIQ+vQ4h7n8S45Gc
GI/ocZccN8h+j1lfRLQnaWI3Jp+c4FMSfCqCT0PwUeMRvW/K5IkmeFlEP51B
yNnE78oh9Ol1HHM8UmJ7Upg5HtHzFnLcJccNZn0R0Z6kid+RdmPyKQk+FcGn
Ifio8Yjed/7D+B2o8UiF7fmHwZtByNnA5OMQ+lyMmeORCtuTwszxiJ73MfX5
BL+QqC8i2pMQfDKCT07wKQk+FcGnIfio8Yjet3dn+DE1HmmwPd0Zv0sGIWcD
k49D6HMxZo5HGmxPCjPHI3rezNTnE/xCor6IaE9C8MkIPjnBpyT4VASfhuDD
50dUSf1ZM8cjCrOIfiKDkP8/9wHJfSxr4vzImjkeUXEn/891HLkOIefR1sT5
kTVxfmRN2ZPJ9//sB61TCD/c+v/fjrHa//xCOP9mUHhJXVqACbuG0o/lFcUc
HjqJjqc6HLxXGs+m46n27DriP+oMHT+VNJx73d5aCG2W5vmtTmhEhTuP/znm
SMdnmVZ+ONfltxjKJ53pP/FtI3EfxCA2ZnGLavEgKRwoTh/g1K0R8eOfTH1h
VI/lfhPM9k17JoP7xZbt4Ckdn0TJh/dtFKVoFBhbCD14p4014MLvqf3XqNc3
MJBffH3zklMjCjK2H2fC44E8ruM1x3MaFOT8dFTDUB4Iy9oU3hTS8U6zHrT2
eOLciHzSp93LvSyAGOMbXtveaBBvFSvsPpcPRq37r2tXSsdDCZTP528uakTo
1/7elhEiODlt4JHlsxuRQ+vqeUO6iKDHwYCXs8I1qGTO2kOdfITwwWTVGPdY
yh7a58t3fobwDh1P1ez++m3BHxqRR/PE1BYDJLBs8Lg3v/o3oujTN3uNOSGG
xyHNJYLjGtSuzba1qytFsKvzmLOFGxvx+a7S0+ikxfVGpCulsGzO6ZCLNRq0
/L9SAvM793+ys7FpfJaLW6ai3VoeBFp2Dv10uRGZJ4fPWGYqhxZxQ60dPmpQ
8Jov7CoHGWT+HDdo7Iv/H/Fcn1t9X2YvwPhBd1fPvG9CsM7bPeFvRSPy7hi6
tVl/JcwQcJ9IL2rQHuPebHMkB5vlH+aO8GpElH9T9UP+9e8+aQQdTyY7d5Xv
YSjG2GvfmKHn5ksh5c+kxgktG9Hdu82TDdPp+uU+ucUuB+nv9+hNdxPxDzk0
SzjQy1z7e3mY/zsSaKuBQpX9mppSyn50vNmKO33f776qhLxhNhvMLRqRvoR+
AZOe+hXT8WirdJ9bh281m2E7wbHDgXg12r/1HESIeRD/dvKLnONq7F8+n08v
bSNQI5uzywZlfRNAcKD92u8j1MhzXS+zQBEfVkVEf/R6q8b+1c1/RfmOEjU6
KPy8MHOeCM59a7E2YpYaNRh5xncNF0K/U4/nHT+lxv4zu3auMnuuBtn+V0rg
tMibjaLV6Mx/pRh+qUI+ho9UI10pBruvuQ0aCzp+z2fY+n59hqkxHpnT7cTZ
zhqUuPtF/6HPpGDre2rbZm17Rb0HtWgcKIV1xpJls+UqJP0WUFtwVQIeBl1C
50SqsX/tNYxfuLdIjZ5MEB970lUOFt+aW7axUyMX/qTN07W/j7Ckx7kPpmpE
zAvRjvN+lgduCTA2PSm7OXehCKSv7eqskRolHun+ueMlBbANZIfPaVQoLCVh
nmMSXT/ceOzZsJtijIfY5eW2YEkxVrt8qpsbI4HopKOpl/+p0RDL0kniOXS8
XNFJ61m1GXS8ncss+0JhNzq+zinnWXfDCro9Y4MM1wG3VPBc9z1039+VZ2X7
3x8drzj+//qLVn7ox7+NSXtVqNjC7vc4tgB69y/lpa6g4wMrLHaZ7zynQpX/
lSJ41Ph9DfqsRI//K4VwzODgp14b6fjBY1u83F/bKxA1/m04ta+0q1auHNjF
N0IlBrX3xDevfirRzU5/7edtEIP3x0lZtr3oeMP6wvQNXc4qUN1z38/eSwoh
8wHHPytbof/8HHgerDnm+FaFCtPGvTtXKoWM7Dafeo5UodbtrGrmrZeCqlN3
XlaoEo21sRveNlcClSv6zjl7i45fnDTN4Fmb23T8XXGftNwHxQoUqNnp2yGw
BNLyWs0NESgQNT4vGePt2ma7Cg1QWY/KmiKH5K1hX+5WKdHtCV7n3KNkYP8w
t9eYrUrUa8cTrnK8DMqeV9f8MqTjI2vt6mYt/6NAuf55J8PuleF4vT5HEuNr
I0Vg3iau37hkBb6Pw+m2xH/bVxWae/CDMHW4Eg443Gq3fLQK/YvS7I6+poAu
l4vPTn+gRPtFc+tDWirgcqtRPh/C6fjLho6WYsPVTeMHnR0H/347SgIvuK9P
Ka8r0CXFVStzl0osF9wIKs13lMINd6vGSbuo368Khh28OiXuvQrpSzBN4vaa
pVEifQmjB04Ux85VojG6EiL2LFz5/AId/0nxd+vMmn9hLR3fuPXI20UrNsqg
KLOHb7fZCjS8S6DbxdpqLH8zO9C01FH7/eLC+n38TccPDmyBFlWolejj/VUV
fjfVWL/Zrhaps/bS7fV6OU/gu1wJKy/NfHQ0To7sInsVXRtQh+X3FSr5mQI1
tNP5gc4frLlWd/7v8/N/cNjsl4v7tsyGpT/yH31g0fF9f/Nu/EgcqkQe3mNd
Xb6IwGPz+5/TBtLxnw4bvYO/dlOiUzeepvHmSABKeuWsBAXy6jm/3cW9Yujz
bdW/5wZ0fKig4syxwI90fKPLz4Td5XV0vKChWTH3fY4C/RG/fHM8VAqPw4xG
X9Py7fbiK1w7aPtHI/cDXk/lqCt/whxrbwmYm6CwLVcU2N+p77N2wNpPwT51
YKc2HqoZK9f6wwIb1YYS2Fx39oB8NR3fGWKX9t6vuxK1eTm5f8VBObxYNrXl
sKsK1D36gec5mQw+rg9x/N5FgQYlto4x2y+D9ZkWO3qIFdj/vy55e+CClI7H
nPFV1vfEcjl69dJo6+S8MjjUs9PYW5Z0vOPV87bCTWvpeNJ1GtHaR98VaL2u
hElek19VzlGgyboSulQebBz9S470JXwJXywbaaPA/v8Qdvd/ZS5DYWV29+O/
lEMNCltRZixHM8rfdR4XWYnt4fh09F9XbX9C4Q6bzyK7MxLwH3Ct2WVDOv4y
+EQHj7o+dHxr1YahjSNaK9FJ5edbcQ9VkDV8muTZYQXa9TUjYHZPFcSVLasb
yZMj52O1ZxLPK+Gw24dD01iKJvGnEZvWTlwqlEGa68gyS217M5x5GxvvVsHs
6c1C7+fK0JAuwcWZ82uw/t7jKZWb8xQYi1Qhuct5cnjv02br5ht0fGjz/nvc
Ooi09loceh1GaOCvXc2yETMVqNmhQWfW7FHD/vh+9RknFIjY/0CLgt51aB9F
f75zlvkPV/5Uwkb1jf1ZO2Uo6Kfiy/7ndWA9aunXTrZytHDErrnVKxqw/ifb
ZZOHp6iB07VFszld6XjfD5d/NDYfoUAnnIOSU4V0ez+3tS17aNQIk85Lz838
LUO6ko5n1c2y86y677zTLKh10/jW9X2fKfxnpsGzNsvLZreSodmPan0LH/Dh
fI1m2NRVUrSqeDTqfS0V6/8u3t7oEJWH8TiDWYdnzuPC2FiTec3fSRFz/SZD
cwevM1M9qoJug9HaZWZS/DxaXDFTfT0nR1elAW5GDVJwDElY1e2dDMW0HokO
9JUCrzA5KdKXjk+eeYGdEm3WNL62rvsZVvrgBqiOeNcmSilFrS/esX1gzoW1
j288H/OUjmdtEWfgvE8jxfj9ruSHFdPlSF9C/n2veZ2fypC+hGbJ/XiTusmQ
voTHA0rlFnVN43lL/w5JHv2YD1Vxm6zsIiVoWvWYf4LfXHAtWbTvQB8pfh4n
Pju05aOHHP216WGwtLkSNi+ftcqvRoYaa/P4fU8r4Ia69Xz7HTI09mYIt6SV
AiZHP78fOJmOv97yw9rUdCIdPywYsyHxUisp8pM7G70Lq4Dgd2ijpr0UP19P
RhyFRH85yl3zZq8sVgU2uzfOfaP1J5/HNw5xbVXw75P9krvXZahb7ZETf34p
4Yjh2JVn+srQ6wkbL0Qv1K7/N82tLPel473XCTm+BVuaxisf8bDy4eyg7fEu
12Je6QgZqIZFNz4vl6DEbpA87E41mIz+aP8lVIr6mU13nd2Ljr+eNGNh8+m7
FJDHtX7m9YSOJz776WeXoAApxqmaafM8F8lRcFLrnlP6aWBv9KO9QbEyBGd2
gau/Grp7t7v/ZbwMcaxzPM4ZqMG+1HnIybym8dTGZrM/ZgH9+Xu367mkzQYl
HEuem24cJEGaWwGhC0zqYJpgbsGiqVLkUxrw6e7eepD0nlfu80+KasYEJtd8
a8D1m2WcZHXoSPNvHHDgWeYwNbiHb/A3yafjoYetGR3cLlWKcZ1f57DHE+Ro
eYVPh3Z3GyGmwXGbwEeGhjvFpK4q0ECntvVqT286/pviv9Rv+4SF/Rrhr26c
1MsTrR6I7LX/pHi+2ur97tdfP0jQw0Xt7Fcu4cGGdT2+mq2VIqXkpdN37fqm
7Oe0vlDaND7bYRrbI7oqBVrasfpYxEjQ1IOqBS4NfNh2NupusJ8UBX+u+pP2
TgB7TnHP3Jc2jedesrRqT82KbPjj0nx3lIUYhY9b/K78VjKWvwj3DUkdUAh5
V/N/t8uQoHCX8Js5D+j6tv4z3k70KIEXfa49G7BAjN66OYTttciC4rbcD5zm
YtTgL5hR5ZMH+475zarqLcb9CVW/S/McOzNuHcbT/tz6+vULD7ImjjQK6i/G
z//oPe9n9SiVol/tFue/PCqHsL0/zKu6S5F1B9eEEy9lcDiTdXV8mhQ/7/bW
7i/tvZvGn+eyFt0YBAJY6XjAfZezGNnbXth2wKEUy/3mRJs05grBW33rX4pY
jPuDyda8pRP8pcjTa/jprbEKWHW475uXKgm69GohlzNGAYeibDqN2C5Br6p8
Zq15IIeuNmbsgCFS/Pz7H1yeMFsjRpXIy3EFqxLa3enrcLSbGD//oarp3Qy6
0/H6W+Ne7Xd6q61/+bDtcF8VNC9uPqDZRClKfZla+cdQBcEGq2NffpKg7SnG
/odOK0Hi9lN13FGKn/e+pSdrXFpo7ferdQ5qUw1j9jx4UJ8qRq4lM6EwpAZ/
31krLneJ+KPAmBuxfunOJ3Lo/DQnb3YBHd/+/P0M30YkxvhKzbR4S+3zIVsa
Ynp7kgaWrPPdV7pMiqK+lxbMj1ZDx79x5jeyJMh7oukV1XQ1vOrp9arIX0qs
/yWo4+HHy39H0vH/b4+/vCJOUsLvhMvcczki9CvGQWFbUgtHd1+bc89HjMb0
WPvNc1A9jBtw5+lrrb1ueG49cXVNA65vklDo/XkjzW+192j5wEtqqJk6I+hP
HzF+np0XzX74R0jjgN2+NmcvSpGubITaVE1NB5kE6UoNxFuEPu6TROcjwP7k
5NA4waERBmbO0v4T4+fZqNI5JVQtQqv6BxjkjuVBM4txaa4XxGiSy6YW177y
4N+uVlkDektQ98dT2zjM5zPj8/3ira6HhW0DNZ0/oPLLibGzSsUYU/rzim48
DfmbBL+fnnGsqBahW97Lh73/yIc1ZVab9hwSI9PItuNmzhVA9TDhXmVbCfrU
gOBXtgC+d67rdvqDGPcHFJ/pcu9+Y7ZmQlhvj86FHkI0+eu8w5WLk7DcyDHk
9dHF/zAO2iYYjoRsGOa/SmbiIkYXhN/W+ycKwXzm9Hk17SXoamjIq6V7RbCm
8Psi/k0xXi9gvhnOu7cHl4BxgGb+ibVCpHrkenVXbgbMyf7h9m4lna9hhzN3
secaMdqpK3H9bUUr54YUlsPcNps+5F4Xoeq6tY/GGNGfb9Cgc97yvnXwqPsT
aehyEeLEcs9xrUuw/M+o5W/UR+h8DddVr86F5tL29ZvR5d2MlrR97JegiV8m
i2BF6uJ+5Z/o/BDFHQNMTxhJ0Os8Z/FivgL8fJ9EvNkgRosX7D1wdLQCTGuF
eY4NYtwfUHwxvrlOf++IgWN74Ky4mM6HYOP9kfPGSYKe5Q2c2/urCl7viLxh
lyRGvTL7qF+MU8GArS8XFoAYnUzp/s4mTAlLR3abf3kOnU/DOHR6atdhYozH
jI6QJ7OEKCjgvEnKj2rc/m9bwyWacgXMGl+51zmXzr+gWvHRpnCTBKn/KzVg
WBlwra5SjJr9V6qh1WH3cvV2MWr9X6mG9p1mTenEF6EO/5UqqHT4ZZ3lRufz
GOnxcbzURowx1b7T46LUb51V8M67qGF8qLb9JcPt/ryqA+nT6S8ea39/x6jC
by97NmD9XS0S8/uWqzG+d+Xe5P0d1LC3s+nkRYvpfBE1Ey4p30+k83Gc7mwu
aWgpQYOffQ84/6ARZj6YIWx9SozYU3IuhQxsBNnopbzBzcQo6Ff1+ei7Glg3
vbesdBd+nnH+ER/J15E7gxpx+0OPDikw/KaBMYrLRu9ma/33hzP/WBft/KFX
mupaqhA1lNxnbbjPgx6W3bP2rROhEs2/kNnmfLD8fPn0wJl0PovPcd7L/w6g
n3fd+l2IXOeNcqsZlAQ/rGTOB6YK0ajH6+OLtPP9m/Z27E3RQqR5/QKSBgvA
3ema09KpIvQ3RhHz8YEApm4syZgRLUIhrHnTQgcLoV2MssvbL3S+DIsBXwuv
hdP5SKj29r/t8eRUYi7GdSvYgsOfM6CT3KVxRDofTbme/LPD+iQsbzP5+svM
I4UQuTPn3SI/IXqnK+Fjus+Awa1E6JOuhJhJPU7zLorQV10Jn2qHvQmdRec/
ofg2nXlRXjy4GJ4/ksDWRgHav/JpssfvXDgpaTa+TwIf5YTl3hpVSOcfaRM4
h78inAsH1zw5eEdr7x6imd0nbBPDE3/77u/3i5D1CO6LRV0lsEbNW7BO0DQf
yLRp7NQ5/8qh9qOnpGWQAJV1K+mw4Fgh7LvUnxsdKUTP0eJedWUS2H9hf2qv
vgL0pfjLDoWGzm+yNmBLaJUFD5xyv7QdYS7A85Wpejk1/6D0Z7nsGT39Kf37
NjNRvHb8KsA4xvr0hvvf6d9jYZuIvbO+iUCmHrY3pliA+xvJfYkxN0CE1rdY
d8leoqDOFdFdfXvOvramW3eLiP0xrf+4nPcI/yPG+NcB+c+EblK4mfFk+epZ
Atz/7HkqiBm/RIT2/leqoOvtCxci7gtRt/9KJdz+GOacmd40P8oNffs3jhcN
iXMSoCCP4eGV3WuwPFgvD7rkt9jnuQD3N99XDLy19aj2+9RHjTPsrZ1PVDd/
ES0RouqT9+csD1RDwbFq1H63EO3re2r1k7Zq+KlK4HbuQ+e3ofgXXDrqMbat
CsZdG7Zp/AoBUsUVbTCwqcfy5q5LI4+b0fpTTRYFOkxVw+fdX8xKxgtwfzFV
ph74+5II7Rg5bqkaNcL1G/5PxJ1EiMWKzTW1aQTBhIGjhl4RIhN3B9cVCRpY
il6ffTqyaX6dZg1jZivSG3F7l4ON5k9r1ggtde3ox/t0q0exyxdf5vNRmxGf
34tW8uCTYXYPzxsCNNjd6nCaigduMevfRdsKcP+gL9HTO16SY55JMOTvE+51
IR/pS4iP6tzba78AfdeVsCn44HwHpQBt1pXQ/dKNy5ML6HwvpW7yhf1TBBhT
/PfXaGbMTs3F+Nenf7v/aZ+/9QN2bJ+8lIcuHGmmXjE8Gcs14jv/2i8ohPN/
s79e+cJHwz12rxzpKAR38ykOWycJULOEtCqDVCHMPX27xOqtABUPGn8ke74I
TDgK724WQhR78FqnF4kimGS6Y9HVIQLcP4QNnG8z3IjO70O1l+LYbuSQlnQ+
nDYaZdTKbA7kTuRl9dvOR1fbiS4Ec3NheFK2mL+Ih2JdLrdTbsvE+vkvy0J3
7y+DkErf6HXz6Xwxoz/VjSsu4iO3miGbe3QTg+/OgLwBmwQoMiS+o8NNMfwx
GndyVZX2+6zaFHVxgATU9afOdzomwP0Lxe80uG2nN6cqwTbx2J4YAz4Kf3XL
5eK9Qkh3s26J2vAQ1+juq+sxbPjmwvey7yVAFy2+WffiSuBV1KM1xT8E6MjJ
XSNeBUmh7Yo5O4/y6Xw7Kj8zkz2n+UhmuHxhSTsuFJ8r40kDeSiua1Jxw9Bi
3P58dUhBnAEfvqRP+5EbQ+e7WdiyetjGTD6K9HQ4z5pG5UsQotv659OC6L8o
PvXeVixPVwGsnXDuwtfRfFR7d/a8V4Fl0HNc/4uC7jy0/rqHfR9n+vfgFfe8
+dqL9qcR/W0uFq2lf7+IZ2mFk23EGFtvT2rV2kgCySPMYmM7a/3pw6fyitOV
WL7VL3LMhmFScOBEnzgbLEDVB5cPGDpFux46e2fRiRECYr+RjxKbP5MGz5VB
YXg/VJ5H5++Jyv202K2dEFW1rz1+fYYGakanq908BGiQW8txN+6pYfDpmhcb
f/HRsk+DODeUKhgUFPJzR64A9zcL93KTbR/y0Ka3QVucOtbj9rrkfBY729H5
jOTT+t5IG6oGXje3PXN+0fmCxpVnuMX30o7fkQ/HBHAbQbFzzYrSqwL0c/qI
oW9dGiFeypnTqrMABSS87JaRr4EPL/32l9UIcP/yZP7CB/ND6HxJVHtRi4z7
fTVrhJBO1Q87VdP5kxa5rlv2eCsP6UvIB6tG9hKt/+tK6t6KXj/TSrzdYXur
sXR+KErea5RHpP2JZOCtgXCDy9rnX5Q7684IAXz9dsN+jhkfrVw1llsULwD+
j529+qQ0zX902Skqq+FuJow/2aW16ksdmuwVfsLJKQXLjyZdOvB4XBHGdy3m
C57FsSF4fOC4D2t5KH3L902VAUKotj947EgBDw08+iLydWdtf+HqljJ7LR95
BF032B8ggldeix8vbEXnW/raetak5F50PiuKXz39XlQ3KAaxtY98bHodOt3/
1CXljCws931/V+B5tQzje3E/wiZq/dvp7ZzEvGY8NNy329Wnf0XQ8salw06+
2s/ntnre8AVieHcoY1y6nIf85j7UBP8Qg5tLv8pFPnw0xqLifT8bCeyyXOs2
uQed/6nsnccd41l0fi2qvSiTBbPO9q6ElhmqNNbMBtQuTP446GgRhK8LWtJr
Ux1a9sXkgcWvPKxvnJ86OOh4DTjEDt50tC0PfTQ585u7SwKRMHxA7A0e6ht2
/oSJWgI9kElmMyM+OmzsP83jghQ6Z9V3+1//SPUvs888uOy9ox7tj06Pe/qw
GPOfPH87l7WSD7d6TQx0MuUhXSkDTl5RvwsSHtKVdP6qmjs3f4VlCsBzv+Hf
eWsaUHrh1omvY8vAKOVRTEFwHbo4vu3w2S1LsX6/+LtLvxfT/rJQFtkvNI3+
vazltpqOj8Vw6v2DewnZ9Wjw4qmT1u+uxHJHx1Wz+/nQ9lN862knXiLF+Nvc
qHUpk+nPd5Ez9HZHRzlIO28UuSjrUULBmDiLXzVwcF/v+hYn+MhudunntMUa
uLLD9ean59r+bdqoTaf3q2Gy4ecpy7byif1K7e8fcqBmcScN3N1ocCC4DR81
+72lqMUu7fpi/9T5Y7x5yKXowZvreRrIy7jcvGEUnZ+Lqn/wtcfheyMa4VvJ
SO2/evz88p7U7xzxvgFdre2y9KUXH16fMHONedRA7AfUoo7N9zn1GPoHHgzt
LnldVoeaJ1iNbm8igEMLjbp0u9SA9qyeM91KLgAL0zeN0RYNxPq/Fi39fqvu
Y2wW/EusLnzxrxpFzS96Xv72D5Y/exk1wyz9H8ZGEf7rjvTLh5HPDx18ElWH
uEMvnB8cLgSPhsGl34rq0YmEgpkWViJYJRqdVnmqrkm+rthnostnu5bA+uCU
g3d61aBvVneFE0ZlY3m04UPZHWc6f5jL1Jeo8+RSSEuw+drQow79/dV6ThFP
BBeMYt2fda9HEQd+9Ju+Www2p2b02NitAZ0zPc272SCGL+UfLYa+qGuSH6zD
8avz4r9VwrHt1xa7RNeirRDQ3Jj9D5QuNnPORlcjF5Manjc7n84XFrDKLyK8
BrZ69pC+8KHzn81wjT97d0QdGjy2+HtKkASm3047tVL7+wUnu8dH9JTC1HTO
8e5jGtBAD17s+ZtS2Dwv63j6yzr8vNlsuyUdwa1Bz1M16y7bl8D0N6Vx40ZU
o8e9Fpje8ufAwImBQfmj65DZ+w0bW4+TQflxRXjs7nrkn9erXp4mgzd/Nn17
EtmABAbJB2r3atcbJ0Uzuap6PH5Tn//G3nWb/qYKYPKZewNPJtSi9MGTPg5Y
Xw6mVZmyNYNrUMKJnVdFn0qx/rc3di+r24qgTezUnd1e0PncDgf/cX5UV4f2
nOi3oYW5Ausfta1w/N1GjLHX076THhaIofmpMlWeRS1Kc4hkPZVXwpwPRZaz
d1Sj7iciGjtPq8D6LQ03D9vxgv59WEZJhz95S+HBDvmITtOr8fqEkv9WfRKV
zqHzu9n/Uy1yGimHLvG9E6Oa1aKuuhKUhi6h65KqkFpXYv3C5MxB5osVUCFt
H/d6ewNa41Zr922ABmyGnOnmxa3Hz7e86+GTkYn1SH3u6yy2WyPM6v463Myl
DoWcX5l57bUGwtQp7Stq6PxwFH+bxVe+DeHQ+c5Csip8gx78hceiZdnDp9ei
wXMlH9dXC8BrbZxhYEINfh4p/c1LU18/KM6GPKMxRnZVFWhHUExgnyd/sXxP
79f3PvoWwN3o9lvHzapGE2fX9m08I4TZrjfMvsbUoPM3xikTbLW/366Zw4NW
VjfJ71Y8Eqasb03nl3v7bvEM3y8cqPUVdPsxpxLZbFpwScDPxvKEAMe4wTPK
wOHx3dF7cqrQs7RFNz/ViGDCz4kzLMXV6C73zqDbh8TQp+bvAmG3WuQvrnhy
sK0E9h4sHrCKU90knxznSoGyq28F9Ox9UjxaVIEUivSP5h8KsLzex+jVx3t0
PrsROzspfuVUwWKTrI1P21WjeItTC+qCJeDOf77jcZcatKTbLoeaoVI4EeO3
/0GvWpQvXe1YFSoFm9e20z+9rsbP213JwTd391ahyYHd50/swIX1LWuHhm2t
QPLg01/AsBhqika3y0isxPPleQ9nlicaVKNVJ5eZ3Bgvg4Z7YTt3DK1BL46f
qa76LoObtztJe9jUosZjn1/NWKFdfyedfl4trcbPX5cN4fuvhlSiolE+ti47
y6B8ZfGq1knl6L3RK+PMm7T9z0kXBGb8EMLeieJBa0dWo7Nb5xYcKpHDvXtW
P5bF1aAB/WvG7HupwPoT/R3i9mno33PZ3fGjBVwx2B5uUXxHXIHm6EosH9Qq
JST4C21/l/UtHfodl2IsuLjglY09nd+vtW+seGovOQwal+TL31eFlm/SvDV6
XgsDB37eKdlfgZY61IWYRVRj/dOGnevN5XQ+wEnHzwQ7NVdCvw7bsiq70vkJ
fyUarpi0ukI7H3L/fA/VgbrTsIFf29agviHmpgcGNeL6i0u6lPvcaYSZut9B
v17OtdLtv5cji4AdN+bn/sX5774+/XG72awciLp56llgYCkKH/lvb+fOtHz0
Qc85XywKwXtg2u/XWvt8uexelqOg8/XtHtFj/qLpxTC6uPmtg63LkHlApgrl
Z2N5cf5NztWedL5AD9W7WfYfuNDQ91yWp18Fuhq27tTf1WJgrQgzqsyuRI3f
ayM6tpQA7851szta/yLz/6UX/Pj5+3Al7Nf8s+2MSpHRWGHM0rcFWL7Askd7
g7Y1kGCQ8TD9dTm68e7eyQEXJTCv8XrLdr8rUK6lZuKUPlJIVq/aNqu0EvWL
dKlc/kQK5uEb4545VhD3T8uRifdvb5NW9VB591T/fuNLUZT70sryRg5Mc2Y9
GPq2HG079PbeOmMZfD3bZ3+rpAr0osvqNg6RMoD3WxfXaPnrwgy8bUAOXoVm
zSN6VmD/Dt8+rXx293L0TFfCiob14XdCuMhJV+L2+6GHYU6+Ihi+51lyv8fl
SD7oS7LwoxxMXsWt7NpYgQ7PmNutYbMCzGvYJa2dtf21c8bK6u5KGFrYN+jz
tUri/mo5ettph9w/VGvvruPDvq0tQ2rbLWx+QCXdnkn1wtS7tL0bau5WDfKQ
gvynvIG3rAKpuar9B57RfLe+n9nPG0/b616f5m0LpDKwqvyVI6ktRaGLx8xc
t7wGy61STx09G0fna1wy+6yhe5gC45mdlCp7pAR3ONYY1FCKmrP73B51vh7y
z8r7tKmtREOlr2Hys0a4cO3Zz0eyCjx+eDu09nHQ+h81/2PkI/TLsqJwD++A
p4YD/uB8hUZ11hvzZ2ZDj8vDW169xUE1aSNeFSuTsHzj6xNPOEsLYMLSJQ/H
ZpWhCTZxVeNOieDnfC+bqLjSJvkV/Vuf4yVJOdD/gfuh5DgO2ranhWlyVCaW
y7nWWX8c6HyPi0ezf2Q958KEUsfGtoe12LjI8pN2fuZmZiq9ZVqGyub+fHXs
p5jOx2gyc+dTVSU8yn+733IMBxU5qM9ppHS+ySk/kleV/KmBeTlrzW0y6XyJ
g9pWrLeAUrRuqbXKrVb7PLzoY1hxpAzxh61eZH1RiuuXFkhKB/RqAKNP74/f
KynG/bnzm+GOE5aXomszZYEGgTLgG6p6j9lXhly2bhIcHSqHpLu/L7/rqrX3
X3VcuW05BEhLH6SvLEWsw4IlVSMV0Pl8t8jc+2XonG3b1bV/FLi9heemuF40
oL+f8Wq7SMFECSxv8dvJZlMJ+rJt7Nfw35VY/uuux6eEIfTn7ZzOv/dVLYUn
Ox4nvTcoQzscPBuFfen8lK0XL1uaGEfnt9yT0KHLxdNy6Kas2WXUvwS9uHa6
7bf3NVhu3vj4c7ET/fkmKw/9STCj81/etAmUT16ggmArL+eGVSVoe1tr0xjj
Biq/i97ecVZ6u6ODohMNMeOT4Hqm+8llzwoQMz6Eg1511bzeMSQT4zep9Zen
OfzDeL7Tn3ZVqWy4B919Br0qxPcLKXnFDlO7A4dLMO6d83Fmz91l8OKMoq/o
3j+8P2d8o++ygGgO4txk+1wzE8MH4eMD7oUlKPzHoLbHp0tgcqJzl91lxU3y
WU4USCIeXqyEktGSkfw9RYirK7E8aKh8VNu8Glg877Nk/XIOunzhe3HPQAm8
6XKq9ba4YoR2mm7rP1cK3diL+viM4SLeMn/BEI0USsc7n0odTucfpfjaxn9I
eHqvATzqv3bocygfuZtfnQo8Dqx9+Xdvr2Q6P+X88JQOsiccZJy5pZVqmQzm
WUshoqAYGT9UPnCsl4Fd7hCv9d21z/f2wKmvz8vhtsdg279hJbj/zTTd1jX+
AQe1eLX40aEqOcTvbnvAVuvvqqXBWV8uKODNp/CiH0ZcJBTXtVGPVIJPj30H
imtLcH9Kfd4PbdTyl/ZiODhH/qxNrzy00upG/f1QOv/ogp4w9ch92p4nn49L
dgqQwt2uGwrckjioWczGkNJbStgca2m6fV8J2hq0cK7HTjof6KGqNZ2XetL2
se0QHzp5ghzixPW9CzYXoFdzE3I/N1Zj+XJ//oTeGjrf6I0bg7aJfikwXl9b
aJP6kv78da0fJsx6rYI1bS4tGtFQhEa1+BEWtL8BJuv8TP/7fLFi5s+k8YvL
MoN6zk94dXthjDQ8F/243Vjk+Oknzrf5+LOR48fQNIyf2G5+ZBqWDdeE42+e
vJeDxvqnjB04iZafvPpgyZAL+Rjfk1Qdkgyl85E6T/c0Gr+QA6NlXZ89zshE
43QlDG/xO+6FbTb29xYBLa6fKsxHpheeXvy5Tozrj9z4+uOIE/83n+nA8VOv
VMOAbX2O9y/Mxf3l1cK+tkrTfLR5f6u0mb+18+XOu/Ot9xWhvOYFkwLvS3H9
tauDR3da1ACz5ImnA8pyUduN9maj2SWwoM3qCuO2Behl/q7u3LsyGOaeNDgk
ogg99rpUfNxWDuWT/13M30znV431S/i+u3sB2rTcaFPnKQroueSz8mNYEZL/
GGpZXKDA7T2q+XK030n6++QJu5/x5NL5UidZKrJa1EohsE9HFedCDl7/jTzc
cOLakQJ0K+JcHb9GCa6Rl1d5PP6HNh/kDXv6QQWRA4b32fGosEn+1C+WvY+V
xdL5V9t7a4IvXaHzrzqVJUkHrqE/X9nin7B2mBKCD+/raPchDy1umVD1sbsa
y4MN3g+d31EFYa3sv/fomoXOReVc+/qlDssjbttkWfdXE/lFo6wovCGx47B9
vASwMfr1oe3HVBRz+HuwXUgC1rdYOylp64K/GL+qH27/fVguxjOf7+ZVdsiE
hdOrBneoSkEOuhLLbfqNHivaWQCeCxe4By1Pxf0tJV91xHnD/jMcMJk+VJA0
KA0FhpxdZXk6B8vLc7xfXrDjwsoZhuYWl35jf5ywWFYfOCMbXe7+bfqmADHW
Tzq38E/WlApYNerEwEMJadj/9tWczrsVkIUO9JieekwtgYArwcpGBzbSzDh+
i10nhTVH1988kZKD+0+KL4299XbjjDrt+DtkUrvOdP7ZN3nzZWZxGYhTNeft
0eHa9Vfanz1THmifl4qwJYb5MvD9tazG7igbLS9rXX/qqhyeePX5bFmci/vL
zV2On/VslY791eeQIq6ieSby9Fzw9UeKHH4tNHCufJuNDDiXuHYHFdB/cCtR
pQsbXV/xp+1PIyVcai7mFLXJxf0n9XnzW55YY/mOtkfX8wPN/vaVgrfhiYEr
PyTT96vju7R2NcxEnW+au3/bogSHt/JG8/456Ev6JpNxo+j8tBsMYVe9GW2P
9alpM1EzOXw5G5J+9F4a6iY9OWCvIZ1fd/6oLR39s+n8tx15zd6XBiuA+zzm
aNXBdLz+euc/WWx1JAvt5C6a0dmF9s/lfd6Pt9tJfx8TwbGhH5fSn+f4gGE+
+TvU8Pi/70HlI31nReV7PeK+NrRjj+9waVTG84SMeBSoK3E+2CnJDkdeTkrH
+Iij489N75MxjlQ1T0jZRufLdW3r4Ls/Lws+Kafw3nj8RLalJ4pm9k+Hupfn
Vja8+4p+Db9yICEsCesPX+N0/7JzIcbZZyZNVBdwwHXWNbdlI1jIt66XxseV
DeFVHYas9YpFj2dlFBxqlYX1w/Ivro/WrsdDKyZYSC6molMZYUY3Y8RYvs05
UmPkUQlGF0aNat4qHs2VsVgTJhWA44sLxZaP4rG/2yzp26n6xV80YJ3EO9VU
CrZfnsxe/PYn9l/jyBVjb5QkoW4bc64O1q63XdIKChTt0pCJYYtTFzvLoRD1
2t793Xfsn9yKdz+PByejTdy1DyYp5NAv59rop9rndfS99pZdXilo+xX8bYjN
oz9v3R2rdbmzpHDKcYenLDYZvX2+o+Ng7fi8+P6eo4+Pp6EVW9f+c3el8/fG
tJ+VtH0Znf/3wyLW1F6WdP7fkaXDNqe2pNtbOXzXcpu/Clhsa3L1edxfZORW
VPPnihrLLxzvMrP8EZ0v+LFFb2GQH93e7xZjtl0PURP5bd9aUdh0l29USdd4
8ErcxhkTFYosfCsSVinisP64Vl4Jj0zTMO7y81iGfF4Sxkqu/dj22TkYe47v
V1J7JROchO8dp5m/RU/aTnNz7p0GpasPtQzrcRpNBb6cW/0b6899sKSbo7wI
4wCl445mC/Ix3iV/3mxzUjGMbTa1+l+fSBTnFTfKMzoHuqktYvzTAlHL5pJO
C60zsX7/TNthT9WlEBNZejJoRyK6yHr9uIwjhovJ8xL82nxA35IjfkfnF8Ha
AAP+9ttXUeCjZ+5jv+eBTeLfd4nl39G+RLuTT+ylsKNHvNyyXTiaN/TemMd+
xXBSetPySApC/8oCzGZulMGlgLaZnc/9QKtuVbi6T5aD3f7AmRbHHqFn0wZI
jZ1L4WDSbtGhhFi0u+/l9QF9FPBqgsA3JeIHumlX9PpglgJ/3pairLVPxWKM
Dya/LPi6RgpjjJ16DpXFolnrbWPuf1Jq5xvNbtlt+omKym9vH3aGzl+8qO3U
kZHb6PzHli7KjUmL6fzHFv02fns5lG7vyg3vG2a1Cmh8e3aBjfo78jYLPZIf
SftHr5TNB+fG0fmSMzcf22V0j26v7llRq4Bvaipe2SBw0avbJ2LjILj9XONb
rV/D++y5ge9y4rA8Qnq1V8eMVIyXvlpqUpP1G+PmS/+Odl2Rg/HWfnss000z
gdXl3IGCnY+g/7hhoSvLUuHQ2k4yzs4oGDXFpVo8OgnrL3O/uDZ+QhHGkimP
es4NzsM4aHLl9ItTi2Gz0wrj/SND4E+nhvfm3jlwKnvC501X34NyYwdPA59M
rF858ZnBWcNSaK1a1G7sq0h0+cWelNdSMXxdsfdMwOA78CHvVuvW64sgAGWF
Rtx8B4MCf/fq2S8fKn25F5/mvELrTyQ+Gr5OCqfZsaZvW0XAPeOnQ36dKIYJ
N/tO3NHsHlq3JfN9290y8ByXUZFm+AH1Hn900EAHOUy4k7jP1eQlJHRQrDe4
VgqZ74wMtn8NQVPRHfmpEQp4/qHAaM6sD0i8qaLmZR2OFzfotDnimFWjGOPJ
pe3dpm2UgoNwz2KX24/Qn/iwUZqfStB0ytx1/1EUMvIe227dfTpvRo1xofvf
vXTenPg9N6ftXEXnfUEjF4oqzOn2tkZv9EoSK6B+yd78qXmv0CKX8LvB32l/
6GXj/Nkqic5zMun3xLs2T+j2Fk/6/aLhpxrnMzbT9z8923/+8LlnAqx0fvEm
wiEey8fq+x8Kd9L3PxSm+h8KU/1PwNi2LksuxYKjYc/qPcvTQLylz6nBhj/B
Nrnf6+6WyVjfXt//UJjqfyi8W9//mEtKu2SEITgQ/2P6gl658Gm8xZmoHYkw
orwqxsg+C+sP0Pc/B7b2mZ1ldwdYLdZ0XaDW9j/t0rI/pcTAj+GRY2WW/2BP
1l0vsXECvD1864Xn8gJYqBvfqHUWgMG35K2lj0HT+U5cgasU2t3YeW7MvVgo
j51/ag2UgNmEt3Ny1vyE9X0V194EaMdD3fiH82tELljSdu/3SPgX2uKg2w4Z
vOAuGXn3ZiC0X1NrMX2lHFxDK++4vkLQ+bTVmZTHZWAaM/TG+0+/4Kp5V+/t
nlzg6sZHnJ/j0om7U6dy30D7w7cfNBopoLZZ5PKAjQEw+u/FHttFCvz9W+n7
szn8oJLogkTwTR2xItixAssP6Pu36WP2dd13+g3keXzw9ElQgvf0634L5p8C
p0dJE6eE0vmvF+r7NwqP0/dvFKb6NwoH6vs3RzfnIKddobDiYtLbmnja36j+
jcIZ+v6NwlT/RuWHPqyfb1Vf3zL59++/sPR+stLd/TuWT9PPtyjsq59vUfi9
fr5FYTf9fKv/8VLfYyuSYD/yt451TIfjlkcP9OmYBq3vtuz8tywF65vo51se
uvUFzrdCyXP1868F6Fm+isuCxDNXZFu92TDg3PWFcPkvrHvUP9buQTbsC48t
sr6XDpKvT84a/6brh+vnY0669QfO3yKJrGntfywWHp1v5tKJJ8b61PzskVNo
ts/CFPALOVR8xaQI7ve711jimQYTI8emVLnmU+sT7M/ffCazOOPjtfPkvX4D
l0shb3Dw5xYD/kJYV8G2W+nFsGKm6cNH2s+399Bp+3kLOHBFtx7B/tw1fZP9
r7QfILjVylyxSgYOG6O3+V36Bo33zlp4zpfDTfvTHVrl/IFthyLs2/cugwX2
61OqBmfAyPCB5TlWXGo9gv3587tVb2zFibAyKm6SUScFOFkN5Ls5f4O28s/3
e1Uo8Pel5nsH+fNKrsxOgtDvO872H1MFd1zrDj3clQ5RS87Hj/lF50On5oOH
desRnM8mNWB/176FibDTe7Lt9+dKuNenQ4+wshgoDDVu2eEWnZ+cmh9SmJof
/rzk2W6l+19o4XBr98DVNVhOzRcpTM0XC3TrEZw/529ql2/CoHioKJtx7vhL
2r+p+SOFqflj5dzKBb6v08HHZq/10051WE7NJ6l83x769TWvszJw94YsMOe0
LRo0IxHLLfXrawq/1a+vKTxLv75+sMP466lJ2ZAis35WPCYVy+3062sKr9Gv
py9nNT96eXEm2Ep/LZnpmwvh1itHmW/OgZGXfB482pqF9av062sj3X4P9m+/
nW42WVZ/IGnBIr4mTYz10/Tr65etvnPP+mfBJYvdSyKeFMKvAtmgVftzYa/T
tB75X/Ko/R/s3/ULWk3KNEyFqQ/fGn+zlGI+tn59/WLuGw+TidmgCBfdnBpZ
DN9/zpvYcy4b6t1NLW3MOCDfGN66xCsdUt+VzM8cI4ON3SN6zRmVAm7bpGZG
I+Qw8W6Uu6dZNnhEhi6YX1MKpbr9IOzPXcKe+DgOSodSlapNWpEcWrzzTbk2
JAVaB0YlL49X4M9DrZ8VfgtTqkdlQbTgUvKMe5UwwYezetNhNtyX2bQ67kPn
o6fW12d1+0PYn2+GKqZnmKVDgZPhuIs+Wv8Zs2DS5FXJ0PHOpL5ybzo/vKt+
fU3hdfr1dej7QZsEm3OhT4eVE3aMr8Zye/36msId9OvroRfOQdaeVOi+/6O9
0VHa/5bq19MUNtavpz/adR6T9i8LZkm6Nnv7rB7LT+jX11R+9af6/chAp64T
Fm/Jg+jBzzeNNfiF5U/0+5EPdfvxOP8VJX+m359M35bkqS7PA0M3ww1/y9Jg
fsSSy27e/6DVbMWRzDe/sf45ar9Stz9P9OdseKDfv6Swi37/sjbkfklZSj4s
vHLdYZHWz4u2jDCP8fgHTsnt2+5nZVD799i/1aLP99uMywaJT0J7fpgY843V
72euzDTXzhsKwC5xZ8uqtoXQY9NZzoeif3BmYrdo7mc63/5D/X5n9+3bbrlZ
5cDvcZEm79USWKHbT6LiPLG+q35/c+PXS996v2LD8pDoISJTLgx/sqexrkMh
7Bk11+D8wWJqfx7379lbO22KF2SBV7JbyocqGZzU7SfhfFxeXr3mzZlSCEfk
IwK63CwF0fOIkgZlFszp6di6xXEFnNPtF+F8XdTnCdHvf9oZ7Ip90aoQ7MpH
t+rCrcBytn4/lMLUfqhyx+crH4OyYKDG/EPEBDo//2f9/iaF2+r3N8dGtPE5
tKYAWtj2dFm7vQbLHfX7nRQu1e93Xn2wfX7SpFxwaH/L1c+Y9kdqv7PqRc3t
94/ywFmSfWzvYXxeBC/0+51Uv3NAf15E4df686E7E1JLHDeWQLNrxvmd2Mm0
nHleBNR5EYWp86H1HcbvDxpeAhy/8RF7l2VhOXVedOZk1iTnY4VQ69m7Ubxd
jOXU+c9ukf9VAXBgSO/SvH5+/2Ch65z+Au28dRv4sPr75WP9a/rzIHvd+SP+
/9GcVBRRXARTR+/dp3wpgR7L+i85J2MD98qDZbaVUqzXTn/+s/UUqo7240DK
K695ByNLoJO/6e5jR0vAJKzd93cfOGCsO5/E/va2MWPL2Qyt3xssMBl0UQbc
hlNuSXHa3zNh/Qj/ADmwhvNcXr3mQLDNvlafospgboTHypfpJTD0i6pTdBAX
+CGVW0doCmHQngeocz8F7H81504Wjw2aUW3GbxpI52WkznveyTyyZGla+z4c
k/DwZyVtf+Z5D1DnPX2Ltpg+Ci6EV4f7PrugXU9F6/bbm7zfgDjvAeq8p/rZ
88Y3eRzgDhuW0l9Qg+XEeQ8Q5z1AnPcAdd6TalnRVeXJgbEpfeqbX2vAduyk
Px+nMHU+/jSzy2N5zzII5jSELcyn5Zup83E9ps6/6xKzF0ZHlIK597It/uHZ
WK7Qn39TmDr/zkhcPcglpAR8T07Nieophgm688gm7zugzr/fNlOVJyWXQqsN
O2/9Sabbp86/DQaWfjkwvBj8+B0fzd4phRLdeSPu3yj9Ev15d9h3AavzhDKI
f+R1z8myGA6UuBwJ6VEM68M98ud1lsNd3fkh7r8CS3gZRvO40P5jeKL30nLI
bnP53Hd2GSQGtu+ajbjwXMkTFo4qBpcP06ba3lPAHt35YZO8ngv05994n1N/
/n14kqfh3SIuLL+xIWlcfSWWU+ff+PfSn3+fHferJG+l9vl57+787yGd55I6
/6Ywdf79JEXRu9C7FNZZtqwcdrEGy830598UnqQ//6Ywdf49xK9f+YQbpdDj
XZ9Fmnv1cF53H4PaF8DvjzDT3zei8Cf9faOOTlsuLGlfCZlPt2THpdNy6r5R
gu5+RZP3NVD3ja40LDl26k4FzD/7Y+u6cTlYztHfN6Kwu/6+UYJ8/t0+UVwY
fHJNpNCIft9Dqv4+kUlxm5qRNRVwut0XibekAMvn6+8TGR9uOPvoWxm0KQhx
nPdZAkOicjokTeXChW+jur9XSbG+kf6+0MHXNhMsXlbC8GqnzTtqtc+D7n4c
tuOTOK8Dt36WgdsyuWTLEhmENjvIvbJb649v982qPiSH7BabCqxTykH+0513
sbEM81P3gUSXvLaM4pfBilZBfSdlyuHYp8p6WMqFy7tXZVkY0e+neKO/72P7
wNJxk6oCvrmmPL/bvBLL++rv+1C4Xn/f59aa8rrhVaXQf6rXrkw+zUfd96Hw
Xf19H56/pof91CqwezJhULWcfl8Hdd+HwtR9n966+21N3ucB+vs/1PseHuvv
f1KYut85IvrHtH17asCq8m2xsBUt362/39l4Y1DxBocKOPF+d+e/K+n3U1D3
Nyn8Rn9/02KFhdlBixo4YuR9KM8rG8up+5sfp66YNZ5TCbFHGmTHzMRQr7uf
1uR9F//09zPvCDMU4T9roOXCizOKH+djea3+fiaFjfX3Mz1096NxPx3DMwg9
u60Scj5bbmjQzs8sdPfTcP+VIfuQcTqzCtQZveR2shK4OqXRteejSjg9dtGA
+MMy6r4Znbe4/4LE9vY10Lzs/TRRVClu/4z+/mRr3X1lvP4Y0ybqxUvPSnBw
ax8YMFYBJrr7ZLj/wu/v0N+npLCD/j4lhQfq709SeL3+/uR93f1kvP6g5Hz9
fUoKt9Lfp/TIvbU9paIKDC6nyG/50vaj7k9SmLo/qbMTD6j4AEq+SH8/Utz4
vz99nhO/bCvqfRhd9PEA+3X3i3H+WUq+TH/ff8Va/xs1fRtgsekmqBmXguXh
+vv+FB6mv+/fWnefuMn7PZD+Pv9Et67ZrbTjUNLOLmeNW2dh+Uf9fX4Kr9ff
53dMN8/dElMD7X4P/Nm4Qgx7dPeFm7wvhLqvb/1n+MfEqloYrF46stOPf5Aj
bLG6R1kD1L0NqNj9l37/iaX+vr5L/LAHw1/UwAPP6erPEgl1Hxj73xmX6TtV
i+rhyMOEK821699NX6fYcbX2imo9/7vopIy6z4v9j+K/qb9PP65D/ZQb+bXQ
asQcxb2V5RDi3cK18XcDBH0bnTHenX7fylf9ffoR7/b0nb29GnaZzPUqYimw
/Ij+/jyF9+rvzyMTr2J3SR08B+Ep9a5KLG+hvy9P4V/6+/IUZunvx1N4rv5+
/CEbn8mHptXDsJVGboNdarA8X38ffprP+9uDc6vB8qqgMca1EecxpuLLKH3q
fjun8H9/dXgfnfJXXZlp9UYXrwJEPBn01MeTjdLFoxD55Xngr48X6xM7wM3M
iQ/hm/0c+39IwvIjzHgxoOLFVuviTZq8L4WK91L6j/y0aSsfIjfUfGqlot/3
QsR7ARXvpY8PxevXHzsLfhRzG2Db9fVV+XkiiNHFlzR5HwsVv5Wbm1R37TQP
Ht1LnfeiqhDLqXituIElvpkfG+DsSrHJkQsSKj4E++fB57ea84fywabI0GJp
A/3+GSoeK0YX34nH4/FPrJ8bdNeuO17+e35snwzG6eJBmuSlp+KzxsLFNpf2
8aB15RLHxQfp70/EYwERjwVUPNaS2lctP8Zp7Rs7/fLIXjgeC4h4LCDisYCI
xwIqHutn6TxOh6M8gObTO7xLr6HiN/H4OlsXn4HzWwd1jD7j0owPeaX+Amtl
Heaj4rH08Zf4/1N+ZqiPz6awvz4+Wx/Pged/Y/6vX/qlW+njK7G/i3TxkkR+
f62/6uOz9fGQRL5/PhDx1UDFV2cnuvbrZCiESy1GucabJ2G5Wh9frY9vBCK+
scn7bP4w46OBio8O8xlbOSSFD55mM12OJOVCM9tTLKuuQlA21LM7fKHf11Og
j4/eqYtXBCJescn7chz18c4XnbsNOjBXAFayAfWn5xVS8YXYnwvaqecde82H
Nw7bM7dq5y/9fb5M6xItAMsjDbw5Ivp9QFT8sj6/Avbv9suLvZfyeRBg98lo
Xjj9ngoqPjl02ogf6Ro+LDda0FF0twz2T16y/F07Ibw2VwosT9H24DPjk4GK
T9bnW2jy/iEiXhmoeOXai67PWWI+SP6/ss48LqrriuPQqtCAUQpCFUrCZsUt
UaIJYeoZFRssoiCgTMSwBOHT2KrI0hoplaRZDIZYWepGFtHKIsZYE0Ndiobo
JyDmo2wiguwCKjLMwswEmE5yzzlT3vDfj/uGmbnvnDvvDZ/7/Z6z+4t/Rx98
+drbLgYXFSRMu1Z456j58Ym4fxl5C3y9QONVuF/Z80lpT3LBMFz2KH3BrW6A
eAlc/wVgs+Slz4fg1uyYRQvP835E7oeBTTPeTswehrjdtgsS3Xh/Mkj2JwPt
T0b+AfcH+WBSkHdC2R15J7h/kfsj13v1Ae/Vw9wPE9bxylsy5BdIfA0qUCDf
BHkE/HvkEUh8DipIRz4J5QHkk3zxw/X6zA/V8K5npeIXeTU8boN8khcFT4D7
46TgCVj4il5H/sjVy8ujh143nb+tMZrjjabnq1kQcGyfGo74f76r1a+ejyf+
yO8Er8j8/abgAVj4j2TIG5nybNxuzUUVVKwJuq+90wpD95xzplxUw3RFct7Z
e81gK/b7c79sc7ry6RtjKriywyWq6uMO/nubkD9CWY58EZ5/5Is4X3B6vsNO
DUUbiv741JfdPH4BeSOUiTeCfCMLX9R85IcUPfjQT39ZBZee7z449a0+CDhU
ltNaqYac2uLOwEzz8cQX6RB8I6533K/P3xetWFq1xUupgjPXSpMehT6EFYJH
xPWubeywebdfCXa+7rpdzuO0H9/CB0X8j0u7arsexqpgcGfNxznHzdcVP0P+
B+WXkP+RIvhBXP+PBT+IM/l8GpH39ZXYj8/1j/vxOecv689d1m/2e+1t6bep
XaeCVcrOKmMG83+4H5D/I/FvqGEN8r3sBL+HX/cCwe+R+DnU4Iv8rpL57s/d
H9VAXlJLeF3PDR73QX4X5Tzkd1UIHo+Fb4r4XNZtfW3r2zRwM8I3LCu8gXg6
Fj6qXcTjWvjf+U8/Nq0Xby7dY8i8D9ZvDr3n2auBpcHJjiWHW+DPggfI94f0
eFfkdd0Pn3Y1S68GR5/TQd81d4JRvuLek3YN3P59kNPjpzr4eOJ3NQleoMSH
ooZc5HlR/hvyvBZ8e26WR6kGStIKqi+VdfP4K8j3ShH8P67/aMHTkfhL1FCB
/K5Qx5rYJ9M1kG9fmBzh0A+pTanbKuy0sO7vqzdUuj4AO8H74/ovErw/8/ov
eDpmH0rjybSqdtP7+9p5d+vxR1D9bNTwjSlaaPL+KutG1AA/P/G7HASvj/ul
TPD6OMu+j3Z5zdRfMdWytwKKx+Ca4OdY+L8ikce1sCsk79+hGlheN7ZjsW6Q
x/+E/C3KR5C/9Ujw9bhfXhV8Pc6dG5WZQZUqWN+y/NzATiOva8THRH4O988P
P93P4nWivEFmn2a/0rhcA9FKhVeStxKQj8f98kDw8SS+FS2EIB8TeXcS/4oW
1iP/siS58krN6hHYYF+QHRD8PY+fRf4l8uss/GHByL+8+55LRrHR1AeODSv+
8UIT8XX582DyO9M3hzZp4YN3NvpEydog6baxbGrnCBjXHe6Pd7hLvF3uB/r7
k5CPmdrqEeKWrwXXVRe3XG/ohNj8tduP7hsBeUO8x/Ve8/FLkJ+JPF3uB+Tp
Svw2WqhHHqbt4b/++sDkEfAxvqh7ek4PjD9a4tppOt5fcX102xLz8RnIx0Re
LvfHv1xroxJmaSG6e/HJIz16mCt4d9wvp74O8XN0HwEHTbUR5vZBoeDfcv2H
Cn4d1/9swa/j7Ji40+3MJS2k1Z6L9Xc3+9/kyK+k3I78SuTTcv0jn5Zzr+DT
cf3PFXw6C3+bHfIpKZ9BPuWc/Epd2uIRyDwW3NKeNMjjXsifpOyP/Enky3I/
IF+WM92XER86WvDnzNdX/3/fVnlXNjm7b/28rBEYTXUpr8+UeD9N492CFyu5
39ZBDPKjdwgeLPfD+yOBnS/H6WBG5DOlr5y+xccTPxp58Pz/4FzlWfexdXpY
W1frfkJRz8cTXzqprjS8t0QHCWcjvkiMauVx4ksj753rncaJD10Qciss7Dd6
sD24/6P93e3Ea+f6Rd4rz1uQ4L1K7m91QLzniv1jTtv9dKAJ3Cp739gDn63y
OD8/Xg+zW7x09se6iM/O9Yx8ds6/FDxXrueijaH1HdY6iBzQDTXk90P81X0P
nSP00Oi05+pWZS/x1M3XO4Knzjml4UDzJtP8X9n8qaIpYBQ0gt9q4b+T8JqB
eM0hH900zGs2nY/TzzWlznrI48RnRj4617tGHre2KkULd7O3ZtoqxqFc8Fgt
/HoS3jIQb5myhJ8MxE9G/jnXM/JSuX7n4ryJ1CUrPxR0InCa6XwbQ9URHygn
njfTOPLPJffTejiBfoKda6ojO39lAP+bjcXpR5vIx8Hr7drtvTObjxtgUcmN
ceu6FvJrcL0pBa+c3wfyyjnT85E/YFLxvX/m9xsg1rl8aUBuO9wW/gyuR+SN
8+P0NvsOzVQaoGRvVmLi+S7wFf4LrifkhXM9IS+cc9zshXOOlhnAfs+OjLw0
8/feEn4/EL8/X/gsuL6QB871hDxwCx8g8fijYlMe1LbrIQxmLkpYZvYXSvj7
QPx99FVwfSG/28IvKOHrA/H1KRM/H/nZXC8T9iXGDsmShG/CfP/WOtWt5ZQB
XvUc7vIO14CL8Evw9Sj6JTijH4LP7ybhb+DXcVH4GzjT889Af8l/hG/Bwgeo
QN8I5SH0i9xxank5NtIA+8Oy501xGIUM4UOw8AdOQ18I1wH6QiiXox8kTfgL
LHyD5AOh7Ig+EMqH0f+xSvhx+H4E/Te8/qPfhucXfTU8f/3CL2NeZ4RfxrzO
Ch8Mzx/5+8gvRJn8Quhz4df5WPhcLPyA5BeiTH4hyuQXOiV8LBY+QfILUSa/
EGXyC1Emv9A34z9dgIr31+j322+EX4rXI4XwR/H8uQo/FM8f+p54/tKF74nz
G8LfxPNHfr7N6AfTCF8TzyeNL0b/F+VC9H+V73WY6nloDCLTB4dbEw08/gn6
vSiT34tyMvq9zisyJ7cdHIMecM27YGX2B/ag34sy+b3QN2fhPySf17fOCc/M
kxkh8JNJOekRg+SX48+HocEff8w+R+p7K/TnoS+O59tH+OB4vtHvxvP9B+F3
44y+Nsn38VZy8vEFCz/bxOsm0zj5+RqFf01yPWEll/j65BJfn5x8fSuFbw0m
rGOmcV/09VEmPx9l8vFRJv8e+tMkn9dWcvLxffZzL5st3xnhWvzKGOvCcXAT
/jQ+7n/nQpSS
   "], {{
     {RGBColor[0.148, 0.33, 0.54], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNVV9ol2UU/r7ft+/9vo2C8KLmbEshaCqp2y+8CHLR1m8mkVDRlvuTFJSm
VtsQuqpE95tEQQU53dZFkPYHnZsE3WQwdTMvgvBCU7fIQL0r1yIGddHz8Dw/
3MXhOe855z3vec8573lXvfzms28Uoii6BEpAr9VE0WYwrwLvj6MoB2WgjXkU
1cLwAeBB6JfBtgy8G+sE8sVMdn9BHoAfQbca/CfA69D9AdkF4ErQMPgEeB/2
rsDe1cBNsG0BrYnkY95+5mEXYBPDZhDrA6AjoLOQzwMvAt8CdoO6QJvN95gn
PgXqNfZYT12793Sbz3zfBZw9AL9T4HcAd4LOg38beDlVbN8Dn8b6OORtwCdB
p8BvzRRnX6y4PsV6FnjU9z4M2g9ajzu1gTaA9oBeBHWCmqCrj5X7DstaCzqf
/mdiydosn7SMOvLTXnPvC6BdoN3207Fk3WHcY90+85Stt+82+6DtE6Bf4PcK
6BzoMmsAOhNLR/t1oGdy3Wl7Lvuztm2133X212qfdZZR929Ab8E2ZDqDe+mD
vXPVZ7fYf+WcFYU7uex0HlnnR1zjomtLfg51m3VvvR6U6w7g3qA97wf1wIJ7
8PGgOjQGree8d9C1ZS9+EdRbk8ARYDmW/regOt8ADoNK4N8N0pXdH1fxNh6D
v2+B/VgPgQZi5WDAa9r2237Afcz1SKq7lIGrkK/PIFub6f3w3fE99Xv/kPdX
en+TbXh2o5Hr50DP+x1OJNJ9nGhfn88tOpfM75epcvUj8Kh5yu4Jert3BfVy
td9VtXu7wTraLKTKcb1tlgfpNxibfeZDmEf1iOXBGuW+z3cp2abJ2GBflTX5
n4Jy9ytwS1DsW12Tdtv9EDQLvgH+59qxhi3OJXPT6DfMGdblvfRxKFfffQW8
meqehSB90f5/t5z6bbB7GPalXHEwnl7gh7ne2zvAA/ZJ3z3Ofa9rOeYeeRS5
aEJONgLvrVKMt7B+BettwJeARWAzqD1Rjxz0/jHPC8rK7qVOxpgozw2J5ix7
nDNrPNb6RKw+P2JZ2X/BrkRv9qTf7XHbcm8pUTxdifQToFFQrWNm7EXHyL/n
hP0ftr8RnzVsv5Tv9XzmnJ7zO+J7WkC+3kPerueyY/z7HRN9cF5NGXnOtPPA
mE7nmoE/57rLtOUnvbdyrynvPVOtfC2rkb9xy2/kmqeL9lPxMeJ7l70etYw0
6DvzL/0z1sz723fhnRbt8x9gN/K1E/ddWaWZyDjP2V9lZgx5zTrvSDW7PkhV
iy7nutd+6I9/LP/TtKCzGQNn7jXzt2P1LGf1csd4bYkN9fznGtxvlXqSL7mf
6r2ety33TGaa8ePArzP9Fccy6VLH1On+7El1fp1jqPPs5x/wud8O39Bu/3PM
XbPP5Tthbqsce615yngWeZ53zDEcyiS77fuPuY6TvvOM837Kb4jyC7nO/S7X
38ZYmbMZ5+i871SJnXEH86kxeA9tao2pY93uOrKeE45pNL5jV+U77/M/PrOk
Pls8KzgzrljO+JtcH+Zp1jHS/n8wvi3U
         "]], PolygonBox[CompressedData["
1:eJwtk11ojmEYx+/nffY+z/O+pXwcmHzMSnlHaot25qM1L1uiENkyS8h8SytO
fGQHSytfoZQDtRWSTOQEZQ7YgRIHozY1Whyp1yTFgd+//w5+9Xvu57qv+77u
675rdx/dfCQXQmiCKthTDGFdHEI77MU/JyGciELohb/4BJzHe+A7noMCvgDm
4I3MaWDufFiM1yf+txxaEs/R3GPwAS/BPDyFGfh2aIg8tgZfyKa62NdWqKly
jGITmI5P5u0V/o/kvYbWWgGt+BkoR855AB+Ejsg1vcXvQXvkmBt4cxrCfTmU
8DfknCR3xvc4fp2xEXwITqWuQbUoxwu8j7pnET8TevGvsApfCWP4s7z3Ogo3
8Y7Ee22BbnwfZ7Y+dg/Uiyes8Yl/H2EQ/8b4luCcyv04du4SPMT3E/Mycg0b
8H7W+BlcwwBek4VQTcNjmIZ3Qj3eDMfxB6nXUo138U3wCH8NXfif1HN/6Dzw
iDkJ33NhNl6X2ZVzNf6emErkmAo+AKORx17hZWKW5bynRvxk6rUUcw1fCrci
72EtfiHxWamH/fjl2LXrzHX24+Q4S66DMJy5JtW2A3rwK8TUEbsErsbuqXqr
O/wFv5M59jA8x0/DNrxJOfGnmXNr7DY+nPos1CP1SndCd0M96MYvTu1Pa17C
32XOfQ4m8Dj1XdOb+kc9O/O+G2PQqbud+u3pDGrxQ1P3SzmVW29Cb0N3ohr/
nTm3zuAX3pd3Lt0B3YVFRb/NAgwVQtjFdxteho1FI9cbbi26ZtWuHrXh/wFG
vn5y
         "]]}]}, 
     {RGBColor[0.3522499999999998, 0.42749999999999994`, 0.6120000000000002], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlFtIVUEUhkdPZ5/joTKp6GJqpqJlD/aQ+CColJYSGQpFViiS4qW0oKgU
krKHDMnUNJCQigJNkjQjgoooKSUKUxMiVMwkg+6YREX1LWY9LL5/bmvW/Hv2
hOeXZ5X5G2PqCBfxzzGmxs8Yj8eYIeIjuhd6vcb4M/EHepbwoF30lRIp6ONw
hmhCz8IRXSs5amjn0N8CPxNV6HFYqWuL4HZiLXoDjCVWoJOhz23ME+oKhC1z
2AedC1fR7kNvggsDjGlm/hoY5WMtB1kJ17F+Cf3BXjsmc6LhKdqp6IMwRPeS
Pd+Sa4acE/AD7ZP0/4WhrDmPng/nac4wGK81p0mf13riB6O1hniYT+xE74Lf
8OI7ngzCh8wT4wdhAWO7mbMXJmk9q2G71tMJc9Qr8btfPZyAU1rnAIwMsP5H
wHCtWWq/r3u1wctECfoO7FHd6rVeiCd5sFf7Zbye9TPoLzAQ37OoZy5Mo9Y4
ak6Aefot9sA38Kmx36yO8UVwn8t6Kmfpg9n6TZPgMGOJ6JdwgPZX9F1YTTsI
fQJO0/bh2yd4TnNK7iC33WsJvKl5euA12mPoq27rnez7zG3XSx43d7xF97oH
R132XJNwuZ5F7tek9r932TOLfoce1rVSby3taHQ9vKj3U+5ph/afhadVy9ww
xorQK2EQdQRTT4xjv73cgUL4CK+96Ej0ViIVnQszVEtfgvq/Dgb57Pz5sBEu
Jn8D3K8+1Lmtv+JPN8zUGkLkTKqlb4HWI3Ul6TeS/++Efotil/VUctbCUtWy
z1LNI+eb8Ni34ics0Ht1SN4GvR/VcIg9ytlrGh6Q/wFdBmOIDvRGGO6xb5ED
o4hmdAiMJFrRa+Ev1p9Ev4bFtG+hMz02d47kJEoYS4VVcLPO2QZDaYeh18MH
Wo/U9ZixUfQ1eIkYQTfCC47NeR1WEhnoWnhY5xyDqVpbrMe+d/Lu3YBb9IxF
sEHrqXDsGlnbDJuIPvRRmK4+pMB2fUs74RHdV/Yv05wF8DbxCd0P2xjLRXfD
AeIQehy+cKwfPbBP36JXMEN9SIfJRBx6h2Pb0h8HE/VuRMA/6rmLtb81/xjs
0hqklhb1sA1e0TOKl9Pq8xRc5tj/0R8W6r7Z8LnW3wWv6nnPOPbbyx0wcL96
VQH/A9mw1PI=
         "]], PolygonBox[CompressedData["
1:eJwtlE1IVVEQx+/T3r33PdKwD6S0TFI0cqEbF+GiKKVEMBL6eGVCkZWQbiqi
jWARCC1S0sBFqwpJiqwgWhRSkbooROgLKXPhIqioNImK6vdnZvHn/d6Zc2bm
zJm5xQc7drZnBUGQQYvQtSgI3iWCYAz1wQ+SQfCV9SnUBzekg6A2OwgqUR18
h98abGVoCN4dYuNsLWqDmzkzhm0U7YHfstaFrR29gM8nzbdiDMAhMbuxnUC/
sXeG5iuDLsP5SfMln6vgJeiZ+8+D59Eceo3eoHLOFCQsp03wWnIuJM8Y5cHD
rLVgq0dX4RuhxepAj+Cznp9iNMHvQ8tNZ57DpyOr1V10DN6KhuAR1AA3Rma7
oprAJWmLrRzK4A2R2XTn4shqNOr1Vm0uhJab4g3Cs6Hlpvp90H0405+wmOVw
krU0XITWwD3Z9jZ6o9twL1oBL0cX4VZy2M9vMzqi9/R66I4T8A7PX3c8Duew
tji0GqvW171eeqNe+CV7vsMRTbUAZ0f23spRuW6Jg6ACWz6qgu+jNrgTjcMF
sdmyUAxPoC5YTfoQPoo2Z5mPXXCT95veuAa+yVrG94/A07H5Voyn8KTnpx5/
AleGVivVbCX8kz39WRZzVuz+atE5eDA231qT7UdkuX7m/BRc7f2l+dgIz7Hn
EvY+NA8vxMaKoVj3QntL1VC1/Ov3lX1ZirdLGetMCTzj95FP+Z72flT//INz
vb/msfewvyptuSinUnjS81eMj7HlKLtmuh7eh/b6f816i8+71g6lreeUr970
D7w0bbEU8zHxWlg7gE6iU2jQvyeq+Rh8xudZb9aq/kKNfkZnE7H1jvZ/Y/94
ZLVVjWfUT24vRKvh9bGx1vLhdSmrlepTDN/izKeE+RiGI/++aOZKlI/Pr3Ic
iOwNtVdnXsEVPp+agW1wkfen+q8aPhzZrGv+tsN13t/q0Qwc+HyqXr/UX94v
8pGjXvbvhfaUwrkpy11v/AX7idh6T/3WDf8HXzWxDQ==
         "]], 
        PolygonBox[CompressedData["
1:eJwtkT9LgmEUR29qbxGFtWRYUdHQJ2gLyiEChwznLBGC14QKzBoCl6BEtIbA
MSjIP7tjQ0ND0CoZRQ0R6tDQ0AfoXN47HM/lPvfx+XmdS+3H93wiEoZ+WOPj
CSexC2moQ0378MdZA18NiLz0ieRwFg7hlX4b7uGXuRbeDojkqbfwJiQMrWfB
5SyOp62ewOMQgkvuf9K7s/c1x7efeXof+A3e/V5GzVqy+Qx+tqxfuANdQ2uf
IzJE9h71OffPIANjzJ/iRc5nOI/iGGw43jv6XhOW9LfhefqTzI3iYRhxvNya
v2s5g9SP7OaHuQauQs3QumJ7vLUd6i5deKB3gI/4zhwUIUrvGK8Mikzxpy3j
dYjBNezSu8FluDC0zkOEsxOb1TtJWKW3o3NkXSBrwXahO/kH3FJE5Q==
         "]]}]}, 
     {RGBColor[0.5087499999999996, 0.4824999999999999, 0.5200000000000002], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlElIlVEUgK/23vufRpoEWkmk+TKowFxYBEFaZpPihKUN2ICaTRaohWER
LqLCIUWERIMWZjZgaos2jQaaYSBqmqCLFmVGUWZS0PAd7ln8fOe/95xzz3Rv
5KGijJP+xpgqvjl8ewKMucPCbpjmNWYVcgJMchlTwP4meMBjTIyfMelwF3vx
6ByBt93GTKDTCn86xkyjM+TYf1mvhonoxaKfDsPU5xIYznl1rIfBWfxexHYQ
7gzEhsA2Qx97beisgOvx9RJbF6zEvhw5G27R+CWPFuyiWa+ENaojuis5OxSd
hfAMZ8RxVikcZq8TnXFYKDmjUwqLyWEInTr4WvMahe3sFaLTAGuxz2G9BfqI
qRc/0W6rJ/qz0KvnhotvzSsZxmqdN8NfnP0A2+fwMzlMsz4J8/GbiJ8y6I+e
H+vfpbaao+Tax94JdO7DUGwa0FkTYOOQeJLhBu1dJmzGfhz5LnyOzyL038JP
fOeR38GP2Mxg+wHmae9SYTnnzWe9ADZpfRrhG74p5H7H5iY57oUj5FOHfhMc
xJcbnRH4iv8O1gdctu5S/z8uuyc6P+BVzf2sx8Yh8fTBMfUpvhs1hmrYoblI
Ti3aly642G39h8EU6nIbnXh4FJsn6ByGp/l6kcvhWrFBjpS68t+FnAZD3Dbm
YJipM5kB+7X+o/CxzobMSKrWLR4u0L78RZ7kq0AegL34+orPTnhdYyiTedN1
2e/RfrU6di5lPq947azIzPTAC9oX6c9N7cUtWIP9O9bPue2/rHfDHZpXJryk
s1QFD9KzbJgDI7VWUQH2fso9nQv9sLmCbSD8rXfWIA87dj7HoOOxffzGuRXq
X87J0Pu4H05pHQw+t2sv8qSf2JYgv4fztBdRsFDneSsMJj4Hfw4MUTki0L5T
8rYsgpe1VsUwRd8NeT8i8BWBTx98qjNzDw7ouXJ+EnG0IW+EmVrDCriPWCfQ
fwG/eG1NgpC3oXcD/dXwoc5qv8Sp8cibt4y9enTCYZrWVuaxSN/JYliFzyzW
m+E1fQeCyGu5xpMAT+nMy/t0XOsms3xObcVHib7P+V7bD+nLjGPrLvXPddnz
5Nxa2K13fwLW6+w9ctv7LDPzDGbpm3nQY2snNVwHozX3GOjT2XAkR9WJ89h3
VmxzYbvWR+r0T2s+4bF1kfr8RT6mvZaeL9X+Ss//A++M24w=
         "]], 
        PolygonBox[CompressedData["
1:eJwtlEtIVVEUhrfXe889WhYSWBRalhpoYAa9IDDJpAfBTbGygqJIamASJERW
EM7SoAchNLBR4IsgdVwNCnoRJVqkkYNqYM+BRdTA+n7WGvzwnb33+c967VN8
pLX+ZCKEsB8l0a90CFksFKA4DmE4O4QhNIAGUQ9rjeydQCPwmSiE2qwQKtHh
yNa0dwE9hEcxHcJ3GL2G5+SEcN33P7O/MGV7OpMP38ajKcs8O+GfrKXgxSiP
5w6eJzj7A92APxHTRzSJ3qEiPAtRBVqFiiN7Vx5peD1aBq9FjfCa3BCqUCkq
Q6N4vPKclftG1jb4GZ2dii125fAdLiefAbgbLYBziekusT1C1fA4HmPuKe/H
SdtXvk/hiBhSqAgtjSyHSX9H78pDXsq5Ad4dWa2V0zr4O2vfUuYhryQxZXsN
VIsVnr/e2QR3ev82oza4wf1U72a4mv73wzfQcjigi/5cCB+KrHaqYQYeTlkv
FN8VeElss1OBquCV1KQ/YTVSrXrxeM+7T9BNuAGN+PMpuNvnRzEq1lWs3WLv
EipJWwyKRTGWwj/wnOLsDLqq+qftrN4pg1fnWG/0/a3w2bR9S99sgVew1pew
GEvgQY9vBj2H0/Q8nW3+X9mfjc2vA03D56hBO+pCl1HIsT2dKYDH0+Ylz8fw
UXTf46+Dm/Dfh38t2gnPy7Vv6Zv58HmPV+/3wMdj653q0w7v9flT/A3Kz++j
7tA1uA/1oiH1ymPs8jXttft90ozt0nzhWYVXne44fIczLe6nu1nv/VTNMvCB
XItdORyBkz6vmvE/zPeE3xf19B68JbbZUA574NnI+qkZ+w03e346k4FH/H+g
GF7AGZ8X9Xeb+uP9bkP/2B+Nrf6t6AH8JjbW2he40udJHjvg+Sm7i4pXd7fG
49MMl8dWM9XuJXqFFvl86x+ZgD9E9m3FkIVfjd8f9Xg7PJ1j/dSMHoTzqMnc
pP2z9O966/VV/n/hschYa8/g07H1Qj05Bv8Hx9SzqA==
         "]], 
        PolygonBox[CompressedData["
1:eJwtkksoxFEUh++YJ3ltkXkyGzYWip2isVE0KztRkjB/G1kgYUV5ZHYzprAi
z1hZSdmImGHYzlYJIayU7/Q/i6/f6Zxzzz3n3BsasOKJImNMGNxw4TXmxWHM
NroJWzDvNGYOhqGSnFk04DHGD80QJD+Ipn3GpOAALIqe+OzzUicJj+Rl0H3O
78EKRKm3gya4fAxWoYDPQv9cxpxiV2OHIQLrGt9FD+EIlrXOgvYp/TZydwO0
QRO9dIhdzDnsEOqHgCJ2OSSJ1aBp7k1BH8xQdw216DsBg3DOHKNoFf4h4hVo
KZTBB/24iefRLORkJp19XGtIrV6tHUe7ocdl58qZM3gndqPzyZzX8I3v2G3n
yplavT+G3mr8GX2FN8jgT+Lb0HlkrojushOuiNWh7SXsh53F0BZohU96dLCP
J/QB8rDEDmP4FvWd5b2j5NZDELzyL9AurT2ibypvm+N/ZKEAE+zi3mPXlNqX
+ufu0H75U9iT6BRMwy/+L3w/qJM7XfAPATZZAg==
         "]]}]}, 
     {RGBColor[0.6652499999999995, 0.5374999999999999, 0.42800000000000027`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlE9IlUEQwLfn9733mYcIShLNl5hBf9AQKiKkxIzKIrXAwg6vok6iEUQF
ZWlh0UOSJ2WRQgmCkaRlUR0ygg7xLMQwulgkVPTHQwUmUlq/Yeaw/GZnZ2dm
Z3c2Z39dZW3IOdfESGEc8537AE/BRhR5yM3wtMmiG2VUIH+CyYhz32Y5NwCz
2dONPhOeZG0O8gl4I+xcFTYN8KPn3H30ztc1sTkIb5qfZ3DMbMQ2Npu9rFfB
1ezPx6YCXsNuBLkNVpt+O3xjuUmOGanOXeVwhTCX/ZnosmAPXIdNP6wxP3Vw
mv1nkH/DSZNnYHbgXIAfD0bwlUD+jBxjrQSb47Ac/QD6SljK2Z7jfxXMZN6N
PgqHiOGQRyIaQ/wPwVeWTxJ+x+85bN4Gaif2vyK6JjZ3YRlnKIF74BI7VyGc
IF4aPgN8Lidekr0JONdyltzHzb+P3Gd33QvnmY3YHmE8RW6CL1nz8Dns6xD5
p69rYnMWxom3G30X3Mv8Pfqv8Dr3l8B/B/xi+oFUtRP7O3Cz1acI1lsNa6EL
a6xxYpUy70G/MlX3i5/HcIvVoRgOYl+D/Yj4tPrLPUTDWpMw7LI33Ak77L3J
uyuzHCSXqMkb4DB7Ytj0y11ZbpLjLeZl6JvhPsstBjeZLLrXtld8TBHjn5wF
7rS6VUl9uItq5IvwKGMXchxG7U7lbhf72gu58Fugd5TG3nz8ZuAzCzZQ33Zs
zsN3dr9yz7mMhcgFMMlaBzYv4GWLdUHes/nJCWsMiTWNTYvl1g5vW/9KH6db
Tzm4lvwKyLMEbrRYK2CPnf1RWHtGemeSs4eQ5yMvgPVWw0Z4mPl69AcCnYu+
BdaRT5JQtfCe5SM1+2P1lLoO2RsbhL6nvR/ytC8lZ3lnvfbOE3CKtT5kz9c9
sveKp3+W/F2jnsaTuNvg34jmHybuIntL8qZarZ4PYYHZ7/D1/qS2bfCH9aP0
Zbvl3w+XyUAuDvRupG6lcKvpiwL9O+QNz+B/jdU5H5ZbrQ4F+mfJ33UJxi0f
ySvP6pwOH9jbkDcSsvqMpej/LjVphS1WB+nXpXYWOVO3/TnyX3Za78RT9M+V
uM0Rra/UWXpvwmr7BP4HXIHJXA==
         "]], PolygonBox[CompressedData["
1:eJwtlElIlWEUhr9rd/jvjYZNkkNBmQUVGi0yF2EmKCmGQ6VWC7UIGqgsGiAN
o6BACtu1aFhHFoYZtChpWKQNQoORgS1qVVYURERgPS/nLB547/ef6TvnfHdB
+/6GfVkhhC0QhxupEPrgGTyHq3DFz/StKBNC8bQQ8qAA/ToZwt5YCN3wG302
CmEjAcvgAPomZ80xs3mKPkGMLo+p2A3pEO5jOwSN6HxscrCNQ0Afg4qYxehB
r8xYbtVQij6VNl/F6EZvJGYjdMBBp8NzKvdyapqHbQTz0RExUjCJ71d4gc0/
5eb7KHqAnK38roFr6J8p+zYHsvBPRhZLMQvQk+7/GUbQs4k9y3Mo15T7y+Yv
etj71wTX0S3YVHC3JmjL2Aw0i3cwDnMjy71UoGvxKYpZz4rQTRnzVYz16D34
7IbtsAOy3V81qJbepN1Nd+xDP0hZ7apPvahiKSphHVTAPejH/RIMol/BSxiD
tzCawA++wXdoJ2YbdEIXXOCsF45DJ9yGAT/Tt0/YfIQYubPgkM9fd9yKLo/s
7tqvOvR0bDKwGJbAmbjVdhl6VLPvq/pRg17g+6V4q7RPzPwisfqgEr0ibVpn
2eh6769qaEU/4myEbxOwLW09VW8r1SuvOeY1qbaHXo969iduNrItg7VQSMxF
UAKroYCzhZAH+XA3bbmUc5nq46wYqqFGuSPrhXpSHVnMMo+hWAl8Tvt9ctA/
Eva21IMU+c5T0zlohpa4xaz2N6S31OLf6qAeyn0/1dMSdAM562EX7Hakj8BR
eA/jcB+GHOl+uAVj1PDGZ67Zjybtv0RvQm/jDvUO+k5pt04m7a1oHtqNEc6G
fYe0S/Veq3a2yndWu5sDuTAFj30ev9BrfJ/0JgrRT+K2O5qZZtfpu1oLG9S7
hPkqRmnCdm6xz0Sz2UxNm3zntfs7fT76TzyMDr5vmsmXyN6M3s4EfIjbDpR4
DMXK9dpnwEz4D/JLpKc=
         "]], PolygonBox[CompressedData["
1:eJwt0s1LlFEYxuFTOTYmZYugQKMETeo/iAhaJASmlgRBbqRNYKEQlRu1Fq2K
KZmoiHJZzsKFZl8rg3SjFMKYlVqWi6LEPnZtKroOcxa/ud857/18nOd5a092
t3WtDSHsQQYtfpqxF5P+H6KN2RC2Mx2kR9GGj2UhLOEvHvEt01HnI7iNY/w3
ac36EKrxrzyES2v46S3evJgBmsM1fK8IYRXfsCT2Kz2v9jnk8Ym/J1NqMtar
o7vQgE3iN+LzOv1Fi+cO8cPyNNITaMc9fdzFdbzWyx06KmafmAJ9gKFEfM6h
3rv7dL/4gnzVdCu24Yv75Z2t0AUsxvtu4OHfQauwGf3+9+EUquTrpVlzqNTD
TlqHenTJOS7fEdqMFvTIeQFX0O7dQLZUO/ZQWVGqvyXdL97zOJ47O0tvpLmN
0Md4gmfqdKhbpHN4g3nzeofBtJcZumA28/iNrHx/6ITaL/AWl519oGOpr4fp
XfS0qjMtT3faX9zj05jf2TQtYhbjcq7oZTDtJe6nIe31cMqxm15Ne7iY5hjn
ueq8TOxLOhW9mdK84twOpF010Z/Of6A8zfuX51nxRYyl3b+Ku07fxBnaidNY
Tt/TXPLHuD55epFDE38/fe8uBb7FNMc4z/82O3Ul
         "]]}]}, 
     {RGBColor[0.8217499999999994, 0.5924999999999998, 0.33600000000000035`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlXtozmEUxx+7ve87WspyWQtDLZKQ0JZrtGlZ2IYlYS3JMusd1tqNRNbQ
pin3KWlJJrGMbESIiLx/mLlFS8ithbBLPqfn+8fT5/zOc855zjnveZ43pWDr
iuIo59x+VjSrOs65mYOcq4LFQecy2CwP+mVyA6yIce44tjvhS76r0H+AD/Ap
wvcJTGBvIzZJ8Hasc9+QL8F6xSmDsbIx2/PytRgZAec6kAthJ987kLvgD/x/
Y/8d3pd9M3xNrBJi3oF9+Pw0e1jK3kLkXfCp9K9gJYVOsFrhY77for8AD+O/
iTiX4Ix456awPzne98J6UgDvY/cJ+S4sYz+BONvgScWshaPZa8RmBGzmO81q
hz3416B/BB9SQzTyF5jKdwrypDi/TE6DO5V/GHao9mewTbLp+ujdReQeGOGM
Zcjv4B+dZWfWYfcCfXmsz9VyLoA39dvZb1it/OtgKnnX4TsYTmSdRp4G0/V7
DYNzJZtuLT1aiV+eUfnPhlEB/9t1I/fH+Z4ko1uOTyW++XAJPgvxXQUzpLf9
DOnnGfE5h286nKXfZQFMYSUhj4KZ1DCdWnJhE3YPsa+G99T/O7CI7wj6A7Bb
tXfCNs47Zr8RfKweWi9XKOZieFcz9gauCTl3C3k9PILPKeybYry/xSmF45Xb
FDgSu2bs54T83Nj8tMMBViL64cQ8xMpB3gPPKmebnd3qSQ4cTKw4dIPgRt2R
dTCsfCyvz6we5PewXvXWBnz9FrMFDlWcZHhQvnUwjF0r9rkBf7+tFputVt33
drhGM2l3a7P6Y336y2pFXkuc7Yppsbt0fz/A5+pVBGZqJrNhNnbt2BfDvarX
6n6lO9sPz+ieXoRZsje/LM3nVNirflpfIzrrKqwP+dwsx2ydWwk3sNqRx8Cl
qj0PFkpv+43qofUyX+9AIfyoPn+FY4P+3EQ4TrLpenXH/8JEzYDNQlg9XA3/
ad7eRPu5sZ6X2/xo5ucH/EzYbGwJ+lgW8xOsUB/KQ/7ts/m8DHdo/mvs/rF3
A30pPKrZOwFjdMeHwBLF3wdP6x2w96xJPbwGr+ttbAn6mq32IPPTpnPtfvSr
Fqvpl96lgRj/Xtt79QQ26L/gClyknqSFfE6WW0fA52o5F8H//Ojkmg==
         "]], 
        PolygonBox[CompressedData["
1:eJwtlF1ozWEcx5+znXP+Z4cL3GizqTV7Y23MW9G8xYY1k5fJFWZJVpRyENts
ZDRhNhQXlAsps1ZeZtlWbtQ2WSlMk5dQhItlQimfb8/v4lPf85zf7/m9Pv/M
6n0b9iY552ogDPWBcwMh5+7BfvShiHMHoQ7q4XvMuW8QSXEuCunYtGN7C7LQ
n6POJdAtEOb3KWw3EmA3XETPgCwogtmQ4M4DFkOx3pHEW3gPH2Bz3LmqZOdW
QBm6FJtVMB8WQA137IS1UA5L4962EOahZ5PDdcsnFx3Cx0Eu5MFhYlzh6Coc
QS8LfC19UIaeEHhf1ZSE7oS36J8wjO6hBw9hFhRIU383vICXUV+DavkIn8I+
R+VaAkvUA3IogkpYbz1Wr9ugHfq5s89iKNZMzvLNR75brF71aDs6nbNpMEqs
NxAQI2o9V+/zrHbdobtqAl/rc6hFv8ZnBJ7BcNjnVGkz0qwabD/UgxvoX9TY
EPI78C/qa1St6rF6XRD3s0iDTHQ1NguwzYQq9CtyqrP96EEfxWcE9x/Qim6k
5mNQDw0pvmfqXTbkwGrOHuHbC+XoTZwVo8tgL7qDGLdtJprN4RRvK58E+nTg
a1cPdqFTsIlBNuTA3YjPJZn/B9Al+Nw0f8Vuxea8xVCsLrNXDS3o3rDfrU4Y
R4+FvdbOdaNPcMdxq1G1DnE2CJfgsubAnbUh32P1+gxnLdAG7dAEjdAMp2zm
ozZDzfI4Pk2Wo3LtsP3VDK+h59j70HuvQNdaP1XjSuVj81UOT9DbbF/0RlYE
PkflehbOQYwZj+EbZd6T4n6HnllNQ5Zjs9WgWpqJcdJ6oF5sDnwuyi+BLuOs
FHZANRyM+dlqxnvQv+jxeMTPTLPbZP6qqRydhk8qFMNcCMV9bsrxK78XRf0u
aie3ohfb+9c+Tw/8G9RbvA8P9P3j7JveAAxCYdzvtnZ8Ibor5ndZO92PnkKM
yRBADJbbe9CbXYOeaN8X5ZuPTrX7lOOEuM+52HqgXtyx+/VNvaDvKDkXQjpk
wJeI31Xt4GP0Os4qzEa26Va/YmSh/xLzj9Wk2vRNj1jP1LsMu9tBCKba9147
8ZvfrwP/LdROPUX/B0GuxUQ=
         "]], PolygonBox[CompressedData["
1:eJwt0l1ojmEYwPF7e717XycKbw4QTTYHVqQs7cABZjshcUJOZj5OZJZCmNmm
Ji3fK5OPxpIDZUmzOXjHEbUlRRkH5qMlakpCsU1+T+998O9/P9d13df9XPfz
lNbv39xQHEKoQBonpofQjAbkJY7xo2kh3JAb4ff4gC1oEqvhtViHKrV37Mnx
TMzCSEkIrzGGQ0UhvOEWtVft7eNWtOEczmJb7NvOR7zQW+tarsZ67Ms62xmN
vBO7EvSs1LuZ23ASFc5eiovoU3+ey9WWYQ5yYot4KhPCT3snucRzJluYJZlp
LvY4fzUPyw9hEF/VP+ObzulGK9aItfAn5/zQ+wsP4jE67b+E/niPXbzQLHnr
BTwP8zHq7EZ73/E4vmE5lqEaK+Rq+QJqkpn4Gq7jaMp9YTdm6HuYT2OxdVPM
JTVZ75PBZ3uO6zHG5d67DKtQao4lXISAce+VEpvg2fE+0lyMFF6K/xb7zr+S
dboQT/IfnbdJboorxVfin3iv2CTfE6+yvs230IN+NQ/xIvYdSBfmS+Z8EO9n
gLfGO9/OG7ARHeZ6In+A23EK9diBupg7mPyjavfaezd+v+Q75uI/MeG7/sFf
dOEyzuCV+k4ejTM95yEMR5L1/TjPU87H/+RK7JH06olzdsTv0s3/AUCjdps=

         "]]}]}, 
     {RGBColor[0.9124999999999999, 0.6512499999999998, 0.32874999999999965`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlFlIlVEQx8+1z+u9IQRWUGJBEVnRhkIrhEJUtlFR0UMvSVC0mUGWGKSR
SyjYTa18EAlDobIyMvOKSClJy0OLkQSGSQ8S3IJ6ifbfcP4Ph998883MmTNn
5szKL9hxLMk5d441gdUSONcMW2FOsnP9yIvhpKhzMQwD+DXiXDlyKnJB2Lnc
kHM7YQnfr9GfhUX4PMd3G/zFmoZNCJuT/HuETT4sZPUgF8AW1hByF3zC3jF8
+2ER36/QF8NT8m2Ad4i1j5hxOEo+Z9C/hftZa5CPwo/YjSD3wFGdqxueVm6W
Y4Ni1kd9HpbPQbiQ9RQ5Dhdg14n9PLiE/Rax71b4M8W5ydhMYa9N2tf2/47+
Lzaf4aDk5yn+PHauGNyA3Uzsl8LfxE3FZiIxjyjOPvgl8Psm8T+PPNotPsxW
/qvhID6H8H0Bu/j+iL4eHsW3HDkL9qkOY3BMdbB6ZCqHLPiQ79vovwU+rsXf
Dh/yby82TXBYNX8H5/I9H/0amEHcRuQVsAb/Knyr4GPOPI59H6zAZzNyHfwd
+L5aRvxK3Xs13CXfQriOf8PIxbBWdbsC37PakEdgLj6t+C6HcfXAMFyrezwM
K+RrMa4qn15Yxr832JyHnfgcQL4J62Vjtv9YUfRR9M2qQze8RaxGYh4PfG9Z
be9Ffe/aWe5bnTUjNiufIn52IujTkn3+Q/hOlWy6Z7rHAbhed51t1EzdgNc1
C03wh3rGeqeEWBVWK3iOVYlcGvh7svvqhhfVz9bXbYpj8a7xbzc2bXB+2M9p
uuWg+10NO1SruzAl4mvyh9okdMYP8JJqeBuWKqbF7lM947BONbRaTo/42UmD
53XXJ2Ca7nQV3KJ+sL6YG/bnjYb9HNpchOC4ZsRmJUs9vzLwd2n51Eb87NkM
JmCx3it7t16ql6ynKjU7l2GuargRpqu3w1H/JtrsxAM/D3aWGJyjmlht2tXn
sbB/I+yt2ANnq542NyHVeQasZr8EMTts1pSDzXGZZMsrQ7Wymq3SXefAn5rZ
hJ1b+9qcDaiXWmCN7v0CzFQNrZa92jcOH6ifra/j0t9K9u+CvQ958D95D9Yq

         "]], PolygonBox[CompressedData["
1:eJwtlVlo1UcUxifmbv8YEYxQKxoXBIl1aW3dEsmi1rilD21yUUFtUjcKLlg1
XiMYNS5RHyoq6IMmElGQZittqQqKC5WiDy4tSNXah6JUyYuCy7WKv49zHn7w
3f+dmXPmmzNnhtWt+XJ1rxBCA8TgTW4IWfgbHsLkKISjDGiH2ehsPITX8B88
gU8j+09jBqKX8W0p1EIdZFh0F+vuhO/QA/NC+BB6Qz408m13sDEN6JPJENqg
E7ogDTWwEeqhmBiniHUeZqCbmLMDvoJq+IGYPax1F5rQt5hzE+7DA+iXCqGA
ue9yQnjO7w5+r+D3FjiH/hgK0RGMQL9OhPAKnsFzGMCcD5L2Tf9NYA+fwWgY
Az+R0x/MvQPd8o6cjkALtMI95vwFj+AxLIQFsBSWwXE8PwbNsBeeMaeDvVyB
/9FRynJTjiPRWeUIi4i1GHqStjftMYveC82wHFbAVsbc9vy2oQ8Scx7ja6ET
PZw9DPMz0lmti5uXil+OTng97IQe4i5mzCKogXSe7UF72QFN0MkeOqANTsLn
7GEGlEIZTIzb2ooxEz3H62EPVKHXsUYFuaWhET2LGJVQBuVwxvdzC06j2xjz
rY9vQcfZcwzyoQ/M59uYHFtTa6+MrJZUUxWR5ahcW+EErCWHo16/q2J2xqPd
I3l1gDW/d4/ldaM89hpWLY/1/ekMs8yfyrcSKIQhSfOsxvc0y++E7kYO9Mqz
M9PZLYGvk5ZTq9eIamVPzLySZ9vRQ4k3BAbB4LjdmY2ek3J77LUnT+RNtd8d
nYnO5s+U3QXdiZ9TloNyeYI3T6ErstqR5+3obvdH+/s1ZmdS5ndCdyPGt1x4
S67vYDoxp7kH8qKUGEWsVQpz0TVQDathDdQR45L3n8rIvum/DGxOmSdLfE2t
fTphZ68auJawHlTrnsibcu9H8qsiZjWS9nrIoFPEOOD10A9dm7LclGMl+g5r
3IYX8FK9zvufcqxHl7BGsd9p3W31PNWOPJJXc73+BkARehOe1MN62ABX4Yrf
Gd2dBtjsYzZ5T1Zvvg43cq0HqxdfVp3FrWc0+xzNHY8nn0AVfAEfEXOU56hc
rzHmN4+p2Hf9/OXBv+iLrHnB96y9b/Bc6+AbGMWaRR5jvMeo8p6d9hov9J6p
3jnF/dAZFKN7vL/Jn1/QMfdfOfxD/HP8/h39AC6iM5HdddVfA7ra+4M8lbcZ
71d6A/ahzyast6nHtSfsTen0N0Fvw+CEnYXmj0P/GFksxdyv98XrXT19d2Se
X3fP5F0f7y3yQF6UeW8r0V2H/Mh6pXrmoMi+6b8C6O8U+B3RXdEdeetvsN7i
w3w75G+I3pJJ/v7Jo77o9wJo9xA=
         "]], PolygonBox[CompressedData["
1:eJwt0k9oz3Ecx/HPltl+ckMtjTYHMhdyVM6UA+K2Cxflb8ufcCDtT0S2Lz+c
RO3g7KC2aWTaT5iidpDtp/YrWpPLFDYxj097H5693t/3+/15//l+Pm2HT+0/
WZ9S2ogGfF2W0hfU+Xjie4Z9lz3NHqTP8Bwrlqe0si6lTbQdW3CxKaULKNCh
6G36rZTSLGqo8k3TbrldKLBHjR7aJ/eI+C3ag1681GcUj/Fd/5GGJX+On8BO
+cfpZf5LKMecV2hh7oLdS7vQjWpjSlP4i5Kzi3QoZh2kY6igU+5VZ2/QMu6g
z9w3cR0T8gfoNn22Yi/eyt9OK2qOYQQzdhul9+V+cOYcPY0zuIbXfP10Xs+F
piV/jh/DU7FOWsYL9tnon+d4Z55x3IsdK3RWn3/6vYr+eY4f/uscxnFU7A39
ZcafKMX9/WavZTez/7DnsYD6uP/22DHv+lCfBxjKKjZA98Xu5+MO8l0Mq3dI
vY/0Eyax237r7bGLHsBB7MBmvg20FW0Yjv9Wpv0oMKHPIz3ex955/0rc1+f8
HtSoxflcZzVW8bXQdeZpQTVqrMnzxfy1eOv5zf8HVVRzhg==
         "]]}]}, 
     {RGBColor[0.9374999999999999, 0.7137499999999998, 0.4062499999999997], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlXtozmEUxx/be49QlpG7fzCvwrS211yTicja3JrYavaHy7yjXCbkfguF
P9xyl9RCpMTkFkJiEsmaS0wT4XVduXyO5/vH0+c853ee85znPOc8v+5llYXz
0pxz+xjpjAdR596haICzA86tQZcF3zL/jP551H8zm3q4j0U9sdkDpwadu4Sc
CS8zz0WuSfffzGYtXBJyrriFcwfg0bBzd5FXwmf4asTnU/hee6XFnNuG/Bh5
J5yI3Xnsp8AdEecK0C+FWxiFyKvhOMZA5Mkwjt0h7LNhBfN89DNgpWyK4RT8
njMZPsHuG/YNcI58roMdbD/0GXANcecgl8O1kk1XorNbDmp0ltNRf0477xFY
yvpa5Onwis5VCw8yHiDvhd/J0QT8pGBS+oWwOeLj3Ih8WHpbt0Hx2zmGMI4h
J2C1crsKvmJtEv1NeI35b/Q3LTfEWsdeB2A+8xPoc+Fhxbwf9mG+BbkVvMN8
OXIK5rHmGmtz4D38HsR/nH2P6Fx2b1dUA1YLn7T2NjwuG8tBE7VVg83ZgM+7
5d/hr4S7L2ZdEXzJmkXom+A07DZiUgYjiq01HIRdHPthcLHqrRpeJ740Wwuj
7LedfVvABXxrhU0S1su/7ZNQDrNha8k5cBT7VWNfBHMY5cjZ8J7uqwHekmy6
q+z3A/lG0NuZfRv4kFhfsNdpWECsw7GdBF9EfGwB9vqqXFnObsjPYxgM+zgb
0c9Vb86HXVjfAT+Z8JPu9yMcrZovhUd1F6fSfd1b/Y+BI1WTM+EI5r3Q58GX
6kHrxQq+1WGzKez702r7PlymHtwJu6p+BsNKxWbvx6+Q751Mi139OwmuUD6X
wYuqz1vwjN6Wc3C8+ncAjHK2ILH/Qb9Z8awP+7u0vD1nbZXisbi2ysZsTyrn
Z8O+l6x39kf9frbvazicOKqIZxgcS8x9sS+Cu1RvSViifq+AGer3ztDxLQlC
Ad8z1jsLYa1qz2rwkPJv9xBQPbSDP3S/j4K+Fq0mS+EXrX0T9H1rcV6A/fHb
A30+bKmcdIS9FbPFnlIdPoXTZJ8I+VxbzsfBXorZYv+rvquHo1STQ2L+jbBa
agr7frM8VMGB6rWsmH877A2ZBZsZ7bHvaHuGvJwJ/6T789q5q9Wbm+B59f4H
GFec/8+neo7H/Pti70wWTMne3oxOqtXuEf9G21u9De5WnHZvbXWnfWBzwPvp
h5+Y9Pa9UHkrCPn/nNVt/4D3a/4TcKjyZm/AR+WkEf7U3dkddlY9dIN5ym0u
/AepMPOd
         "]], PolygonBox[CompressedData["
1:eJwtlElsjVEYho/b3vvf/yJNiNDGEDbGLmjFWNGKKEKi0RIxhyBEqQUhMZZ2
QUJr2BI1xBClWNwSgrAwJMSQGBIrqomxLDSI5833LZ7c957/nO984xm4vLpi
fSKEsBZyYWIyhAkwBypgciaEwpwQSqEc3cCmQ1ALe2FcFMLZLiE0Qr50HMIZ
aIJTUKxfLjgIMXoLbIYjcBRaUyFk4Q28hZnYnAGzYDb0isz2dvjJ946Uaa39
Rjfz/T36ITShL+LzBaiFvfACG8/hMTyBucRQ6fFMRU/KmFaMReg+fp9iGoDe
jY1dUAf1sDuyu3TnOXQxa0WeM+UuxR0byWMNZPxO3X0fHsA9uOs5VC57pkPo
AR3Y+gntxLQZ2/shzf+/2PwDGda7QvfIvmlPEp0bW26V4zz0JvbWqG5QCu2Q
YG9v6EyaD/fdB/nSnTPdoC/0g53s2eExK/YW1q7Afjig2nLmNGShFQpSZnsE
DE1ZzmvdB/lyQzV2G7JVQI6T5DofBqGbWfuI721wObaaq/aVUAXXyc01OA8X
IAMxDIYhWufMOe859d431r6mLSbFVpixu1Tf0ejh3s9a648+jM+NcEm9BAWc
zfeaqDb1XvujcAy+4tMXSKBzYCt7yvG9CKrRH/n2AdrgE0z0+bgJU9C34RZk
oTWyHGb9jM5W+OypBqrFOGIYC9NhRmwxK/ZRUKRf9oz0HlQvrmHPaiiFMpic
a72onhyP/gwX0XegE700Mt+ewSp0nvfXCShE9/H6qod+YH8Zd5YQawWsQ7+L
rXaq4Wv0S9ZeeM1Uu3+x1fs73z/EluNLPvOa/VZsZn1mNbs7fb6uq8cjy7ly
fwtuJ20GNAvDYQSMisxX+TwMPT+ys7KxTd+I8TichKZcq1nCc6bcrcSnFf4m
6W0qT1kvK+ZB6D1pi1Uxr0qbjZM+A5qFDZyp9pwr9xPUl75/Groustwqx8vQ
Szx/2lOGrvL3R2/SYvRK7hyju2EBuiRlWmsL0T3xuUfS3jS9bYu8fuqxEvQ7
+OXv01PVz/tfNYjV/0mrvXqgg/N12NznM6BZaPH3VDZeoas8n8rx7Mh6us1n
QLNQ7PnXnjnoxeTgOLFdhU7iq4xNa+0R/xMZ6wX50y1jM6BZOAQNkb1Bfb3n
1fvz0jZbmrGatM3AdK+ZavcfO9nVxA==
         "]], PolygonBox[CompressedData["
1:eJwt0klIl0EYB+DJNg2CaIGKDi2XKAvSQGy3UxsEoh2ik2Kd6q/tEdQlK6M9
C6LF9kMqHYo2FS2UokOIYQQZbYTRJaMVWp+hOTz8Pt6Z75355psJZZnidVkh
hJkMJHdQCFOZzcR+IUyTdf1DOMs+JplzWvZkh3DYi69kN09pVC80fj7Nj+9V
p3e2yk1spsHceg5RrMd+2aHezrXUo02uGBBCKVXUqK2UjTRQyS61jFxt412e
K2QZ5cxI42tlHvlcj++r3Uw9Yq9z1q7jDlX20iRnMdnzODmGsbTp2coTvutx
T9aqLzLvWOoRewW+Ore/g0PI8Twk+/9+4r7G02zKKvnF+Gc+8Nv8PvnLN//k
JcvN+yaH2WOF5z9pLM5ZprZdbb6cw1xGp96j5HBG8I4svVvkXZqojudCSeqx
U65P53syngfnmRLrakVyCUvTOnG9kWlPBelc4/kWxv+kNln25ITwybm8lk00
85hetUZ5lXouc4kzdBq7IG9zixu8V+uUJzhOLd1qV2SRb1nAdO5bd5Z8m/7h
G/mRvuz/9y3eu3KGmrdBdqd/+EP+4jeV7nmGEnKdWbF8lv7Dg3Q34x3tUX9O
L1vMeyFb0r4upr3Hb3iovsP4I9lOBwfU91MTv8/8vfJU+vYqmaGSfPvOYzH5
xpbJo+7HEfbRpe9BuVHPUs/b0t4r0zpxvYtp7IJcQ4HnarmbPSyMZ0hB/A/W
mBf/T7qL92UrbfwD6qSUhw==
         "]]}]}, 
     {RGBColor[0.9624999999999999, 0.7762499999999997, 0.4837499999999996], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlX1o1VUYx4/dl907XYzCMZLe/CPnW2gTMkmzYSE1hdbtn8gKtYUR261J
yPojX1rlSonhy8yVc5ik5QtKUt5rTGUpJJqaq+DWH415kyKmhCSJ9vl2vn8c
Ps95fs/znOc85znnd+/i1qaWW0II+xkJxoRkCK3wCpNvkD9EXgvvqgyhFt1k
eDkTwjs4VWdD6LeNbOfxbS42s+Gdtq+BM7C/G/sFsJ75FPRzZIP/R+irYJFR
Qi7BqbaX3xPM9yI/BBeyRhtrPZmMQ/Ik+CyxcsR8WrGZL0WfgXPwOYxvA6xn
nkc/HaaIW4l+DNyG30z0e2AS/yS8hv1l7A6hvwqLFSGUR4XwNVzGfA36ifAi
diPEuQHfwG88+g64xfJm2GZZ3xuczzLtCf9e9EU41nsZB3dZr+8/k9+b2J+H
/fgvRD8A1zufLjg6FcJO9GexH7R9CZZZ4xLycDbGVfxp8Jz1+p4n1hj0LToP
4pxCboBf2eYI3IFPJ/rtcB3zk+gPws8YF5E/h9cTsebVyp/5IPoT2dhD6qV/
EnEu/QC8anv53e/z0rllXf9auJU8zqJ/HubxOYPvVriO+W/ou+H3zlP5vura
NsNO28i20mcd4B/U6zp1+70iDsnDsMM93AV/xaeMXILT3KuTKmONVKsX4Xuu
g+oxkOY8iXMSPorPj9i0wQdSsX8ScAdrv4/9v/AX7BZjX4KzbC+/7a7z67DO
vaqenc1oR26ED1qW7i3nrNxb3JPqzQJrLGKtXtjKvFu9Db91nsfhDOemHL90
PkfgY76/OdjpPa6GfY5ZhEudZzNs9N18Bd4kVhVxEsRZy1iAvD4dh+SNcInP
tBku917mw098vlvg6WTs5wvwgPPfnYx7kHwQVrnn1fsnbC+/HP7biFOXjUPy
faLja50+xjDyp9nYu+rh0/BUJto/g/yX79og3Om+3QTbGceQu+G1RDyjm/CQ
753u3z5GM/KuTHw7VOdMKtZLdVuh/VKLHDXpgWW/pXpTL/nul+EKr/USvMfv
5CN6Z1w31a9s+wL82LX9/954j2f0Pjn+EPzB+z0PV/q+N8F292E+Fc9P53ir
+gKfh7FfBJ9zfJ1hl9+fAjzA/E+dERyPz2T08+EV5jXItch1voO6i4f93u6G
H7hWX+huYj8K+yG42rkpxxHWuA2bvyvindTd7IMNzu0FkTEBeSbsdq+qZ/Os
PZeYy2Gjc3s8Heui+nwH97s/N6TjGlrrdnyb7KsY/X4rynBsJtpUwxH3ifql
1+tugH2+a3obBmzzEyx4j8Ow6DqoHj3uh9fguHSsW006/j/073gbTvG5jIZT
LUt31G9dfyoOyZt1r/0/3QfvcH1mwR6vq//ey8yfQr8mE9991TwH37V+Fezw
+e6Bjf4v18Mh//suZONbpjekAP8Dxl4ePw==
         "]], PolygonBox[CompressedData["

1:eJwtlUlsjVEUx7/yvdfvewiKpkhNC0VV1BCUlggiwqLVmEs8MRR5NS1Ea0FD
RW0JEiRCQo0xLdRCDImFRERqngUJFjUlJDR+f+csfun/3e+ec8+555zb/uma
iky7IAgyEMLyOAhusHAWZqAfZwfBI3gFr+F2IghuQQs8hPmszYNaqIPVsdnK
xxb0GpzW43c/1KD3u/+HcDI2G9luh3poTgZBOisIZsF59ET2HPR4ZqKns1bI
t0lQga6CRbASVsE59jxn7x3Yjd6bNF/yeRl9MgqCFXwrhwZ0N8hBF0Av9E32
VLO3Eg6jDyVNa+0oeoFyhjzoCWWslXoMiiVXsDcLPvO9Iz5T+O4LRZHZyLYb
dIcu5NwZimAYvE+YrXx8Q+9irQGWQhoqU+Tenr+wCD2XO50DC2AhfOb8TxCx
N4bRMArKoQJKIst1AkxGD8HHUHzlQX7K9pR7TVXb+sjuSne2B12Ysr2yGYku
Yc846Am9YCwxj4FCGJqwGCLPUbkepybv8fUBTqB/EPN3+KTYQ7uDIo9ZsU/z
eus+eiet59R7f6ENLrHnoveoenUxVEEplMEDYq71+M+hm0LrRfVkJrQYFati
UCynvT9kcyWyO1/qPhe7z1LPucRzVu49IBdmp6w2qtEU9DifB/VwPno0jIIY
Uo50FrSDEeRY7D2l3srzftIdDEAXsacRX0fgLvE94/dTzSk8ia0H1AtpWAYj
I+s99eAg9Davp+qfRi+JTGttJfq5z0+raoT+yZk/oBW+Ji1H5ao1fftFnjXc
5Tr4jX7L2hvvQfXiWO83zVgPdKn3r/pnOHpT0mZZM6ZZa6IWX/D1CLag98X2
VujN2Iy+GNtsK8Zr6PU+n/KRUa+EFo/qq7cnjzNC7+8+6I0J860zdqCz2ZOE
FHSAM36+ZrAZXc0ZVznrHqxD7yH3Rp9JzWZWaA+nfMjXgdj2ymYtusznSzlP
Rb9m7RW8gJfOC6+hajkwttqqxse4r9+xxa96vIvtjdNb1wC7oCW2b7qPy+g2
/y2bmPOaifEjufyB6+pRn199D9GnWGvyGbrkb/B2X9O3Cfgb7z2r3h3s77nu
uAD9ILZZ1kzfR1d5P/1/Y9DzYC5sgI1QHFqvyF616oLNTp+Pfnobsi1WxXwt
22xkWwdbI6vxJJ+HmehO/v9BPlr5/s7fT9XwQsJqqtp2hRz4B+1Kzcg=
         "]], 
        PolygonBox[CompressedData["
1:eJwt011oz1Ecx/HfNrN5mGa4FldShKaJ2bUL24U8bEKZtXLDbCWxpeRhG0la
mae2SfNQbijFNrbabEWYGCsaE4sVE7nCvE7/c/Huc/qe7+/z/Z5zvr8F5Xs3
7ElPkmQVMtGZnSTbBTpoPwbwKyNJfuINSuRM0HVTkuSgdQHNx0pko0Lsd8wP
3/2YKh8D2J2WJI/o8DReeIrPar2kZSjFJrSIbaQN/M7wO0xrUYeh2EM3fYCH
6JHbjS588e0LOkudHPWW0OVYMTX1ffBZH3vfT6/jGjrQKnaDFjvzfD7r6RaU
Itvl3LWfTwuxFunqpOGt/UPyh+n3rCT5hjH8UX88K9Vj6PVWRuqeO+nNuL5E
L+AiDqjdKHY19hR6+xTP9JyO4D0m5VbJW2Q/QRrqne8EmlCsbgMdFG+X0k97
0Tcl9Z7hXT/iON8xWsnzvnURXYNCjMv9ijto5nE7fh98zsZ36aYb3cMT6yO0
Hg1478wjSHhP55uZnZqPMCe5cUaWhvuW24JKDIpdptXOtg87MVOsKt5NuKNj
WCh2ntbxrEVTnNdmejTu10SP4NUQ+zqHUXuNdJnaNdYldDO24LEzf+Jzhbai
DTtiX9toGbaiOfr00F70xVkIM7Eh3kUR3cWzHNXxTStolzcp9zbv6AeMIlff
eepOxLkJ85MndzYWxz7n0X88/2JGnOtJ6wnx78iIs/nD+l6YPfun6Umcwlz7
c/AqzkOO9RWMWbfFNwhvccSZB/RSH//F8E92xv/iS6wVavaJD8lrj/9dT7yv
cG8X8cxeC63i+dq3q2kBVuE/5l2ifw==
         "]]}]}, 
     {RGBColor[0.9874999999999998, 0.8387499999999997, 0.5612499999999996], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtln1Ml1UUxx/9vWMamODK1SLDppXZUsFCWGY1N5kFJiJgC9SICanV5phM
JS3tZW1tpUhZOskQF41cyIIZOhN8K9JB6GYkSiWUsXzBIOlzut8/zj7f5z7n
vp177nme+LyX04uHe553BvNhyWHPe4yGXDjB73lFtN0Liz2ny7BCHEfAAjg6
6HmD6J8DnreC53j0KtiNLUZfhxVYInoPPK92e3+CPv3oDngXc7yKjocdzP0e
axge8byb8mmD5RrHxjuILUI3wyH5mG8Hz7noTpjAWK+hk+BI3n2DHhNwZvp2
OBOrQ4dhEtaGXgFT1G7v/6L/DnQDPMbaXmBtlbBP7fb+CtaEfgD/eq1zP2zC
bxX+R2G/3405AAP4VaJb0Fmei6/t51u/az8Mx2v9to/7dAYTYVqU56Uz9jyY
EmJdw4gpzMTq0Ivgc9pjHJyDnUBnwnH0GUvfMTAJv934J8Jq7Dj6dRjS2myN
xcy3xc4OnuU8BtnLOfgg+xmBvgV28vwv+iKM4TkGfSuMtRxCJ8FR8p8MF2ht
tsZHmG8n806HOdpLNhzGfDn4DPlc/lnu9aA/UI6tg7F+l0ujYS/PaejvLcfI
yXzGaYSztXeLwUbWd4Q1rLH1B9x5JUAvyu1riPZa5v6Fvl/Dd7BudD18A2tF
b4R50pvgesVtQ8idmcWt1e/ugK1zA/yUObrRO+ElnzvvRvgKsZjKvAvhfOb+
Cp0Fq7B29FY4D6tBF0XcO/Mpg3djFeho6Iu4+zLEOE3oS+jDsNDv7utSGCv/
e+Bynt+mvQQWSFvbNt6dxGeL+UiXwxexenQ+bFCcD8A7lUuT4EPY/eiJMJe4
jycmKfAHnzvHduWc+cfC2VgqOgPO1R5T4VT1nQGjeN5F+zS4QHt/FiZrPcvg
31gPui/i1mRra4OzNH4ybIHZtJ+E0zXmwzABewt9nbjtCjs9gbZ9utdNsBbb
a7kHqxSrz+FW/OfgXxp2z9a+Gmaqjk2By3z/p5a3xOql39WlEPxD67Sc3az8
nB9w67A1XDWq3d43q4Y0hF3uFKleZGsum/OG9tgPj7KHLvyb4WlsAN0Bg1Hu
nvrgJuKbRJwLYD/v/rE42D2W/yAsxQ6hP4q4vLH8eQIe1/g2z0jGuomOggMR
p62tUXneBEs0TqHFW3ewJuLiYvF5HrbrHO08l6ju5cN01Ydp8HHWGoO+Da5W
/NfCp3meRPuTQZc3lj+pcJb8rd9YLBYdC+diqehieJr+JYzTCj9h7gvoHbCE
uPdY3YMLVW+t7lbQJ4O+2+CvOhc7n3Faw1OwRmOegtWqn5Vws2JusX+Td0vx
qYJl2DPodXCP2nfDAHYN/072/qPutd3vtdp7OfxC8bTadplxS/H/E36smmO1
p071sAFeDrn6HG31WDXZavMafTuy4Hb8CtCHgq6P9T0Aj+g7a9/tg/Jpgj+p
Zu6DtVZP0V2wWjH8zL65vHvfzg5Oxt5FR8Pf7SzRvTBPcVgPrwadfxw+H6qW
Wu0fpb4x8A59vx6FX+rO2t3dq/rZEnHfafteZ8OziskZ+J1i1QenqHbNjHLf
aTvT3+BK/Q8shzP0LUsMu/42zvaAyxXLmWPwGnbD7q+1KQ6dAZcrljNFsFV3
7RQ8F3Lnex5ewAYsbrBHZ2RntV/foDr7NsrnYsj9Q9i/RCTg5rN5r8AMfVOy
YLf8bexe1bEu2BNwdyEu6L495p8WdvfB7sVKGAm5c+lBL9Y/YQ7MVw6/FHT/
N/afUwX/A8c6ZHA=
         "]], PolygonBox[CompressedData["
1:eJwtlntoVnUYx497L+c978Kctg3yn0QyMp2Vba5aDboLgrJBsWu0kS3ZVpKa
DBe57iMVglLbMBBL3ARhpSZIMkVTvNTKtBHI2ruKnMyMzVyb2ufb8/zxffmc
c36X5/fcfu+sulfKmrOCIOhEcXSIn2/QB6gdzU0HQX4sCO5B98KFYRBsnxIE
G1BBaGM0thW9gW5NBsFUdD9aiI5GQXCRDYbRt/C00OauRRH8ZioIlvHtYVQL
b2bMGfgAeimyOZp7Hu2CdzLmxSyb0wZ3sedm7N6NeuC702arbJ4JjzGmnbFr
0Gn4E2z6GO1F+9CWyNY+glrgzkQQdKBa9Dza5fu1oD3w8shsk42N8D7O8Ctn
uYouwE2sWQ6Xokb4CGqAW9ExeDE2PoMKURGaSJltsnEHXIEegBejtfBI0uZq
jcPw68xZg1ah1e7zVn+nb5m4+UI+6YbP4IcquBp9D5/D5p/QXtmOhlDG3+nb
Rs68AW1BW9F9vNuBLZtQLLIz6Wxz0dPwOsWIb1+iZ+F694/mFMGbGLPRfS7f
d7p/dJ5t8HeMGWfsv6gPzsOHH/FtJ7odLsYHczw/SuCHQvt2ED0aWkzlvxfQ
SXiSNSZ8vWvwCY/v/zkEb/X8yqBtkUk8hD6DLyUtN5WjU1m/39ebRL/AJyMb
K5tl+3rPX+XIe/Ah5td7fv+p80aWW7Jhd2QxW+U5oFzIisy38lcaLmXObOYW
o3r4tO8nG0/BV7weVFMjevb8kM/G4ByvL9XoQniF778HLYGbImO9a4VrUuZb
naEObk1Z7ikHX4MLPf6KaUlke2rvG2gCboss9sqBdvhx1OH7LdV5fD+9uwMe
9XjrTDrbj5HFSj4+q+eU1Zp80g+/jI/aPJ+b4XTa9r6OknAFZ9zv5y2Dr3m+
V6K/4Tx8kuv5OhO+wru/0Ai6HLMxGtuM7mL9mynbWzachcf4PupzNDdkTI3X
0xSNjxlrz3F4hmLAXpM8T4cjxqTitobWynV7AjREfQ3zronHCnQRHvb8Uw4N
wo94PytFT8ANScsN5UgNPBBa71EP+hkuT9vYcp0LXorK/HkZPEv5x16r0Wy4
Pm6sd1XwdFQb2Bmz1U/j5hvFQLF4Kmm+VA9YkrQeoV5xFB1DJb6/bF4AV3p8
TqH1cCxtsVM9BfBK7yfqCeoNGcZMwL+jr+EEY+JoXHmC/vF8UQ5dhX+LbD3l
xB9wbWi9oQ/VwdOIYU6W9ZDclI254fXzA3whMlu0xgBc5PebbH4Ofis02/W8
Dq7y9dWDiuFh77e9aBTOx9Y8t1m2ZxIWa8V8GN4f2tlk37vwvITNPYeK4Ztu
j+rhOnwLNmdnWYwTKfPBuPds9e53QltLNlXD1V7POu+D8Fd+P+kM3fDbfh69
64Hf9/my6UN40PNJe2br7vP6U47Ogb9Qzrq9K/2O1F1ZiapQnBjG/D+A/gss
8n6t/nQb3JiwuTrzfHiG93v1sMuM741ZLagmD8Pz2XOe11Dkd6buzgK0AB1w
fypnDob2rsDnaO6d7l/F6BLPfd5f1K+74FfdHp2pBT7u/UD1fALu8vMqhj3w
QMxqQzUy6DVV7vX5GPyk14fina/69PhrjW64gXHZlvrBcniR32/K0Rz4vPcT
7dEPH/f7SXfWp/Dn/n9HMVkB9/r/C9VPB/wfb0BcTQ==
         "]], 
        PolygonBox[CompressedData["
1:eJwtk09I02EYgN/c2p+2sA5biH9gRFFBErXI0w7mxcMO6jAoEFGp7LCJKIin
Dl2cZLdSVkEOD/OwCeKGbmk7qHgI6SKIpadsIhbroAODfD5+7+Hhefned9/v
/b73W6An1h6tEpFbcB5G7SLjOIXTkIGPJPZZ+4AT8B7uOUTuQgiunhMJYjfr
OepCuBkeQswmEoVu8JB7gX0XRK7geuw3MTyi9iv5OH4NE3DgFCnBTzjlG/v4
CeuPoQby1Hfim26RG3Ad4hzmGm6i72HyffgpPIOkS2QaCjBIXdFlnc+cswCf
qJ+zW32b/iPaUwveYH2G+AtehhWo5veX2edQ+zT97lH7j7pd/B1+QEm/9wuX
4S/4tf+L2ANeaGTdQ91tHIT7sMb6KmxBhfp1vK3xf2zj3u3wh/v8DVsQJneE
T6CL2EevtVCnmPgODJFrwC+pCxAP6KzMzCbhHbzS3FucggfEU5ozNXlYglnN
LeIs978AGVjnPGm8qX0VtN78zqtn/6Z36yQ+IT4Gl76lCnFRZ1PWnKlpY895
9o7o7M0bmOK+Wlmb1Dkn9Q7NXYaNyXXgfu6rifc0hifgjcOak5nXtL71HZxl
fQE+Qy/1OYc1OzPDS3wvwX4+t/W2zBsb0f/Oc3wGfp1yUQ==
         "]]}]}, 
     {RGBColor[1., 0.9099999999999996, 0.6749999999999993], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNWGtwVtUVvfnu/e733RASJAkIgiYkXyRaBIW8eHVqQCWBJNgZaKsDKY/S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         "]], 
        PolygonBox[CompressedData["
1:eJwtln1MVWUcxx/uuffce67JO/RHm4qF00pZS1EqbL5lksWkRZYODChMsdaa
Jc0mtqzVfFkrKczxhyStbM25AnpFnDM1eWmzzNzKAB0aRlYKQY4+33788dn9
nOc8v+fld37nPier7Omip0LOuXoIwy8R50b4TU5wLtV37iYaq7jeDFPwrzzn
FuLL4SKeEnVuO32rIRHfSdss7uVCLX4K7sUXQxfe4ZnfA8fwNGLeILYR0vE2
2hY5m0NzZTPnY/gquBF/Abbiz0MVPkCfMrwcLuNzaHvOWYxiz9NWgC+BbnwQ
Sp216V6/Z301xiW8E5aOxeveOsjElaMSfDpjbsCrIQdfTdtEfBKswXto24cf
VDwehG1tilFsjWd9lSPlajJta/Fi6NPaIMAnQAV+f9y5fH6XwfK47Vl71x5X
44+H7dnUan7lCjY5G1NjawyNpTU+gS8J29q3w/qwId+hnOJ7YCdeo5zjbxFz
K34LNOEXPFvrPPjUsz7qqznr8dfDNtZ70IrvDdvalJN9eLNnsRpTYw+z2QGS
6+ER9pdLDTQkWE3djv/J/avc/xUO4+XQgrdDJT4ZduOvQgY+GiMWb9CYXP8L
SYydDNfwFdxfyr1VsBevgUK8Al7CB+E1vB6y6e+xphRiU8HHf6DtTMjW3Iuv
g8P4fijE34/ZWNXwIT6NmExib4Yc/BNysM1ZDe/HFwQWqz1oL1PpM5G+4/Ru
4Mdo6+fej/ARvgWOhGwNH+Pp9Al5NscN+Ghge9WaHddXuB6PJ8JV/G8YClmb
7pVCE9d7IAe/wprXhywHysU12IpvgE78ODyLl0BbzHKoXCrmW/woY3QrFo7j
twX2LPTMcvGMuD1rrVlr/0vF7tkeTwU2h+Yqh8aYIS+DDvxIYLVwAt7U86Vt
W8jWOIPrIsYs0H8Q3Bm3PWlv6qO+g4HlQjUxhPfFrHa0J+1NMYqdqXcOvytu
z24uzMc30aeAvrOUE/ztwGpRe96lWgzsWakmXsQfiVnfSfAg/l3MakM1ejJm
OVKu9ExO4PG41VoajMdn0yebe3dAXszadG+U6xH6t+mddVZTqq1lgdXuASgO
rIZUS3qH/uD6cmCxyrlyvzGwvqop1VZh3PaaP/bfszJmc+sdKcHrYvbslQPl
4jTnxT8M1wvteB5nRpLOApgp983VJ4x/CYVcPwDNeBPveDfeDgfwLdCFn4NX
8IAxW4htgBH2V8p1F34OduN10IN36D8Nb4SL+Kj+b/AsaMW/hkr85ajN1QKb
8SravncW8wz+m2dnm848nX3ak/amOb7B18BJZ2Nq7OaorXVYY+JJ5CQ5ZM8s
Be/37WysgAt4q2+uHCgXbVCJb4RDeAvz3+fsDPoM/923ezojB/DUsfNSbZe4
fjRqe9F/5sN4T9TWkqT/JzyRNVyn95G2cXh31Fw5/xlfAV8kWM5XRi1GsdrD
eXx21M5m9ZmDf+DZ2a41/r/WiOX+c30z4AtZ01T6puk8x+dBNj4F5uMZkI5P
g+vxsxF7VmrrjViMYlNhAX63vkESrKZUW1lh+xbQGT4hbDWh2tA7MISn+fbt
ojk192jYziLVUCLjN0Cfs2eoZ/kQdDqrqWJ8RszeVeVMucuO2FmuGpmOn/Xs
W0LfNKfxg2PPrwjewWt9q+082IHXR6xWh+EnPDNiudKcmrvOt9h8WOtbH/XV
N9gZfJFvuZoLi/EnfRtbOSnHj3r2LaVvpkP6XvGtr8bc5RtyrfFd/D976kIS

         "]], 
        PolygonBox[{{1296, 186, 1287, 1285, 1286}, {1354, 1353, 1367, 206, 
         1355}, {1294, 184, 1348, 1353, 1354}, {1286, 1285, 1225, 164, 
         1279}}]}]}, 
     {RGBColor[1., 0.9499999999999998, 0.7499999999999998], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtkL8uBHEQx2dv7Z694iLcC5wGjXsACgkNV90l2vOnIDlBqfASElvQSBAS
D4DorhCNhMILKCkkItERPt/MFJPv7Pw+892Zaa7vdncqZjZFpMRCbjaRmM0S
bxT61MaHzH6GzU4BW4XZNfVl6u/oPd/f1L/Q0arZAX0XxBP8HvVLdKZmtgjb
RacL95FfJ+p6fw7+F91P3Ocj939rhjX0k94a/Bj8Ifkr/AM6gNtIvO8P7g4+
z8weK86I3YLp8H6M9nl7gTlHj6JXHkuZ99Yz31+8+ubjJg10Ff8S5gzdDJ8m
WjLXHPlt6jtrF+3UiF7ddST82+hN8GXso70m0R4Kbtup+8pf89ajV/vlkctP
N9KtdPt21LVHK+68UvismvmKOIlce/wDbkY+lw==
         "]], 
        PolygonBox[{{1689, 337, 358, 1688}, {2546, 757, 778, 2544}, {2502, 
         736, 757, 2500}, {951, 64, 85, 949}, {1001, 85, 106, 
         1000}}]}]}}, {{}, 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[{877, 862}], 
        LineBox[{950, 916, 951, 949, 1001, 1000, 1058, 1121}], 
        LineBox[{1182, 1120, 1186, 169}], LineBox[{1383, 1313, 1386, 1443}], 
        LineBox[{1603, 1556, 1604, 316, 1643, 1689, 1688, 1728, 379, 1773, 
         1810, 421}], LineBox[{2254, 2214, 2255, 2301}], 
        LineBox[{2350, 2300, 2351, 2399}], 
        LineBox[{715, 2451, 2502, 2500, 2546, 2544, 2579, 2600}], 
        LineBox[{2641, 2619, 2642}], 
        LineBox[{1279, 1294, 1354, 1355, 1296, 1286, 1279}]},
       "1"],
      Annotation[#, 1, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{863, 868, 870, 872, 874, 879, 896, 917, 918, 920, 937, 952, 
         953, 955, 975, 1004, 1005, 1007, 1009, 1013, 1033, 1069, 1071, 1078, 
         1097, 1141, 1143, 1150, 1162, 1215, 1225, 1285, 1287, 1292, 1302, 
         1365, 1366, 1371, 1375, 1436, 1438, 1498, 1499, 1501, 1503, 1554, 
         1555, 1601, 1602}], 
        LineBox[{2139, 2213, 2251, 2253, 2293, 2295, 2341, 2345, 2385, 2390, 
         2428, 2437, 2478, 2486, 2518, 2532, 2554, 2565, 2583, 2581, 2580, 
         2587, 2601, 2607, 2620, 2626, 2640, 2639, 2637, 2648}], 
        LineBox[CompressedData["
1:eJwl0jtIFQAUBuAT13xiFylpiUDLtgKx9Do1WESTUINU0pCIGdfETYLogTXW
VmhuUkEGRoU2KHEd8kFGQSAuIV4RLTF62BU07IOGbzlw4PCfv+JS55mrOyLi
FV8TEWNkGGeSKT7wkVnmmGeBJXLsy4vYTwUHqCJFG5dJc40hXvCaDDk22KRo
Z0QDJzhNE/fo5R0TzDBHXn5EkhqOUs9xWmjnPg8YZoRR3rLCKrsKIsqooZYm
znOLHl4yzBcWKCm0wxGOcZZzdHODXgbIMM0yPykviqikgUY6uE4/z5lill/8
YI1NSosjisknQbBt/pctNsjxh3V+M8N7ppmkj4e00UIt1STYdttnPvGMp9zm
Jhdppp46ykiyIoclFsnyhhHucodmLpCijj3s5ru81xgnwyP66CDNKU6yl3IW
/XeeQZ7QRZrDVLGqK1kGecwVWjnEQb4l/vf4H22SaCQ=
         "]]},
       "0.8`"],
      Annotation[#, 0.8, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{864, 878, 880, 882, 900, 919, 921, 923, 938, 954, 956, 959, 
         982, 1006, 1008, 1012, 1032, 1068, 1070, 1077, 1096, 1140, 1142, 
         1149, 1161, 1214, 1216, 1221, 1233, 1291, 1293, 1300, 1305, 1370, 
         1374, 1435, 1437, 1440, 1442, 1500, 1502}], 
        LineBox[{2299, 2212, 2342, 2344, 2388, 2393, 2434, 2442, 2479, 2485, 
         2517, 2531, 2553, 2564, 2582, 2589, 2602, 2608, 2621, 2628, 2643, 
         2650}], LineBox[CompressedData["
1:eJwl0j1IFAAUB/BnfpeIBDrkolMEFSIJInqCQ5MtElSEDWdIRZxFi4gO0qBG
ugknhFEQdAoFYkNwDRFW4BBlhCKEJKJwg12k2JL9jobf8uDB/300Jgd6UkUR
8YyTJRG/iiMO+MMhRWrlHOM4tdTTxCWu0sd1+hnkORlekOUnefapKI3oIEEX
F5ngAZOkWeIbfzmkuCyimmYS9HKDcSaYYppXvOEHOSrLI2o4Sws9XGGY+8yz
yCoblFZEVHGGc1zgMvcYIc1Tsnxkmzw1lRENdNLNLYZIk+EDS7zlC9tsscF3
1lnjKyt85hPLPOExs8xwm37aaeEoRwr9cqzwkgxjjJKkl3ZaqS3kZde8OXbY
IstrHjJOkmskaOMEdezZa573vGOWR9wlRTfnqaeucAf322SBOYa4Qyun+e0n
ciwwR4qbnCr5/4//AFyKW7Y=
         "]]},
       "0.6`"],
      Annotation[#, 0.6, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{865, 881, 883, 886, 901, 922, 924, 927, 941, 958, 960, 965, 
         984, 1011, 1014, 1020, 1040, 1076, 1079, 1085, 1100, 1148, 1151, 
         1157, 1170, 1220, 1223, 1230, 1237, 1299, 1304, 1369, 1372, 1379, 
         1382, 1439, 1441}], 
        LineBox[{2349, 2252, 2389, 2392, 2440, 2445, 2483, 2492, 2524, 2534, 
         2558, 2569, 2584, 2590, 2603, 2611, 2622, 2629, 2644, 2652}], 
        LineBox[CompressedData["
1:eJwl0kFI03EYBuCftJYzQkKCEjrUSZw7mAOZNUFPUhG0g0UkohASQYp6CPIg
RixIOoTUQQITragEYRDCn2CCoSfpkkZsSERIHnLkrkEPdHi+68f7fe+ZweHc
3ZoQwiJNMYM4dRynmUtcoZcbDDLKSxZ4TcQuv9jn0OEQzpHmAjkmmeIRzymy
yhpf+MvReAgtpGgly02GyDPDMhElynxnj9ojIdSTIs1VrnOfKd5SYJsdQq2c
NNHGZa4xygQzzBGxzg8qHEuEcJoMF7nFPZ7xiiIfWeEzO5T5xlc2eccbFpln
jllGuE03nZwnTYIaSvZv8YH3TPOAIfrppoNGGqjKWeE3uxSJeMoTHpNngD6y
ZDjFCaruWmGDT8zzgnFGyNHDWU7yxw9/ErHEQ8boooN2khzoyB4FlhjmDkla
aYv97+M/WutXWA==
         "]]},
       "0.4`"],
      Annotation[#, 0.4, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{1381, 1378, 1312, 1309, 1301, 1298, 1236, 1229, 1222, 1219, 
         1169, 1156, 1108, 1093, 1087, 1084, 1044, 1028, 1022, 1019, 991, 972,
          967, 964, 943, 932, 929, 926, 906, 891, 888, 885, 867}], 
        LineBox[{2654, 2646, 2632, 2624, 2613, 2605, 2594, 2586, 2572, 2562, 
         2539, 2529, 2491, 2482, 2444, 2441, 2298, 2398}], 
        LineBox[CompressedData["
1:eJwl0jFI1HEYBuBfcVZKIThVHISTmBB0DpbncOIQpyQk6dBUUdigXUpw6JLB
peByyGUgEgonCaZoYEZ/CKHCwU2iKYJoMBG0wUE9gnzA4Zlf3u97q+9nOh6f
CCFMkoiF0MsT5llhhxJXykJI0U+OeSI+8YVtSlw8FUItbdwmwwBTFPnKOnsc
cv50CJdoooW7dDPKGBGrfGaNbfaoOhPCBeJUk+QG9+hhmDxvec93fhErD6GS
Bpp5RIY+nvKaGWaZY4El3rHMB4rkeck4WR6Q5hpxzvJX3m/W+MgUBQbJ0Ema
BDWU81+3n2ywxAxDZOminQSXOUcZf9zxBxGLFBjmBTkecockdVTwz68O2Ocb
q7xihOc84xZJ6rnKSXZtYYtNIt5QZJoJxumjk5u00kyKRq7Hjnd2BEsbVGo=

         "]]},
       "0.2`"],
      Annotation[#, 0.2, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{866, 884, 887, 890, 905, 925, 928, 931, 942, 963, 966, 971, 
         990, 1018, 1021, 1027, 1043, 1083, 1086, 1092, 1107, 1155, 1158, 
         1167, 1175, 1228, 1232, 1242, 1245, 1308, 1311, 1377, 1380}], 
        LineBox[{2397, 2297, 2448, 2348, 2490, 2495, 2530, 2538, 2561, 2571, 
         2585, 2593, 2604, 2612, 2623, 2631, 2645, 2653}], 
        LineBox[CompressedData["
1:eJwl0k9I03EYBvDvYOoETyIEgVIRM3dpIXSY4EGiAilCFOokyPASGTQa/Rjk
v0JjEa522CVCPHiy2MkZ6EGQHeogXRoREVFBh112kLIEP9Dhc33ged/n9NTd
sZlYCOEFlXgIr9jiK9/4QawthHOkSHODPA94SJlNauzwgQM620NI0k+KDLfI
skiJDbb4SINP/CTeEUIXA1zgGhPkmWWNN+zzmSM6EiGcJc1VxpkhosRLauzx
hSbtnSGcZJArTHGfZxRZ4hHzzFIgIk+O21wiQzcJvstt8JbXPOcxd8gyyjBJ
znCKHg51aPKOOntsU6HMCk+YZpIRhujjBL/drcV76qyzyhz3uMl1ztNLjL/+
9Idf7FKlSMRlLvLPBlrUqJIjosAcCyzzlHL8/46OARdRT9Q=
         "]]},
       "0"],
      Annotation[#, 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{869, 889, 892, 894, 907, 930, 933, 935, 945, 970, 973, 979, 
         993, 1026, 1029, 1038, 1050, 1091, 1095, 1105, 1113, 1166, 1174, 
         1227, 1231, 1241, 1244, 1307, 1310}], 
        LineBox[{2450, 2347, 2489, 2494, 2536, 2541, 2568, 2576, 2588, 2595, 
         2606, 2615, 2625, 2633, 2647, 2656}], LineBox[CompressedData["
1:eJwl0j0oJgAYB/Dn5OOVSemiLJJkQUrdoiw+IpRksfiaKC6XLLz5qDslRW+S
Unc7BvlcMJgoGa5cnSQl01tncaU78ivDb/339P8/Jf2jnSMfImKBvcyIGb6x
QIoDfvKLW+64J7Iiyqmgig7GmWCKFPtc8odHnkhkR5TxiW76mSLJLEtscsgV
92TkRORRTjWtdDFGku9sccFv/pOdiCiligY6GWKCJdbZ4ZQb0mTlRhRRQyN9
9NLDGF+ZY5okI7TTSjN1FFJAPjk8yL3mhG1WmOczA7RQRxkfeXX7P55Jc84x
66yxyiLDDNJEPaUU86Kvv1xyxgY/mOELPbRRSTFB2i7n7LLMJO0000AtrzZ/
4ijz/U/eAIUySxw=
         "]]},
       RowBox[{"-", "0.2`"}]],
      Annotation[#, -0.2, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{871, 893, 895, 898, 909, 934, 936, 940, 947, 978, 981, 988, 
         997, 1037, 1049, 1090, 1094, 1104, 1112, 1165, 1168, 1179, 1181, 
         1240, 1243}], 
        LineBox[{2499, 2396, 2537, 2540, 2567, 2575, 2591, 2598, 2610, 2617, 
         2627, 2635, 2649, 2657}], LineBox[CompressedData["
1:eJwl0jsoBWAYBuCfjvuOUjjIIMVEJhQGOeWSlMmlFMlJIYXJ5iSyGEQZDEqI
rIrJLSKXGCw2SrHIQJ4yPONbX+/7Rfvi7SNJIYRZ7iMhPPNDcUoIJZTSwghx
xlhih10OuOSd1NQQCiikhGo66WWaeTbZ55ob7nghKS2ETEqpoJkORplhjS0u
eOSLSHoI+ZTTQBuDTDDHCnsc88AbISOEbCpppJsuOminlRh1FJBHDlm8yj9x
yC7LJBhngFbqKSOXZD7decsVlxyxziorLBBnmCH6aaKWIvL41c8Xt5yzzQYJ
JumhjSqipPFhj2suOGWfRaaIUUOEb1sfc8IZN5H/P/gDZn5FYQ==
         "]]},
       RowBox[{"-", "0.4`"}]],
      Annotation[#, -0.4, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{873, 897, 899, 903, 910, 939, 946, 977, 980, 987, 996, 1036, 
         1039, 1047, 1053, 1103, 1106, 1117, 1119, 1178, 1180}], 
        LineBox[{2543, 2449, 2574, 2577, 2592, 2597, 2609, 2616, 2630, 2636, 
         2651, 2658}], LineBox[CompressedData["
1:eJwl0T8oBHAABeCfdA6FZFBE+ZfCYrApZMDkoqxKnUh3DJerM5qUKLLcIBk4
A4NusRkMSkn+RYYbMTBhMOArw7e94fVe09T8WLIohJCmLhJCM0PMMkeCdXIc
cMQFz7zwRqQkhEZ6iDHJImmWWCXHMVcU+CUaDaGVLoaJkSBDlhzn3PFFcWkI
DXTSzyhxUqyQ5ZBTrnnlh5qyEDpop5UWmmikkneZAmfk2WaNJWaYYJBu6inl
U58n7rnhjH122WGTFAskiTPCAG00EPi2wyOX5NljgwzTjNNLCxV82PuBW644
YYtlxumjnCqqqY38//oH+/s9lw==
         "]]},
       RowBox[{"-", "0.6`"}]],
      Annotation[#, -0.6, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
        LineBox[{875, 902, 904, 908, 913, 944, 948, 986, 989, 995, 999, 1046, 
         1048, 1055, 1056, 1116, 1118}], LineBox[{876, 911, 912, 914, 915}], 
        LineBox[{2578, 2498, 2596, 2599, 2614, 2618, 2634, 2638, 2655, 2659}],
         LineBox[{2661, 2660, 2662, 2663}], LineBox[CompressedData["
1:eJwl0T8oBHAYBuDf0R0DxSQTt50sJisDiuTqFlJ0mY4rkq5YWGQQo1M2deff
oG6QBYvFDUoMNjl1suokxeCR4Rnfvt73i88spOYjIYQs6WgIGbYoUOSQGyq8
8EpdLIR2ehhmhCTT5NikQIlbnvgm1hBCnG4GSTLLMjsUueaedyKNIbTRRR9j
pFlknTxHXHJHlS8++aBGhTLn7LPNKlkmGaKXDpr/8u5WKHNGiVOOOSDPCjmW
yDDKAAk6qedH32eqvPHAFSfsssYc4/SToJUWmqjZ+ZEL9thggqno/59+AaQM
PRQ=
         "]]},
       RowBox[{"-", "0.8`"}]],
      Annotation[#, -0.8, "Tooltip"]& ], {}, {}}}],
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"rf field\"", TraditionalForm], None}, {
     FormBox["\"resonance offset\"", TraditionalForm], None}},
  FrameStyle->Directive[Medium, FontFamily -> "Helvetica"],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{},
  Method->{"DefaultBoundaryStyle" -> Automatic},
  PlotRange->{{-2., 2.}, {0., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic}]], "Output",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.497531405394969*^9, 3.497531476320292*^9, 3.497531579845817*^9, 
   3.497569439391952*^9, 3.497574266956819*^9, 3.4976484994466553`*^9, 
   3.499304103442713*^9, 3.499304150401456*^9, 3.499304182779442*^9, 
   3.502011176260639*^9, 3.5020112399600697`*^9, 3.5027109453239517`*^9, 
   3.502761302549653*^9, 3.50330714976085*^9, 3.507024642987081*^9, 
   3.50702833885542*^9, 3.510318336928258*^9, 3.510318399336216*^9, {
   3.51031878830634*^9, 3.5103188175967293`*^9}, 3.511623963990953*^9, 
   3.513162412179598*^9, 3.515068515165504*^9, 3.515069530075324*^9, 
   3.533177830594707*^9, 3.568904359905752*^9, 3.5713805704583817`*^9, 
   3.70385370827995*^9, 3.703853771687748*^9, 3.703854891786476*^9, 
   3.703854999094979*^9, {3.7038550500230727`*^9, 3.703855062735704*^9}, 
   3.7038551143693886`*^9, 3.703855211383501*^9, 3.7038552886531277`*^9, 
   3.703855418409294*^9, 3.703855491333693*^9, 3.703855533302088*^9, {
   3.7038555835768986`*^9, 3.7038556053235483`*^9}, 3.70385603305287*^9, 
   3.703856077730251*^9, 3.703856186610606*^9, 3.703856282033825*^9, 
   3.7038563826806574`*^9, 3.703856421220403*^9, 3.703856527136936*^9, 
   3.7038565881470594`*^9, 3.7038567966248336`*^9, 3.703920770641244*^9, 
   3.71215114733119*^9, 3.7286342277704763`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PaperOrientation"->"Portrait"},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 573, 14, 30, "Text"],
Cell[CellGroupData[{
Cell[1143, 38, 149, 2, 101, "Title"],
Cell[1295, 42, 208, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[1528, 50, 222, 4, 30, "Input"],
Cell[1753, 56, 196, 5, 34, "Print"],
Cell[1952, 63, 885, 16, 39, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2874, 84, 296, 6, 33, "Subsubtitle"],
Cell[CellGroupData[{
Cell[3195, 94, 94, 1, 49, "Subsection"],
Cell[CellGroupData[{
Cell[3314, 99, 183, 4, 30, "Input"],
Cell[3500, 105, 2071, 32, 40, "Message"],
Cell[5574, 139, 2215, 35, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7826, 179, 134, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[7985, 184, 219, 5, 30, "Input"],
Cell[8207, 191, 746, 15, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8990, 211, 280, 7, 30, "Input"],
Cell[9273, 220, 734, 14, 30, "Output"]
}, Open  ]],
Cell[10022, 237, 335, 9, 50, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10394, 251, 144, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[10563, 256, 149, 3, 30, "Input"],
Cell[10715, 261, 738, 14, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11502, 281, 176, 2, 39, "Subsubsection"],
Cell[11681, 285, 154, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[11860, 292, 885, 23, 30, "Input"],
Cell[12748, 317, 2239, 47, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15024, 369, 278, 5, 30, "Input"],
Cell[15305, 376, 1204, 18, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16570, 401, 299, 4, 49, "Subsection"],
Cell[16872, 407, 208, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[17105, 415, 652, 13, 88, "Input"],
Cell[17760, 430, 2257, 43, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20054, 478, 599, 12, 30, "Input"],
Cell[20656, 492, 11129, 193, 225, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31822, 690, 1172, 28, 30, "Input"],
Cell[32997, 720, 11125, 195, 247, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[44171, 921, 360, 6, 49, "Subsection"],
Cell[CellGroupData[{
Cell[44556, 931, 852, 20, 107, "Input"],
Cell[45411, 953, 3061, 76, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48509, 1034, 1752, 45, 69, "Input"],
Cell[50264, 1081, 20738, 358, 247, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71039, 1444, 3384, 84, 297, "Input"],
Cell[74426, 1530, 42932, 744, 204, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117407, 2280, 359, 6, 49, "Subsection"],
Cell[117769, 2288, 268, 5, 30, "Text"],
Cell[118040, 2295, 195, 5, 30, "Input"],
Cell[118238, 2302, 208, 5, 30, "Input"],
Cell[118449, 2309, 700, 21, 30, "Input"],
Cell[CellGroupData[{
Cell[119174, 2334, 1151, 25, 126, "Input"],
Cell[120328, 2361, 3066, 76, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123431, 2442, 1804, 46, 107, "Input"],
Cell[125238, 2490, 32451, 549, 247, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157726, 3044, 3310, 83, 297, "Input"],
Cell[161039, 3129, 54326, 931, 162, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[215414, 4066, 531, 9, 49, "Subsection"],
Cell[215948, 4077, 195, 5, 30, "Input"],
Cell[216146, 4084, 208, 5, 30, "Input"],
Cell[216357, 4091, 963, 25, 126, "Input"],
Cell[217323, 4118, 1271, 25, 126, "Input"],
Cell[CellGroupData[{
Cell[218619, 4147, 1384, 34, 107, "Input"],
Cell[220006, 4183, 3861, 72, 254, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223904, 4260, 1813, 38, 107, "Input"],
Cell[225720, 4300, 75935, 1315, 374, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

